'use strict';

/* jshint unused: false */

// Copyright 2014 The Serviced Authors.
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// set this guy here to true to get waaaay
// more log messages. exciting!
var DEBUG = false;

/*******************************************************************************
 * Main module & controllers
 ******************************************************************************/
var controlplane = angular.module('controlplane', ['ngRoute', 'ngCookies', 'ngDragDrop', 'pascalprecht.translate', 'ngSanitize', 'angularMoment', 'zenNotify', 'serviceHealth', 'ui.datetimepicker', 'modalService', 'angular-cache', 'ui.codemirror', 'serviceActions', 'sticky', 'graphPanel', 'servicesFactory', 'healthIcon', 'publicEndpointLink', 'authService', 'miscUtils', 'hostsFactory', 'poolsFactory', 'instancesFactory', 'baseFactory', 'ngTable', 'jellyTable', 'ngLocationUpdate', 'CCUIState', 'servicedConfig', 'areUIReady', 'log', 'LogSearch', 'hostIcon', 'appName']);

controlplane.config(['$routeProvider', function ($routeProvider) {
    $routeProvider.when('/login', {
        templateUrl: '/static/partials/login.html',
        controller: "LoginController" }).when('/logs', {
        templateUrl: '/static/partials/logs.html',
        controller: "LogController" }).when('/services/:serviceId', {
        templateUrl: '/static/partials/view-subservices.html',
        controller: "ServiceDetailsController" }).when('/apps', {
        templateUrl: '/static/partials/view-apps.html',
        controller: "AppsController" }).when('/hosts', {
        templateUrl: '/static/partials/view-hosts.html',
        controller: "HostsController",
        controllerAs: "hostsVM" }).when('/hosts/:hostId', {
        templateUrl: '/static/partials/view-host-details.html',
        controller: "HostDetailsController",
        controllerAs: "hostDetailsVM" }).when('/pools', {
        templateUrl: '/static/partials/view-pools.html',
        controller: "PoolsController",
        controllerAs: "poolsVM" }).when('/pools/:poolID', {
        templateUrl: '/static/partials/view-pool-details.html',
        controller: "PoolDetailsController" }).when('/status', {
        templateUrl: '/static/partials/view-status.html',
        controller: "StatusController" }).when('/backuprestore', {
        templateUrl: '/static/partials/view-backuprestore.html',
        controller: "BackupRestoreController" }).when('/internalservices', {
        templateUrl: '/static/partials/view-internal-services.html',
        controller: "InternalServicesController",
        controllerAs: "internalServicesVM" }).when('/internalservices/:id', {
        templateUrl: '/static/partials/view-internal-service-details.html',
        controller: "InternalServiceDetailsController",
        controllerAs: "internalServiceDetailsVM" }).otherwise({ redirectTo: '/apps' });
}]).config(['$translateProvider', function ($translateProvider) {
    $translateProvider.useStaticFilesLoader({
        prefix: '/static/i18n/',
        suffix: '.json'
    });
    $translateProvider.preferredLanguage('en_US');
    $translateProvider.fallbackLanguage('en_US');
    $translateProvider.useSanitizeValueStrategy('sanitizeParameters');
}]).config(['CacheFactoryProvider', function (CacheFactoryProvider) {
    angular.extend(CacheFactoryProvider.defaults, {
        // Items will not be deleted until they are requested
        // and have expired
        deleteOnExpire: 'passive',

        // This cache will clear itself every hour
        cacheFlushInterval: 3600000,

        // This cache will sync itself with localStorage
        storageMode: 'memory'
    });
}]).
/**
 * Default Get requests to no caching
 **/
config(["$httpProvider", function ($httpProvider) {
    //initialize get if not there
    if (!$httpProvider.defaults.headers.get) {
        $httpProvider.defaults.headers.get = {};
    }
    $httpProvider.defaults.headers.get['Cache-Control'] = 'no-cache';
    $httpProvider.defaults.headers.get['Pragma'] = 'no-cache';
    $httpProvider.defaults.headers.get['If-Modified-Since'] = 'Mon, 26 Jul 1997 05:00:00 GMT';
}]).filter('treeFilter', function () {
    /*
     * @param items The array from ng-repeat
     * @param field Field on items to check for validity
     * @param validData Object with allowed objects
     */
    return function (items, field, validData) {
        if (!validData) {
            return items;
        }
        return items.filter(function (elem) {
            return validData[elem[field]] !== null;
        });
    };
}).filter('toGB', function () {
    return function (input, hide) {
        return (input / (1024 * 1024 * 1024)).toFixed(2) + (hide ? "" : " GB");
    };
}).filter('toMB', function () {
    return function (input, hide) {
        return (input / (1024 * 1024)).toFixed(2) + (hide ? "" : " MB");
    };
}).filter('cut', function () {
    return function (value, wordwise, max, tail) {
        if (!value) {
            return '';
        }

        max = parseInt(max, 10);
        if (!max) {
            return value;
        }
        if (value.length <= max) {
            return value;
        }

        value = value.substr(0, max);
        if (wordwise) {
            var lastspace = value.lastIndexOf(' ');
            if (lastspace !== -1) {
                value = value.substr(0, lastspace);
            }
        }

        return value + (tail || ' …');
    };
}).filter('prettyDate', function () {
    return function (dateString) {
        return moment(new Date(dateString)).format('MMM Do YYYY, hh:mm:ss');
    };
}).
// create a human readable "fromNow" string from
// a date. eg: "a few seconds ago"
filter('fromNow', function () {
    return function (date) {
        return moment(date).fromNow();
    };
}).run(["$rootScope", "$window", "$location", "areUIReady", "log", "CCUIState", function ($rootScope, $window, $location, areUIReady, log, CCUIState) {
    // scroll to top of page on navigation
    $rootScope.$on("$routeChangeSuccess", function (event, currentRoute, previousRoute) {
        $window.scrollTo(0, 0);
    });

    var queryParams = $location.search(),
        config = CCUIState.get();

    // option to disable animation for
    // acceptance tests
    if (queryParams["disable-animation"] === "true") {
        $("body").addClass("no-animation");
        config.disableAnimation = true;
    }

    // set log level
    if (queryParams["loglevel"]) {
        log.setLogLevel(log.level[queryParams["loglevel"]]);
        log.info('set log level to ' + queryParams["loglevel"]);
    }

    var loaderEl = $(".loading_wrapper"),
        isCleared = false;

    $rootScope.$on("ready", function () {
        var clearLoader = function clearLoader() {
            loaderEl.remove();
            $("body").removeClass("loading");
            isCleared = true;
        };

        setTimeout(function () {
            if (!isCleared) {
                if (config.disableAnimation) {
                    clearLoader();
                } else {
                    loaderEl.addClass("hide_it").one("transitionend", clearLoader);
                }
            }
        }, 1000);
    });

    // tiny but visible loading indicator
    // if the UI is busy
    var uiLockEl = $("<div class='uilock icon-spin' style='display: none;'></div>");
    $("body").append(uiLockEl);
    areUIReady.onLock = function () {
        uiLockEl.show();
    };
    areUIReady.onUnlock = function () {
        uiLockEl.hide();
    };
}]);
"use strict";

/* BackupRestoreController
 * Lists existing backups and allows creation
 * of new backups.
 */
(function () {
    'use strict';

    controlplane.controller("BackupRestoreController", ["$scope", "$routeParams", "$notification", "$translate", "resourcesFactory", "authService", "$modalService", function ($scope, $routeParams, $notification, $translate, resourcesFactory, authService, $modalService) {
        // Ensure logged in
        authService.checkLogin($scope);

        // localization messages
        var BACKUP_RUNNING = $translate.instant("backup_running"),
            BACKUP_COMPLETE = $translate.instant("backup_complete"),
            RESTORE_RUNNING = $translate.instant("restore_running"),
            RESTORE_COMPLETE = $translate.instant("restore_complete"),
            ERROR = $translate.instant("error");

        $scope.createBackup = function () {

            var modalScope = $scope.$new(true);

            $modalService.create({
                templateUrl: "add-backup.html",
                model: modalScope,
                title: "backup_create",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "backup_create",
                    classes: "btn-primary submit backup-ok",
                    action: function action() {
                        var notification = $notification.create("Backup").updateStatus(BACKUP_RUNNING).show(false);

                        // TODO - when the server switches to broadcast instead of
                        // channel. this can be greatly simplified
                        resourcesFactory.createBackup().success(function checkFirstStatus() {
                            // recursively check if a valid status has been pushed into
                            // the pipe. if not, shake yourself off and try again. try again.
                            resourcesFactory.getBackupStatus().success(function (data) {
                                // no status has been pushed, so check again
                                if (data.Detail === "") {
                                    checkFirstStatus();

                                    // a valid status has been pushed, so
                                    // start the usual poll cycle
                                } else {
                                    pollBackupStatus(notification);
                                }
                            }).error(function (data, status) {
                                backupRestoreError(notification, data.Detail, status);
                            });
                        }).error(function (data, status) {
                            backupRestoreError(notification, data.Detail, status);
                        });

                        this.close();
                    }
                }],
                onShow: function onShow() {
                    var _this = this;

                    this.disableAction("backup-ok");
                    modalScope.backupCheck = {
                        BackupPath: "",
                        AvailableString: "",
                        EstimatedString: "",
                        AllowBackup: true,
                        pct: 0,
                        mcKraken: "",
                        ready: ""
                    };

                    resourcesFactory.getBackupCheck().success(function (data, status) {

                        var pct = data.EstimatedBytes / data.AvailableBytes * 100;
                        pct = Math.min(100, pct); // don't break out of box
                        pct = Math.max(1, pct); // show _something_

                        modalScope.backupCheck.pct = pct;
                        modalScope.backupCheck.BackupPath = data.BackupPath;
                        modalScope.backupCheck.AvailableString = data.AvailableString;
                        modalScope.backupCheck.EstimatedString = data.EstimatedString;
                        modalScope.backupCheck.mcKraken = "disappear";

                        if (data.AllowBackup) {
                            modalScope.backupCheck.ready = "ready";
                            _this.enableAction("backup-ok");
                        } else {
                            modalScope.backupCheck.ready = "ready danger";
                        }
                    }).error(function (data, status) {
                        // do something
                    });
                }
            });
        };

        $scope.restoreBackup = function (filename) {
            $modalService.create({
                template: $translate.instant("confirm_start_restore"),
                model: $scope,
                title: "restore",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "restore",
                    classes: "btn-danger",
                    action: function action() {
                        var notification = $notification.create("Restore").updateStatus(RESTORE_RUNNING).show(false);

                        // TODO - when the server switches to broadcast instead of
                        // channel. this can be greatly simplified
                        resourcesFactory.restoreBackup(filename).success(function checkFirstStatus() {
                            // recursively check if a valid status has been pushed into
                            // the pipe. if not, shake yourself off and try again. try again.
                            resourcesFactory.getRestoreStatus().success(function (data) {
                                // no status has been pushed, so check again
                                if (data.Detail === "") {
                                    checkFirstStatus();

                                    // a valid status has been pushed, so
                                    // start the usual poll cycle
                                } else {
                                    notification.updateStatus(data.Detail);
                                    pollRestoreStatus(notification);
                                }
                            }).error(function (data, status) {
                                backupRestoreError(notification, data.Detail, status);
                            });
                        }).error(function (data, status) {
                            backupRestoreError(notification, data.Detail, status);
                        });

                        this.close();
                    }
                }]
            });
        };

        function pollBackupStatus(notification) {
            resourcesFactory.getBackupStatus().success(function (data) {

                if (data.Detail === "") {
                    notification.updateStatus(BACKUP_COMPLETE);
                    notification.success(false);
                    getBackupFiles();
                    return;
                } else if (data.Detail !== "timeout") {
                    notification.updateStatus(data.Detail);
                }

                // poll again
                setTimeout(function () {
                    pollBackupStatus(notification);
                }, 3000);
            }).error(function (data, status) {
                backupRestoreError(notification, data.Detail, status);
            });
        }

        function pollRestoreStatus(notification) {
            resourcesFactory.getRestoreStatus().success(function (data) {

                // all done!
                if (data.Detail === "") {
                    notification.updateStatus(RESTORE_COMPLETE);
                    notification.success(false);
                    return;

                    // something neato has happened. lets show it.
                } else if (data.Detail !== "timeout") {
                    notification.updateStatus(data.Detail);
                }

                // poll again
                setTimeout(function () {
                    pollRestoreStatus(notification);
                }, 3000);
            }).error(function (data, status) {
                backupRestoreError(notification, data.Detail, status);
            });
        }

        function backupRestoreError(notification, data, status) {
            notification.updateTitle(ERROR + " " + status);
            notification.updateStatus(data);
            notification.error();
        }

        function getBackupFiles() {
            resourcesFactory.getBackupFiles().success(function (data) {
                $scope.backupFiles = data;

                $scope.$emit("ready");
            });
        }

        function init() {
            $scope.name = "backuprestore";
            $scope.params = $routeParams;
            $scope.breadcrumbs = [{ label: 'breadcrumb_backuprestore', itemClass: 'active' }];

            $scope.backupTable = {
                sorting: {
                    full_path: "asc"
                },
                searchColumns: ['full_path']
            };

            //load backup files
            getBackupFiles();

            // poll for backup files
            resourcesFactory.registerPoll("running", getBackupFiles, 5000);
        }

        init();

        $scope.$on("$destroy", function () {
            resourcesFactory.unregisterAllPolls();
        });
    }]);
})();
"use strict";

/* globals controlplane: true */

/* DeployWizard.js
 * Guides user through deployment of an app
 */
(function () {
    'use strict';

    controlplane.controller("DeployWizard", ["$scope", "$rootScope", "$notification", "$translate", "$q", "resourcesFactory", "servicesFactory", "miscUtils", "log", "Pool", "Host", function ($scope, $rootScope, $notification, $translate, $q, resourcesFactory, servicesFactory, utils, log, Pool, Host) {
        var step = 0;
        var nextClicked = false;
        $scope.name = 'wizard';

        $scope.dockerLoggedIn = true;

        resourcesFactory.dockerIsLoggedIn().success(function (loggedIn) {
            $scope.dockerLoggedIn = loggedIn;
        });

        $scope.dockerIsNotLoggedIn = function () {
            return !$scope.dockerLoggedIn;
        };

        var showError = function showError(message) {
            $("#deployWizardNotificationsContent").html(message);
            $("#deployWizardNotifications").removeClass("hide");
        };

        var resetError = function resetError() {
            $("#deployWizardNotifications").html("");
            $("#deployWizardNotifications").addClass("hide");
        };

        var validTemplateSelected = function validTemplateSelected() {
            if (!$scope.install.templateID) {
                showError($translate.instant("label_wizard_select_app"));
                return false;
            } else {
                resetError();
            }

            return true;
        };

        var validDeploymentID = function validDeploymentID() {
            if ($scope.install.deploymentID === undefined || $scope.install.deploymentID === "") {
                showError($translate.instant("label_wizard_deployment_id"));
                return false;
            } else {
                resetError();
            }

            return true;
        };

        var validTemplateUpload = function validTemplateUpload() {
            var uploadedFiles = $("#new_template_filename_wizard")[0].files;
            if (uploadedFiles.length === 0) {
                showError($translate.instant("template_error"));
                return false;
            } else {
                var formData = new FormData();
                $.each(uploadedFiles, function (key, value) {
                    formData.append("tpl", value);
                });
                resourcesFactory.addAppTemplate(formData).success($scope.refreshAppTemplates).error(function () {
                    showError("Add Application Template failed");
                });

                resetError();
                return true;
            }
        };

        var validHost = function validHost() {
            var err = utils.validateHostName($scope.newHost.host, $translate) || utils.validatePortNumber($scope.newHost.port, $translate) || utils.validateRAMLimit($scope.newHost.RAMLimit);
            if (err) {
                showError(err);
                return false;
            }

            $scope.newHost.IPAddr = $scope.newHost.host + ':' + $scope.newHost.port;

            resourcesFactory.addHost($scope.newHost).success(function () {
                step += 1;
                resetError();
                $scope.step_page = $scope.steps[step].content;
            }).error(function (data) {
                // if it already exists then allow the user to continue
                if (data.Detail.indexOf('already exists') !== -1) {
                    step += 1;
                    resetError();
                    $scope.step_page = $scope.steps[step].content;
                } else {
                    showError("Add Host failed", data.Detail);
                }
            });

            return false;
        };

        var resetStepPage = function resetStepPage() {
            step = 0;

            $scope.install = {
                poolID: 'default'
            };

            if ($scope.templates.data.length === 0) {
                $scope.steps.unshift({
                    content: '/static/partials/wizard-modal-add-template.html',
                    label: 'template_add',
                    validate: validTemplateUpload
                });
            }

            // if there is not at least one host, add an
            // "add host" step to the wizard
            if ($scope.hosts.length === 0) {
                $scope.newHost = {
                    port: $translate.instant('placeholder_port')
                };
                if ($scope.poolIds.length > 0) {
                    $scope.newHost.PoolID = $scope.poolIds[0];
                }
                $scope.steps.unshift({
                    content: '/static/partials/wizard-modal-add-host.html',
                    label: 'add_host',
                    validate: validHost
                });
            }

            $scope.step_page = $scope.steps[step].content;
        };

        $scope.steps = [{
            content: '/static/partials/wizard-modal-2.html',
            label: 'label_step_select_app',
            validate: validTemplateSelected
        }, {
            content: '/static/partials/wizard-modal-3.html',
            label: 'label_step_select_pool' }, {
            content: '/static/partials/wizard-modal-4.html',
            label: 'label_step_deploy',
            validate: validDeploymentID
        }];

        $scope.install = {
            poolID: 'default'
        };

        $scope.selectTemplate = function (template) {
            $scope.template = template;
            $scope.install.templateID = template.ID;
        };

        $scope.selectPool = function (pool) {
            $scope.install.poolID = pool.id;
        };

        $scope.getTemplateRequiredResources = function (template) {
            var ret = { CPUCommitment: 0, RAMCommitment: 0 };

            // if Services, iterate and sum up their commitment values
            if (template.Services) {
                var suffixToMultiplier = {
                    "": 1,
                    "k": 1 << 10,
                    "m": 1 << 20,
                    "g": 1 << 30,
                    "t": 1 << 40
                };
                var engNotationRE = /([0-9]*)([kKmMgGtT]?)/;
                // Convert an engineeringNotation string to a number
                var toBytes = function toBytes(RAMCommitment) {
                    if (RAMCommitment === "") {
                        return 0;
                    }
                    var match = RAMCommitment.match(engNotationRE);
                    var numeric = match[1];
                    var suffix = match[2].toLowerCase();
                    var multiplier = suffixToMultiplier[suffix];
                    var val = parseInt(numeric);
                    return val * multiplier;
                };
                // recursively calculate cpu and ram commitments
                (function calcCommitment(services) {
                    services.forEach(function (service) {
                        // CPUCommitment should be equal to max number of
                        // cores needed by any service
                        ret.CPUCommitment = Math.max(ret.CPUCommitment, service.CPUCommitment);
                        // RAMCommitment should be a sum of all ram needed
                        // by all services
                        ret.RAMCommitment += toBytes(service.RAMCommitment);

                        // recurse!
                        if (service.Services) {
                            calcCommitment(service.Services);
                        }
                    });
                })(template.Services);
            }

            return ret;
        };

        $scope.addHostStart = function () {
            $scope.newHost = {
                port: $translate.instant('placeholder_port')
            };
            if ($scope.poolIds.length > 0) {
                $scope.newHost.PoolID = $scope.poolIds[0];
            }
            $scope.step_page = '/static/partials/wizard-modal-addhost.html';
        };

        $scope.hasPrevious = function () {
            return step > 0 && $scope.step_page === $scope.steps[step].content;
        };

        $scope.hasNext = function () {
            return step + 1 < $scope.steps.length && $scope.step_page === $scope.steps[step].content;
        };

        $scope.hasFinish = function () {
            return step + 1 === $scope.steps.length;
        };

        $scope.step_item = function (index) {
            var cls = index <= step ? 'active' : 'inactive';
            if (index === step) {
                cls += ' current';
            }
            return cls;
        };

        $scope.step_label = function (index) {
            return index < step ? 'done' : '';
        };

        $scope.wizard_next = function () {
            nextClicked = true;

            if ($scope.step_page !== $scope.steps[step].content) {
                $scope.step_page = $scope.steps[step].content;
                nextClicked = false;
                return;
            }

            if ($scope.steps[step].validate) {
                if (!$scope.steps[step].validate()) {
                    nextClicked = false;
                    return;
                }
            }

            step += 1;
            resetError();
            $scope.step_page = $scope.steps[step].content;
            nextClicked = false;
        };

        $scope.wizard_previous = function () {
            step -= 1;
            $scope.step_page = $scope.steps[step].content;
            resetError();
        };

        $scope.wizard_finish = function () {

            var closeModal = function closeModal() {
                $('#addApp').modal('hide');
                $("#deploy-save-button").removeAttr("disabled");
                $("#deploy-save-button").removeClass('active');
                resetStepPage();
                resetError();
                $rootScope.$emit("wizard.deployed");
            };

            nextClicked = true;
            if ($scope.steps[step].validate) {
                if (!$scope.steps[step].validate()) {
                    return;
                }
            }

            $("#deploy-save-button").toggleClass('active');
            $("#deploy-save-button").attr("disabled", "disabled");

            var deploymentDefinition = {
                poolID: $scope.install.poolID,
                TemplateID: $scope.install.templateID,
                DeploymentID: $scope.install.deploymentID
            };

            var checkStatus = true;
            resourcesFactory.deployAppTemplate(deploymentDefinition).success(function () {
                checkStatus = false;
                servicesFactory.update(true, false);
                $notification.create("App deployed successfully").success();
                closeModal();
            }).error(function (data, status) {
                checkStatus = false;
                $notification.create("App deploy failed", data.Detail).error();
                closeModal();
            });

            //now that we have started deploying our app, we poll for status
            var deployStatusRequest = {
                DeploymentID: $scope.install.deploymentID,
                LastStatus: "initial status that won't match anything",
                Timeout: 3000
            };
            var getStatus = function getStatus() {
                if (checkStatus) {
                    var $status = $("#deployStatusText");
                    resourcesFactory.getDeployStatus(deployStatusRequest).success(function (data) {
                        if (data.Detail === deployStatusRequest.lastStatus) {
                            $("#deployStatus .dialogIcon").fadeOut(200, function () {
                                $("#deployStatus .dialogIcon").fadeIn(200);
                            });
                        } else {
                            deployStatusRequest.LastStatus = data.Detail;
                            var parts = data.Detail.split("|");
                            if (parts[1]) {
                                $status.html('<strong>' + $translate.instant(parts[0]) + ":</strong> " + parts[1]);
                            } else {
                                $status.html('<strong>' + $translate.instant(parts[0]) + '</strong>');
                            }
                        }
                    }).error(function (err) {
                        log.warn("Error getting deploy status", err);
                    }).finally(function () {
                        getStatus();
                    });
                }
            };

            $("#deployStatus").show();
            getStatus();

            nextClicked = false;
        };

        $scope.refreshAppTemplates = function () {
            var MAX_RETRIES = 4;
            var deferred = $q.defer(),
                attempts = 0;

            // allow requests to be repeated if necessary
            var fetch = function fetch() {
                resourcesFactory.getAppTemplates().then(function (templatesMap) {
                    var templates = [];
                    for (var key in templatesMap) {
                        var template = templatesMap[key];
                        template.ID = key;
                        templates.push(template);
                    }
                    $scope.templates.data = templates;
                    deferred.resolve();
                }, function () {
                    if (attempts >= MAX_RETRIES) {
                        deferred.reject("Unable to refresh application templates");
                    }
                    // retry in 3s
                    setTimeout(fetch, 3000);
                    attempts++;
                });
            };
            fetch();

            return deferred.promise;
        };

        function init() {
            var p1 = $scope.refreshAppTemplates().catch(function (e) {
                return console.warn("error refreshing app templates: " + e);
            });
            var p2 = resourcesFactory.v2.getHosts().then(function (data) {
                $scope.hosts = data.map(function (result) {
                    return new Host(result);
                });
            }).catch(function (e) {
                return console.warn("error fetching hosts", e);
            });
            var p3 = resourcesFactory.v2.getPools().then(function (data) {
                $scope.pools = data.map(function (p) {
                    return new Pool(p);
                });
                $scope.poolIds = $scope.pools.map(function (p) {
                    return p.id;
                }).sort();
            }).catch(function (e) {
                return console.warn("error fetching pool", e);
            });

            return $q.all([p1, p2, p3]).catch(function (e) {
                return console.warn("error initializing DeployWiz", e);
            });
        }

        init().then(resetStepPage);
    }]);
})();
'use strict';

/* globals jstz: true */

/* graphpanel
 * creates graphs from graph configs, and provides
 * controls for displayed range and update frequency
 */

(function () {
    'use strict';

    angular.module('graphPanel', []).directive("graphPanel", ["$interval", "$location", function ($interval, $location) {
        return {
            restrict: "E",
            scope: {
                serviceId: "=",
                graphConfigs: "="
            },
            templateUrl: "/static/partials/graphpanel.html",
            link: function link($scope, element) {

                // configure viz library
                zenoss.visualization.url = $location.protocol() + "://" + $location.host() + ':' + $location.port();
                zenoss.visualization.urlPath = '/metrics/static/performance/query/';
                zenoss.visualization.urlPerformance = '/metrics/api/performance/query/';
                zenoss.visualization.debug = false;

                $scope.graphs = {};
                $scope.showStartEnd = false;
                $scope.showGraphControls = false;
                $scope.refreshInterval = 300000;

                var momentFormat = "MM/DD/YYYY  HH:mm:ss";

                // graph configuration used to generate
                // query service requests
                $scope.graphConfig = {
                    aggregator: "sum",
                    start: zenoss.utils.createDate("1h-ago").format(momentFormat),
                    end: zenoss.utils.createDate("0s-ago").format(momentFormat),
                    range: "1h-ago",
                    now: true
                };

                $scope.viz = function (graph) {
                    var id = $scope.getUniqueGraphId(graph),
                        graphCopy;

                    if (!$scope.graphs[id]) {
                        if (window.zenoss === undefined) {
                            return "Not collecting stats, graphs unavailable";
                        } else {
                            // create a copy of graph so that range changes
                            // do not affect the original service def
                            graphCopy = angular.copy(graph);

                            // set graphs to local browser time
                            graphCopy.timezone = jstz.determine().name();

                            updateGraphRequest(graphCopy);
                            zenoss.visualization.chart.create(id, graphCopy);

                            // store graph def for later use
                            $scope.graphs[id] = graphCopy;
                        }
                    }
                };

                $scope.datetimePickerOptions = {
                    maxDate: new Date(),
                    mask: true,
                    closeOnDateSelect: true,
                    format: "m/d/Y  H:i:s",
                    onChangeDateTime: function onChangeDateTime() {
                        // let angular finish current digest cycle
                        // before updating the graphs
                        setTimeout(function () {
                            $scope.refreshGraphs();
                        }, 0);
                    }
                };

                // select options for graph aggregation
                $scope.aggregators = [{
                    name: "Average",
                    val: "avg"
                }, {
                    name: "Sum",
                    val: "sum"
                }];
                // refresh intervals
                $scope.intervals = [{
                    name: "1 Second",
                    val: 1000
                }, {
                    name: "5 Seconds",
                    val: 5000
                }, {
                    name: "1 Minute",
                    val: 60000
                }, {
                    name: "5 Minutes",
                    val: 300000
                }, {
                    name: "15 Minutes",
                    val: 900000
                }, {
                    name: "Never",
                    val: 0
                }];
                // select options for graph ranges
                var CUSTOM_RANGE = "custom";
                $scope.ranges = [{
                    name: "Last hour",
                    val: "1h-ago"
                }, {
                    name: "Last 4 hours",
                    val: "4h-ago"
                }, {
                    name: "Last 12 hours",
                    val: "12h-ago"
                }, {
                    name: "Last 24 hours",
                    val: "1d-ago"
                }, {
                    name: "Last 48 hours",
                    val: "2d-ago"
                }, {
                    name: "[Custom]",
                    val: CUSTOM_RANGE
                }];

                // on range select change, update start/end
                // values to reflect the selected range
                $scope.rangeChange = function () {
                    var range = $scope.graphConfig.range;

                    if (range === CUSTOM_RANGE) {
                        // show start/end options
                        $scope.showStartEnd = true;
                    } else {
                        // hide start/end opts
                        $scope.showStartEnd = false;

                        // parse graph range into something the date picker likes
                        $scope.graphConfig.start = zenoss.utils.createDate($scope.graphConfig.range).format(momentFormat);

                        // when using a range, always use "now" for the end time
                        $scope.graphConfig.end = zenoss.utils.createDate("0s-ago").format(momentFormat);
                    }

                    $scope.refreshGraphs();
                };

                // on refresh change, update refresh interval
                $scope.setupAutoRefresh = function () {
                    // cancel existing refresh
                    $interval.cancel($scope.refreshPromise);

                    // if refreshInterval is zero, don't setup
                    // a refresh interval
                    if ($scope.refreshInterval) {
                        // start auto-refresh
                        $scope.refreshPromise = $interval(function () {
                            $scope.refreshGraphs();
                        }, $scope.refreshInterval);
                    }
                };

                // kick off inital graph request
                $scope.setupAutoRefresh();

                $scope.refreshGraphs = function () {
                    // don't refresh graph if tab is not visible
                    if (document.hidden) {
                        return;
                    }

                    var graph;

                    // iterate and update all graphs
                    for (var i in $scope.graphs) {
                        graph = $scope.graphs[i];
                        updateGraphRequest(graph);
                        zenoss.visualization.chart.update(i, graph);
                    }
                };

                $scope.getUniqueGraphId = function (graph) {
                    return ($scope.serviceId + "-graph-" + graph.id).replace(/\./g, "_");
                };

                $scope.cleanup = function () {
                    var chart;

                    // remove graph from cache
                    for (var id in $scope.graphs) {
                        // TODO - expose removeChart() and use it
                        chart = zenoss.visualization.chart.getChart(id);
                        chart.onDestroyed();
                    }

                    $scope.graphs = {};
                };

                $scope.graphControlsPopover = function () {
                    $scope.showGraphControls = !$scope.showGraphControls;
                };

                // make clicking anywhere outside of graph
                // control hide it
                var hideGraphControls = function hideGraphControls() {
                    $scope.showGraphControls = false;
                    // force angular to apply the visibility change
                    $scope.$apply();
                };
                angular.element("html").on("click", hideGraphControls);

                $scope.$watch("serviceId", $scope.cleanup);

                $scope.$on("$destroy", function () {
                    $scope.cleanup();
                    $interval.cancel($scope.refreshPromise);
                    angular.element("html").off("click", hideGraphControls);
                });

                function updateGraphRequest(graph) {
                    // update aggregator
                    graph.datapoints.forEach(function (dp) {
                        dp.aggregator = $scope.graphConfig.aggregator;
                    });

                    // if end should always be "now", use current time
                    if ($scope.graphConfig.now) {
                        $scope.graphConfig.end = zenoss.utils.createDate("0s-ago").format(momentFormat);
                        graph.range.end = zenoss.utils.createDate($scope.graphConfig.end).valueOf();

                        // else, use specified end time
                    } else {
                        graph.range.end = zenoss.utils.createDate($scope.graphConfig.end).valueOf();
                    }

                    // if range, update start time
                    if ($scope.graphConfig.range !== CUSTOM_RANGE) {
                        $scope.graphConfig.start = zenoss.utils.createDate($scope.graphConfig.range).format(momentFormat);
                    }
                    // update start/end
                    graph.range.start = zenoss.utils.createDate($scope.graphConfig.start).valueOf();
                }
            }
        };
    }]);
})();
'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* healthIconDirective
 * directive for displaying health of a service/instance
 * in icon form with helpful popover details
 */
(function () {
    'use strict';

    angular.module('healthIcon', []).directive("healthIcon", ["hcStatus", function (hcStatus) {
        var OK = hcStatus.OK,
            FAILED = hcStatus.FAILED,
            NOT_RUNNING = hcStatus.NOT_RUNNING,
            UNKNOWN = hcStatus.UNKNOWN,
            EMERGENCY_SHUTDOWN = hcStatus.EMERGENCY_SHUTDOWN;


        return {
            restrict: "E",
            scope: {
                // status object generated by serviceHealth
                status: "="
            },
            template: '<i class="healthIcon glyphicon"></i><div class="healthIconBadge"></div>',
            link: function link($scope, element, attrs) {
                var _STATUS_STYLES;

                var STATUS_STYLES = (_STATUS_STYLES = {}, _defineProperty(_STATUS_STYLES, FAILED, "glyphicon glyphicon-exclamation bad"), _defineProperty(_STATUS_STYLES, OK, "glyphicon glyphicon-ok good"), _defineProperty(_STATUS_STYLES, UNKNOWN, "glyphicon glyphicon-question unknown"), _defineProperty(_STATUS_STYLES, NOT_RUNNING, "glyphicon glyphicon-minus disabled"), _defineProperty(_STATUS_STYLES, EMERGENCY_SHUTDOWN, "glyphicon glyphicon-fire bad"), _STATUS_STYLES);

                // cache some DOM elements
                var $el = $(element),
                    $badge = $el.find(".healthIconBadge"),
                    lastStatus;

                function update() {
                    var statusObj,
                        popoverHTML,
                        hideHealthChecks,
                        placement = "right",
                        popoverObj,
                        template;

                    statusObj = $scope.status;

                    if (!statusObj) {
                        // TODO - re-implement?
                        //statusObj = new Status(id, "", 1);
                        //statusObj.statusRollup.incNotRunning();
                        //statusObj.evaluateStatus();
                        return;
                    }

                    // determine if we should hide healthchecks
                    hideHealthChecks = false;

                    // if service should be up and there is more than 1 instance, show number of instances
                    if (statusObj.statusRollup.total > 1) {
                        $el.addClass("wide");
                        $badge.text(statusObj.statusRollup[OK] + "/" + statusObj.statusRollup.total).show();

                        // else, hide the badge
                    } else {
                        $el.removeClass("wide");
                        $badge.hide();
                    }

                    // setup popover

                    // if this $el is inside a .serviceTitle, make the popover point down
                    if ($el.parent().hasClass("serviceTitle")) {
                        placement = "bottom";
                    }

                    // if this statusObj has children, we wanna show
                    // them in the healtcheck tooltip, so generate
                    // some yummy html
                    if (statusObj.children.length) {
                        popoverHTML = [];

                        var isHealthCheckStatus = function isHealthCheckStatus(status) {
                            return !status.id;
                        };

                        // if this status's children are healthchecks,
                        // no need for instance rows, go straight to healthcheck rows
                        if (statusObj.children.length && isHealthCheckStatus(statusObj.children[0])) {
                            // if these are JUST healthchecks, then don't allow them
                            // to be hidden. this ensures that healthchecks show up for
                            // running instances.
                            hideHealthChecks = false;
                            // don't show count badge for healthchecks either
                            $badge.hide();
                            $el.removeClass("wide");

                            statusObj.children.forEach(function (hc) {
                                popoverHTML.push(bindHealthCheckRowTemplate(hc));
                            });

                            // else these are instances, so create instance rows
                            // AND healthcheck rows
                        } else {
                            statusObj.children.forEach(function (instanceStatus) {
                                // if this is becoming too long, stop adding rows
                                if (popoverHTML.length >= 15) {
                                    // add an overflow indicator if not already there
                                    if (popoverHTML[popoverHTML.length - 1] !== "...") {
                                        popoverHTML.push("...");
                                    }
                                    return;
                                }

                                // only create an instance row for this instance if
                                // it's in a bad or unknown state
                                if (instanceStatus.status === FAILED || instanceStatus.status === UNKNOWN) {
                                    popoverHTML.push("<div class='healthTooltipDetailRow'>");
                                    popoverHTML.push("<div style='font-weight: bold; font-size: .9em; padding: 5px 0 3px 0;'>" + instanceStatus.name + "</div>");
                                    instanceStatus.children.forEach(function (hc) {
                                        popoverHTML.push(bindHealthCheckRowTemplate(hc));
                                    });
                                    popoverHTML.push("</div>");
                                }
                            });
                        }

                        popoverHTML = popoverHTML.join("");
                    }

                    // choose a popover template which is just a title,
                    // or a title and content
                    template = hideHealthChecks || !popoverHTML ? '<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-title"></h3></div>' : '<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-title"></h3><div class="popover-content"></div></div>';

                    // NOTE: directly accessing the bootstrap popover
                    // data object here.
                    popoverObj = $el.data("bs.popover");

                    // if popover element already exists, update it
                    if (popoverObj) {
                        // update title, content, and template
                        popoverObj.options.title = statusObj.description;
                        popoverObj.options.content = popoverHTML;
                        popoverObj.options.template = template;

                        // if the tooltip already exists, change the contents
                        // to the new template
                        if (popoverObj.$tip) {
                            popoverObj.$tip.html($(template).html());
                        }

                        // force popover to update using the new options
                        popoverObj.setContent();

                        // if the popover is currently visible, update
                        // it immediately, but turn off animation to
                        // prevent it fading in
                        if (popoverObj.$tip.is(":visible")) {
                            popoverObj.options.animation = false;
                            popoverObj.show();
                            popoverObj.options.animation = true;
                        }

                        // if popover element doesn't exist, create it
                    } else {
                        $el.popover({
                            trigger: "hover",
                            placement: placement,
                            delay: 0,
                            title: statusObj.description,
                            html: true,
                            content: popoverHTML,
                            template: template
                        });
                    }

                    $el.removeClass(Object.keys(STATUS_STYLES).join(" ")).addClass(statusObj.status);

                    // if the status has changed since last tick, or
                    // it was and is still unknown, notify user
                    if (lastStatus !== statusObj.status || lastStatus === UNKNOWN && statusObj.status === UNKNOWN) {
                        bounceStatus($el);
                    }
                    // store the status for comparison later
                    lastStatus = statusObj.status;
                }

                // if status object updates, update icon
                $scope.$watch("status", update);

                // TODO - cleanup watch
                $scope.$on("$destroy", function () {});

                function bindHealthCheckRowTemplate(hc) {
                    return "<div class='healthTooltipDetailRow " + hc.status + "'>\
                            <i class='healthIcon glyphicon'></i>\
                        <div class='healthTooltipDetailName'>" + hc.name + "</div>\
                    </div>";
                }

                function bounceStatus($el) {
                    $el.addClass("zoom");

                    $el.on("webkitAnimationEnd animationend", function () {
                        $el.removeClass("zoom");
                        // clean up animation end listener
                        $el.off("webkitAnimationEnd animationend");
                    });
                }
            }
        };
    }]);
})();
"use strict";

/* jshint multistr: true */
(function () {
    'use strict';

    // OK means health check is passing

    var OK = "passed";
    // Failed means health check is responsive, but failing
    var FAILED = "failed";
    // Timeout means health check is non-responsive in the given time
    var TIMEOUT = "timeout";
    // NotRunning means the instance is not running
    var NOT_RUNNING = "not_running";
    // Unknown means the instance hasn't checked in within the provided time
    // limit.
    var UNKNOWN = "unknown";
    // EMERGENCY_SHUTDOWN means instance has been emergency shutdown
    var EMERGENCY_SHUTDOWN = "emergency_shutdown";

    var serviceHealthModule = angular.module('serviceHealth', []);

    // share constants for other packages to use
    serviceHealthModule.value("hcStatus", {
        OK: OK,
        FAILED: FAILED,
        TIMEOUT: TIMEOUT,
        NOT_RUNNING: NOT_RUNNING,
        UNKNOWN: UNKNOWN,
        EMERGENCY_SHUTDOWN: EMERGENCY_SHUTDOWN
    });

    serviceHealthModule.factory("$serviceHealth", ["$translate", function ($translate) {

        var statuses = {};

        // updates health check data for all services
        function update(serviceList) {

            var serviceStatus, instanceStatus, instanceUniqueId, service;

            statuses = {};

            // iterate services healthchecks
            for (var serviceId in serviceList) {
                service = serviceList[serviceId];
                serviceStatus = new Status(serviceId, service.name, service.desiredState, service.emergencyShutdown);

                // refresh list of instances
                // TODO - this "if" is a workaround for old servicesFactory
                // services and should be removed along with servicesFactory
                if (service.fetchInstances) {
                    service.fetchInstances();
                }

                // if this service has instances, evaluate their health
                service.instances.forEach(function (instance) {

                    // create a new status rollup for this instance
                    instanceUniqueId = serviceId + "." + instance.model.InstanceID;
                    instanceStatus = new Status(instanceUniqueId, service.name + " " + instance.model.InstanceID, service.desiredState, service.emergencyShutdown);

                    // evalute instance healthchecks and roll em up
                    instanceStatus.evaluateHealthChecks(instance.healthChecks);
                    // store resulting status on instance
                    instance.status = instanceStatus;

                    // add this guy's statuses to hash map for easy lookup
                    statuses[instanceUniqueId] = instanceStatus;
                    // add this guy's status to his parent
                    serviceStatus.children.push(instanceStatus);
                });

                // now that this services instances have been evaluated,
                // evaluate the status of this service
                serviceStatus.evaluateChildren();

                statuses[serviceId] = serviceStatus;
            }

            return statuses;
        }

        function evaluate(service, instances) {

            instances = instances || [];

            var status = void 0;

            status = new Status(service.id, service.name, service.desiredState, service.emergencyShutdown);

            // if instances were provided, evaluate their health
            instances.forEach(function (instance) {
                var instanceUniqueId = service.id + "." + instance.model.InstanceID;
                var instanceStatus = new Status(instanceUniqueId, service.name + " " + instance.model.InstanceID, service.desiredState, service.emergencyShutdown);

                // evalute instance healthchecks and roll em up
                instanceStatus.evaluateHealthChecks(instance.healthChecks);
                // store resulting status on instance
                instance.status = instanceStatus;

                // add this guy's status to his parent
                status.children.push(instanceStatus);
            });

            // now that this services instances have been evaluated,
            // evaluate the status of this service
            status.evaluateChildren();

            return status;
        }

        // used by Status to examine children and figure
        // out what the parent's status is
        function StatusRollup() {
            this[OK] = 0;
            this[FAILED] = 0;
            this[NOT_RUNNING] = 0;
            this[UNKNOWN] = 0;
            this.total = 0;
        }
        StatusRollup.prototype = {
            constructor: StatusRollup,

            incOK: function incOK() {
                this.incStatus(OK);
            },
            incFailed: function incFailed() {
                this.incStatus(FAILED);
            },
            incNotRunning: function incNotRunning() {
                this.incStatus(NOT_RUNNING);
            },
            incUnknown: function incUnknown() {
                this.incStatus(UNKNOWN);
            },
            incStatus: function incStatus(status) {
                if (this[status] !== undefined) {
                    this[status]++;
                    this.total++;
                }
            },

            // TODO - use assertion style ie: status.is.ok() or status.any.ok()
            anyFailed: function anyFailed() {
                return !!this[FAILED];
            },
            allFailed: function allFailed() {
                return this.total && this[FAILED] === this.total;
            },
            anyOK: function anyOK() {
                return !!this[OK];
            },
            allOK: function allOK() {
                return this.total && this[OK] === this.total;
            },
            anyNotRunning: function anyNotRunning() {
                return !!this[NOT_RUNNING];
            },
            allNotRunning: function allNotRunning() {
                return this[NOT_RUNNING] === this.total;
            },
            anyUnknown: function anyUnknown() {
                return !!this[UNKNOWN];
            },
            allUnknown: function allUnknown() {
                return this.total && this[UNKNOWN] === this.total;
            }
        };

        function Status(id, name, desiredState, emergencyShutdown) {
            this.id = id;
            this.name = name;
            this.desiredState = desiredState;
            this.emergencyShutdown = emergencyShutdown;

            this.statusRollup = new StatusRollup();
            this.children = [];

            this.status = null;
            this.description = null;
        }

        Status.prototype = {
            constructor: Status,

            // distill this service's statusRollup into a single value
            evaluateStatus: function evaluateStatus() {
                // stuff is shutdown and emergency shutdown is flagged
                if (this.emergencyShutdown) {
                    this.status = EMERGENCY_SHUTDOWN;
                    this.description = $translate.instant("emergency_shutdown");
                    // if all are ok, up
                } else if (this.statusRollup.allOK()) {
                    this.status = OK;
                    this.description = $translate.instant("passing_health_checks");
                    // if all are failed, fail
                } else if (this.statusRollup.allFailed()) {
                    this.status = FAILED;
                    this.description = $translate.instant("failed");
                    // if all are stopped, stopped
                } else if (this.statusRollup.allNotRunning()) {
                    this.status = NOT_RUNNING;
                    this.description = $translate.instant("container_down");
                    // else some running up some stopped
                } else {
                    this.status = UNKNOWN;
                    this.description = $translate.instant("missing_health_checks");
                }
            },

            // roll up child status into this status
            evaluateChildren: function evaluateChildren() {
                this.statusRollup = this.children.reduce(function (acc, childStatus) {
                    acc.incStatus(childStatus.status);
                    return acc;
                }.bind(this), new StatusRollup());
                this.evaluateStatus();
            },

            // set this status's statusRollup based on healthchecks
            // NOTE - subtly different than evaluateChildren
            evaluateHealthChecks: function evaluateHealthChecks(healthChecks) {
                for (var name in healthChecks) {
                    this.statusRollup.incStatus(healthChecks[name]);
                    this.children.push({
                        name: name,
                        status: healthChecks[name]
                    });
                }
                this.evaluateStatus();
            }

        };

        return {
            update: update,
            evaluate: evaluate,
            get: function get(id) {
                var status = statuses[id];

                // if no status found, return unknown
                if (!status) {
                    status = new Status(id, UNKNOWN, 0, false);
                    status.evaluateStatus();
                }

                return status;
            }
        };
    }]);
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

(function () {
    'use strict';

    // share angular services outside of angular context

    var utils = void 0;

    controlplane.factory('Host', HostFactory);

    var Host = function () {
        function Host(host) {
            _classCallCheck(this, Host);

            this.name = host.Name;
            this.id = host.ID;
            this.model = Object.freeze(host);

            this._status = {
                Active: false,
                Authenticated: false,
                MemoryUsage: { Cur: 0, Max: 0, Avg: 0 }
            };

            this.touch();
        }

        _createClass(Host, [{
            key: 'touch',
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: 'resourcesGood',
            value: function resourcesGood() {
                return this.RAMAverage <= this.RAMLimitBytes;
            }
        }, {
            key: 'RAMIsPercent',
            value: function RAMIsPercent() {
                return this.RAMLimit.endsWith("%");
            }
        }, {
            key: 'status',
            get: function get() {
                return this._status;
            },
            set: function set(value) {
                this._status = value;
                this.touch();
            }
        }, {
            key: 'RAMLimit',
            get: function get() {
                if (!this.model) {
                    return undefined;
                }

                return this.model.RAMLimit || "100%";
            }
        }, {
            key: 'RAMLimitBytes',
            get: function get() {
                if (this.RAMIsPercent()) {
                    return +this.RAMLimit.slice(0, -1) * this.model.Memory * 0.01;
                } else {
                    return utils.parseEngineeringNotation(this.RAMLimit);
                }
            }
        }, {
            key: 'RAMLast',
            get: function get() {
                return this._status.MemoryUsage.Cur || 0;
            }
        }, {
            key: 'RAMMax',
            get: function get() {
                return this._status.MemoryUsage.Max || 0;
            }
        }, {
            key: 'RAMAverage',
            get: function get() {
                return this._status.MemoryUsage.Avg || 0;
            }
        }]);

        return Host;
    }();

    HostFactory.$inject = ['miscUtils'];
    function HostFactory(_utils) {
        utils = _utils;
        return Host;
    }
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* HostDetailsController
 * Displays list of hosts
 */
(function () {
    'use strict';

    var params = void 0,
        $location = void 0,
        resourcesFactory = void 0,
        authService = void 0,
        $modalService = void 0,
        $translate = void 0,
        $notification = void 0,
        $interval = void 0,
        servicedConfig = void 0,
        log = void 0,
        utils = void 0,
        Host = void 0,
        Instance = void 0,
        $q = void 0;

    var HostDetailsController = function () {
        function HostDetailsController($scope) {
            var _this = this;

            _classCallCheck(this, HostDetailsController);

            authService.checkLogin(this);

            this.name = "hostdetails";

            $scope.breadcrumbs = [{ label: 'breadcrumb_hosts', url: '/hosts' }];

            this.hostInstances = [];

            this.touch();
            this.touchInstances();

            $scope.ipsTable = {
                sorting: {
                    InterfaceName: "asc"
                },
                watchExpression: function watchExpression() {
                    return _this.lastUpdate;
                },
                searchColumns: ['InterfaceName', 'IPAddress', 'MACAddress']
            };

            $scope.instancesTable = {
                sorting: {
                    name: "asc"
                },
                watchExpression: function watchExpression() {
                    return _this.lastInstanceUpdate;
                },
                searchColumns: ['model.ServiceName']
            };

            this.refreshHost().then(this.refresh()).then(function () {
                $scope.breadcrumbs.push({
                    label: _this.currentHost.name,
                    itemClass: 'active' });

                $scope.$emit("ready");
            });

            this.updateFrequency = 3000;
            servicedConfig.getConfig().then(function (config) {
                _this.updateFrequency = config.PollFrequency * 1000;
            }).catch(function (err) {
                var errMessage = err.data ? err.data.Detail : err.statusText;
                log.error("could not load serviced config:", errMessage);
            });

            this.startPolling();

            $scope.$on("$destroy", function () {
                return _this.stopPolling();
            });

            // New scopes are created to use as models for the modals dialogs.
            // They require some additional methods that are on the global
            // scope.  Since we want to keep $scope limited to just the constructor,
            // this method can be used to create new scopes for modals.
            this.newScope = function () {
                return $scope.$new(true);
            };

            // This method will be called by a directive, so when it is executed
            // 'this' will be the directive and not the contoller.  To solve this we can
            // bind 'this' to the controller.
            this.getHostStatus = this.getHostStatus.bind(this);
        }

        _createClass(HostDetailsController, [{
            key: 'touch',
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: 'touchInstances',
            value: function touchInstances() {
                this.lastInstanceUpdate = new Date().getTime();
            }
        }, {
            key: 'refreshHost',
            value: function refreshHost() {
                var _this2 = this;

                return resourcesFactory.getHost(params.hostId).then(function (data) {
                    _this2.currentHost = new Host(data);
                    _this2.touch();
                });
            }
        }, {
            key: 'refreshInstances',
            value: function refreshInstances() {
                var _this3 = this;

                return resourcesFactory.v2.getHostInstances(params.hostId).then(function (data) {
                    _this3.hostInstances = data.map(function (i) {
                        return new Instance(i);
                    });
                    _this3.touchInstances();
                });
            }
        }, {
            key: 'refreshHostStatus',
            value: function refreshHostStatus() {
                var _this4 = this;

                var id = params.hostId;
                return resourcesFactory.v2.getHostStatuses([id]).then(function (data) {
                    var statusHash = data.reduce(function (hash, status) {
                        hash[status.HostID] = status;return hash;
                    }, {});

                    if (id in statusHash) {
                        _this4.currentHost.status = statusHash[id];
                    }
                });
            }
        }, {
            key: 'refresh',
            value: function refresh() {
                return $q.all([this.refreshInstances(), this.refreshHostStatus()]);
            }
        }, {
            key: 'getHostStatus',
            value: function getHostStatus() {
                return this.currentHost.status;
            }
        }, {
            key: 'startPolling',
            value: function startPolling() {
                var _this5 = this;

                if (!this.updatePromise) {
                    this.updatePromise = $interval(function () {
                        return _this5.refresh();
                    }, this.updateFrequency);
                }
            }
        }, {
            key: 'stopPolling',
            value: function stopPolling() {
                if (this.updatePromise) {
                    $interval.cancel(this.updatePromise);
                    this.updatePromise = null;
                }
            }
        }, {
            key: 'viewLog',
            value: function viewLog(instance) {
                var _this7 = this;

                var modalScope = this.newScope();
                modalScope.editService = angular.copy(instance);

                resourcesFactory.getInstanceLogs(instance.model.ServiceID, instance.id).success(function (log) {
                    modalScope.log = log.Detail;
                    $modalService.create({
                        templateUrl: "view-log.html",
                        model: modalScope,
                        title: "title_log",
                        bigModal: true,
                        actions: [{
                            role: "cancel",
                            label: "close"
                        }, {
                            classes: "btn-primary",
                            label: "refresh",
                            icon: "glyphicon-repeat",
                            action: function action() {
                                var _this6 = this;

                                var textarea = this.$el.find("textarea");
                                resourcesFactory.getInstanceLogs(instance.model.ServiceID, instance.id).success(function (log) {
                                    modalScope.log = log.Detail;
                                    textarea.scrollTop(textarea[0].scrollHeight - textarea.height());
                                }).error(function (data, status) {
                                    _this6.createNotification("Unable to fetch logs", data.Detail).error();
                                });
                            }
                        }, {
                            classes: "btn-primary",
                            label: "download",
                            action: function action() {
                                utils.downloadFile('/services/' + instance.model.ServiceID + '/' + instance.id + '/logs/download');
                            },
                            icon: "glyphicon-download"
                        }],
                        onShow: function onShow() {
                            var textarea = this.$el.find("textarea");
                            textarea.scrollTop(textarea[0].scrollHeight - textarea.height());
                        }
                    });
                }).error(function (data, status) {
                    _this7.createNotification("Unable to fetch logs", data.Detail).error();
                });
            }
        }, {
            key: 'click_app',
            value: function click_app(instance) {
                $location.path('/services/' + instance.model.ServiceID);
            }
        }, {
            key: 'editCurrentHost',
            value: function editCurrentHost() {
                var _this8 = this;

                var modalScope = this.newScope();
                modalScope.refreshHost = function () {
                    return _this8.refreshHost();
                };
                modalScope.currentHost = this.currentHost;

                modalScope.editableHost = {
                    Name: this.currentHost.name,
                    RAMLimit: this.currentHost.RAMLimit
                };

                $modalService.create({
                    templateUrl: "edit-host.html",
                    model: modalScope,
                    title: "title_edit_host",
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        label: "btn_save_changes",
                        action: function action() {
                            var hostModel = angular.copy(modalScope.currentHost.model);
                            angular.extend(hostModel, modalScope.editableHost);

                            if (this.validate()) {
                                // disable ok button, and store the re-enable function
                                var enableSubmit = this.disableSubmitButton();

                                // update host with recently edited host
                                resourcesFactory.updateHost(modalScope.currentHost.id, hostModel).success(function (data, status) {
                                    $notification.create("Updated host", hostModel.Name).success();
                                    modalScope.refreshHost();
                                    this.close();
                                }.bind(this)).error(function (data, status) {
                                    this.createNotification("Update host failed", data.Detail).error();
                                    enableSubmit();
                                }.bind(this));
                            }
                        }
                    }],
                    validate: function validate() {
                        var err = utils.validateRAMLimit(modalScope.editableHost.RAMLimit, modalScope.currentHost.model.Memory);
                        if (err) {
                            this.createNotification("Error", err).error();
                            return false;
                        }
                        return true;
                    }
                });
            }
        }, {
            key: 'resetKeys',
            value: function resetKeys() {
                this.modal_confirmResetKeys();
            }
        }, {
            key: 'modal_confirmResetKeys',
            value: function modal_confirmResetKeys() {
                var scope = this.newScope();
                scope.host = this.currentHost;

                $modalService.create({
                    template: $translate.instant("reset_host_keys", { name: this.currentHost.name }),
                    model: scope,
                    title: $translate.instant("title_reset_host_keys"),
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        classes: "submit btn-primary",
                        label: $translate.instant("btn_reset_keys"),
                        action: function action() {
                            var _this9 = this;

                            // disable ok button, and store the re-enable function
                            var enableSubmit = this.disableSubmitButton();

                            resourcesFactory.resetHostKeys(scope.host.id).success(function (data, status) {
                                $modalService.modals.displayHostKeys(data.PrivateKey, data.Registered, scope.host.name);
                            }).error(function (data, status) {
                                // TODO - form error highlighting
                                _this9.createNotification("", data.Detail).error();
                                // reenable button
                                enableSubmit();
                            });
                        }
                    }]
                });
            }
        }, {
            key: 'restart',
            value: function restart(hostId, instanceId) {
                resourcesFactory.killRunning(hostId, instanceId).then(this.refresh());
            }
        }]);

        return HostDetailsController;
    }();

    controlplane.controller("HostDetailsController", ["$scope", "$routeParams", "$location", "resourcesFactory", "authService", "$modalService", "$translate", "$notification", "$interval", "servicedConfig", "log", "miscUtils", "Host", "Instance", "$q", function ($scope, _$routeParams, _$location, _resourcesFactory, _authService, _$modalService, _$translate, _$notification, _$interval, _servicedConfig, _log, _miscUtils, _Host, _Instance, _$q) {

        params = _$routeParams;
        $location = _$location;
        resourcesFactory = _resourcesFactory;
        authService = _authService;
        $modalService = _$modalService;
        $translate = _$translate;
        $notification = _$notification;
        $interval = _$interval;
        servicedConfig = _servicedConfig;
        utils = _miscUtils;
        Host = _Host;
        Instance = _Instance;
        $q = _$q;
        log = _log;

        return new HostDetailsController($scope);
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* HostsController
 * Displays details for a specific host
 */
(function () {
    "use strict";

    var resourcesFactory = void 0,
        authService = void 0,
        $modalService = void 0,
        $translate = void 0,
        $notification = void 0,
        areUIReady = void 0,
        $interval = void 0,
        servicedConfig = void 0,
        utils = void 0,
        Host = void 0,
        log = void 0,
        Pool = void 0;

    var HostsController = function () {
        function HostsController($scope) {
            var _this = this;

            _classCallCheck(this, HostsController);

            authService.checkLogin(this);

            this.touch();

            this.pools = [];

            this.name = "hosts";
            this.indent = utils.indentClass;
            this.hostsInView = [];

            this.updateFrequency = 3000;
            servicedConfig.getConfig().then(function (config) {
                _this.updateFrequency = config.PollFrequency * 1000;
            }).catch(function (err) {
                var errMessage = err.data ? err.data.Detail : err.statusText;
                log.error("could not load serviced config:", errMessage);
            });

            $scope.breadcrumbs = [{ label: 'breadcrumb_hosts', itemClass: 'active' }];

            $scope.hostsTable = {
                sorting: {
                    name: "asc"
                },
                watchExpression: function watchExpression() {
                    return _this.lastUpdate;
                },
                searchColumns: ['name', 'model.PoolID', 'model.Cores', 'model.KernelVersion']
            };

            $scope.dropped = [];

            this.refreshHosts().then(function () {
                $scope.$emit("ready");
            }, function (error) {
                return $notification.create("Unable to load hosts.", error.Detail).error();
            });

            this.refreshPoolIds();

            this.startPolling();

            $scope.$on("$destroy", function () {
                _this.stopPolling();
            });

            // These methods will be called by directives, so when they are executed
            // 'this' will be the directive and not the contoller.  To solve this we can
            // bind 'this' to the controller.
            this.updateHostsInView = this.updateHostsInView.bind(this);
            this.getHostStatus = this.getHostStatus.bind(this);

            // New scopes are created to use as models for the modals dialogs.
            // They require some additional methods that are on the global
            // scope.  Since we want to keep $scope limited to just the constructor,
            // this method can be used to create new scopes for modals.
            this.newScope = function () {
                return $scope.$new(true);
            };
        }

        _createClass(HostsController, [{
            key: "touch",
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: "refreshHosts",
            value: function refreshHosts() {
                var _this2 = this;

                return resourcesFactory.v2.getHosts().then(function (data) {
                    _this2.hosts = data.map(function (result) {
                        return new Host(result);
                    });
                    _this2.touch();
                });
            }
        }, {
            key: "refreshPoolIds",
            value: function refreshPoolIds() {
                var _this3 = this;

                resourcesFactory.v2.getPools().success(function (data) {
                    _this3.pools = data.map(function (result) {
                        return new Pool(result);
                    }).sort(function (first, second) {
                        return first.id.localeCompare(second.id);
                    });
                }).error(function (data) {
                    $notification.create("Unable to load pools.", data.Detail).error();
                });
            }
        }, {
            key: "refreshHostStatuses",
            value: function refreshHostStatuses() {
                var _this4 = this;

                if (!this.hostsInView || this.hostsInView.length < 1) {
                    return;
                }

                var ids = this.hostsInView.map(function (h) {
                    return h.id;
                });
                return resourcesFactory.v2.getHostStatuses(ids).then(function (data) {
                    var statusHash = data.reduce(function (hash, status) {
                        hash[status.HostID] = status;return hash;
                    }, {});

                    _this4.hosts.forEach(function (h) {
                        if (h.id in statusHash) {
                            h.status = statusHash[h.id];
                        }
                    });
                });
            }
        }, {
            key: "startPolling",
            value: function startPolling() {
                var _this5 = this;

                if (!this.updatePromise) {
                    this.updatePromise = $interval(function () {
                        return _this5.refreshHostStatuses();
                    }, this.updateFrequency);
                }
            }
        }, {
            key: "stopPolling",
            value: function stopPolling() {
                if (this.updatePromise) {
                    $interval.cancel(this.updatePromise);
                    this.updatePromise = null;
                }
            }
        }, {
            key: "clickAddHost",
            value: function clickAddHost() {
                var _this6 = this;

                var modalScope = this.newScope();

                // Acceptance timing fix.
                modalScope.SetDirect = function () {
                    modalScope.newHost.UseNat = false;
                };
                modalScope.SetNat = function () {
                    modalScope.newHost.UseNat = true;
                };

                modalScope.refreshHosts = function () {
                    return _this6.refreshHosts();
                };
                modalScope.poolIds = this.pools.map(function (p) {
                    return p.id;
                });

                modalScope.newHost = {
                    AddType: "direct",
                    port: $translate.instant('placeholder_port'),
                    PoolID: modalScope.poolIds[0] || ""
                };

                areUIReady.lock();
                $modalService.create({
                    templateUrl: "add-host.html",
                    model: modalScope,
                    title: "add_host",
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        label: "btn_next",
                        icon: "glyphicon-chevron-right",
                        action: function action() {
                            if (this.validate()) {
                                // disable ok button, and store the re-enable function
                                var enableSubmit = this.disableSubmitButton();
                                if (modalScope.newHost.RAMLimit === undefined || modalScope.newHost.RAMLimit === '') {
                                    modalScope.newHost.RAMLimit = "100%";
                                }

                                modalScope.newHost.IPAddr = modalScope.newHost.host + ':' + modalScope.newHost.port;
                                if (modalScope.newHost.UseNat) {
                                    modalScope.newHost.NatAddr = modalScope.newHost.natHost + ':' + modalScope.newHost.natPort;
                                } else {
                                    modalScope.newHost.natHost = "";
                                    modalScope.newHost.natPort = "";
                                    modalScope.newHost.NatAddr = ":0";
                                }

                                resourcesFactory.addHost(modalScope.newHost).success(function (data, status) {
                                    $modalService.modals.displayHostKeys(data.PrivateKey, data.Registered, modalScope.newHost.host);
                                    modalScope.refreshHosts();
                                }.bind(this)).error(function (data, status) {
                                    // TODO - form error highlighting
                                    this.createNotification("", data.Detail).error();
                                    // reenable button
                                    enableSubmit();
                                }.bind(this));
                            }
                        }
                    }],
                    validate: function validate() {
                        var err = utils.validateHostName(modalScope.newHost.host, $translate) || utils.validatePortNumber(modalScope.newHost.port, $translate) || utils.validateRAMLimit(modalScope.newHost.RAMLimit);
                        if (modalScope.newHost.UseNat) {
                            err = err || utils.validateHostName(modalScope.newHost.natHost, $translate) || utils.validatePortNumber(modalScope.newHost.natPort, $translate);
                        }
                        if (err) {
                            this.createNotification("Error", err).error();
                            return false;
                        }
                        return true;
                    },
                    onShow: function onShow() {
                        return areUIReady.unlock();
                    }
                });
            }
        }, {
            key: "clickRemoveHost",
            value: function clickRemoveHost(id) {
                var _this7 = this;

                var modalScope = this.newScope();
                modalScope.refreshHosts = function () {
                    return _this7.refreshHosts();
                };

                var hostToRemove = this.hosts.find(function (h) {
                    return h.id === id;
                });
                $modalService.create({
                    template: $translate.instant("confirm_remove_host") + " <strong>" + hostToRemove.name + "</strong>",
                    model: modalScope,
                    title: "remove_host",
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        label: "remove_host",
                        classes: "btn-danger",
                        action: function action() {
                            resourcesFactory.removeHost(id).success(function (data, status) {
                                $notification.create("Removed host", id).success();
                                modalScope.refreshHosts();
                                this.close();
                            }.bind(this)).error(function (data, status) {
                                $notification.create("Removing host failed", data.Detail).error();
                                this.close();
                            }.bind(this));
                        }
                    }]
                });
            }
        }, {
            key: "clickHost",
            value: function clickHost(id) {
                resourcesFactory.routeToHost(id);
            }
        }, {
            key: "clickPool",
            value: function clickPool(id) {
                resourcesFactory.routeToPool(id);
            }
        }, {
            key: "getHostStatus",
            value: function getHostStatus(id) {
                var index = this.hostsInView.findIndex(function (h) {
                    return h.id === id;
                });
                if (index > -1) {
                    return this.hostsInView[index].status;
                }
            }
        }, {
            key: "updateHostsInView",
            value: function updateHostsInView(data) {
                this.hostsInView = data;
                this.refreshHostStatuses();
            }
        }]);

        return HostsController;
    }();

    controlplane.controller("HostsController", ["$scope", "resourcesFactory", "authService", "$modalService", "$translate", "$notification", "areUIReady", "$interval", "servicedConfig", "log", "miscUtils", "Host", "Pool", function ($scope, _resourcesFactory, _authService, _$modalService, _$translate, _$notification, _areUIReady, _$interval, _servicedConfig, _log, _miscUtils, _Host, _Pool) {

        resourcesFactory = _resourcesFactory;
        authService = _authService;
        $modalService = _$modalService;
        $translate = _$translate;
        $notification = _$notification;
        areUIReady = _areUIReady;
        $interval = _$interval;
        servicedConfig = _servicedConfig;
        utils = _miscUtils;
        Host = _Host;
        log = _log;
        Pool = _Pool;

        return new HostsController($scope);
    }]);
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* hostIconDirective
 * directive for displaying status of a host
 */
(function () {
    'use strict';

    angular.module('hostIcon', []).directive('hostIcon', [function () {
        var template = '\n            <div ng-class="vm.getHostStatusClass()" style="position: relative; height: 22px;">\n                <i class="healthIcon glyphicon"></i>\n            </div>';

        var popoverContentTemplate = function popoverContentTemplate(m) {
            return '\n                <div class=\'healthTooltipDetailRow ' + m.getHostActiveStatusClass() + '\'>\n                    <i class=\'healthIcon glyphicon\'></i>\n                    <div class=\'healthTooltipDetailName\'>Active</div>\n                </div>\n                <div class=\'healthTooltipDetailRow ' + m.getHostAuthStatusClass() + '\'>\n                    <i class=\'healthIcon glyphicon\'></i>\n                    <div class=\'healthTooltipDetailName\'>Authenticated</div>\n                </div>\n            ';
        };

        var Controller = function () {
            function Controller() {
                // hi.

                _classCallCheck(this, Controller);
            }

            _createClass(Controller, [{
                key: '_getHostStatus',
                value: function _getHostStatus() {
                    if (!this.host) {
                        return { active: null, authed: null };
                    }

                    var status = this.getHostStatus(this.host.id);

                    if (!status) {
                        return { active: null, authed: null };
                    }

                    var active = status.Active,
                        authed = status.Authenticated;

                    return { active: active, authed: authed };
                }
            }, {
                key: 'getHostStatusClass',
                value: function getHostStatusClass() {
                    var _getHostStatus2 = this._getHostStatus(),
                        active = _getHostStatus2.active,
                        authed = _getHostStatus2.authed;
                    // connected and authenticated


                    if (active && authed) {
                        return "passed";
                    }
                    // connected but not authenticated is fail
                    return active ? "failed" : "not_running";
                }
            }, {
                key: 'getHostActiveStatusClass',
                value: function getHostActiveStatusClass() {
                    var _getHostStatus3 = this._getHostStatus(),
                        active = _getHostStatus3.active;

                    return active ? "passed" : "not_running";
                }
            }, {
                key: 'getHostAuthStatusClass',
                value: function getHostAuthStatusClass() {
                    var _getHostStatus4 = this._getHostStatus(),
                        active = _getHostStatus4.active,
                        authed = _getHostStatus4.authed;

                    if (active && authed) {
                        return "passed";
                    }
                    // connected but not authenticated is fail
                    return active ? "failed" : "not_running";
                }
            }, {
                key: 'updatePopover',
                value: function updatePopover() {
                    var p = this.popover;
                    p.options.content = popoverContentTemplate(this);
                    p.setContent();

                    // if the popover is currently visible, update
                    // it immediately, but turn off animation to
                    // prevent it fading in
                    if (p.$tip.is(":visible")) {
                        p.options.animation = false;
                        p.show();
                        p.options.animation = true;
                    }
                }
            }]);

            return Controller;
        }();

        return {
            restrict: "EA",
            scope: {
                host: "=",
                getHostStatus: "="
            },
            controller: Controller,
            controllerAs: "vm",
            bindToController: true,
            template: template,
            link: function link(scope, element, attrs) {
                var $icon = $(element).find(".healthIcon");
                $icon.popover({
                    trigger: "hover",
                    placement: "right",
                    delay: 0,
                    html: true
                });
                // NOTE: directly accessing the bootstrap popover
                // data object here.
                scope.vm.popover = $icon.data("bs.popover");
                scope.vm.updatePopover();

                // use a bitfield to describe host state as a
                // single value to determine if we need to
                // update the view
                var ACTIVE = 1 << 1,
                    AUTHED = 1 << 2;

                scope.$watch(function () {
                    var _scope$vm$_getHostSta = scope.vm._getHostStatus(),
                        active = _scope$vm$_getHostSta.active,
                        authed = _scope$vm$_getHostSta.authed,
                        val = 0;

                    // no results have come back yet


                    if (active === null && authed === null) {
                        return -1;
                    }

                    // results, so lets smoosh em
                    // into a single value
                    if (active) {
                        val = val ^ ACTIVE;
                    }
                    if (authed) {
                        val = val ^ AUTHED;
                    }

                    return val;
                }, function (newVal, oldVal) {
                    scope.vm.updatePopover();
                });
            }
        };
    }]);
})();
'use strict';

// hostssFactory
// - maintains a list of hosts and keeps it in sync with the backend.
(function () {
    'use strict';

    // make angular share with everybody!

    var resourcesFactory, $q, instancesFactory, utils;

    angular.module('hostsFactory', []).factory("hostsFactory", ["$rootScope", "$q", "resourcesFactory", "$interval", "instancesFactory", "baseFactory", "miscUtils", function ($rootScope, q, _resourcesFactory, $interval, _instancesFactory, BaseFactory, _utils) {
        // share resourcesFactory throughout
        resourcesFactory = _resourcesFactory;
        instancesFactory = _instancesFactory;
        $q = q;
        utils = _utils;

        var newFactory = new BaseFactory(Host, resourcesFactory.getHosts);

        // alias some stuff for ease of use
        newFactory.hostList = newFactory.objArr;
        newFactory.hostMap = newFactory.objMap;

        // wrap update to do some extra work
        newFactory.update = utils.after(newFactory.update, function () {
            var _this = this;

            // check running hosts and mark them as active
            resourcesFactory.getRunningHosts().success(function (activeHosts, status) {
                _this.hostList.forEach(function (host) {
                    if (activeHosts.indexOf(host.id) !== -1) {
                        host.active = true;
                    } else {
                        host.active = false;
                    }
                });
            });
        }, newFactory);

        return newFactory;
    }]);

    // Host object constructor
    // takes a host object (backend host object)
    // and wraps it with extra functionality and info
    function Host(host) {
        this.active = false;
        this.update(host);
    }

    Host.prototype = {
        constructor: Host,

        update: function update(host) {
            if (host) {
                this.updateHostDef(host);
            }
        },

        updateHostDef: function updateHostDef(host) {
            this.name = host.Name;
            this.id = host.ID;
            this.model = Object.freeze(host);
        },

        resourcesGood: function resourcesGood() {
            return this.RAMAverage <= this.RAMLimitBytes;
        },

        RAMIsPercent: function RAMIsPercent() {
            return this.RAMLimit.endsWith("%");
        }
    };

    Object.defineProperty(Host.prototype, "instances", {
        get: function get() {
            return instancesFactory.getByHostId(this.id);
        }
    });

    // RAMLimit may not be set yet, so use RAMCommitment
    // NOTE: RAMCommitment is deprecated
    Object.defineProperty(Host.prototype, "RAMLimit", {
        get: function get() {
            if (!this.model) {
                return undefined;
            }

            if (this.model.RAMLimit) {
                return this.model.RAMLimit;
            } else {
                // RAMCommitment of 0 means 100% commitment
                return this.model.RAMCommitment || "100%";
            }
        }
    });

    // get the RAMLimit in bytes
    Object.defineProperty(Host.prototype, "RAMLimitBytes", {
        get: function get() {
            // if percentange
            if (this.RAMIsPercent()) {
                return +this.RAMLimit.slice(0, -1) * this.model.Memory * 0.01;
                // if stringy value
            } else {
                return utils.parseEngineeringNotation(this.RAMLimit);
            }
        }
    });

    Object.defineProperty(Host.prototype, "RAMLast", {
        get: function get() {
            var instances = this.instances;
            var sum = 0;
            for (var i = 0; i < instances.length; i++) {
                sum += instances[i].resources.RAMLast;
            }
            return sum;
        }
    });

    Object.defineProperty(Host.prototype, "RAMMax", {
        get: function get() {
            var instances = this.instances;
            var sum = 0;
            for (var i = 0; i < instances.length; i++) {
                sum += instances[i].resources.RAMMax;
            }
            return sum;
        }
    });

    Object.defineProperty(Host.prototype, "RAMAverage", {
        get: function get() {
            var instances = this.instances;
            var sum = 0;
            for (var i = 0; i < instances.length; i++) {
                sum += instances[i].resources.RAMAverage;
            }
            return sum;
        }
    });
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

(function () {
    'use strict';

    // share angular services outside of angular context

    var utils = void 0;

    controlplane.factory('Instance', InstanceFactory);

    function buildStateId(hostid, serviceid, instanceid) {
        return hostid + '-' + serviceid + '-' + instanceid;
    }

    var Instance = function () {
        function Instance(data) {
            _classCallCheck(this, Instance);

            this.update(data);
        }

        _createClass(Instance, [{
            key: 'update',
            value: function update(data) {
                this.model = Object.freeze(data);
                this.id = buildStateId(this.model.HostID, this.model.ServiceID, this.model.InstanceID);
                this.resources = {
                    RAMCommitment: utils.parseEngineeringNotation(data.RAMCommitment)
                };
                // the instance model data comes in with health and
                // memory stats, so use that to do an initial instace
                // status update
                this.updateState({
                    HealthStatus: data.HealthStatus,
                    MemoryUsage: data.MemoryUsage
                });
            }
        }, {
            key: 'resourcesGood',
            value: function resourcesGood() {
                return this.resources.RAMLast < this.resources.RAMCommitment;
            }

            // update fast-moving instance state

        }, {
            key: 'updateState',
            value: function updateState(status) {
                this.resources.RAMAverage = Math.max(0, status.MemoryUsage.Avg);
                this.resources.RAMLast = Math.max(0, status.MemoryUsage.Cur);
                this.resources.RAMMax = Math.max(0, status.MemoryUsage.Max);
                this.healthChecks = status.HealthStatus;
            }
        }]);

        return Instance;
    }();

    InstanceFactory.$inject = ['miscUtils'];

    function InstanceFactory(_utils) {

        // api access via angular context
        utils = _utils;

        return Instance;
    }
})();
'use strict';

// instancesFactory
// - maintains a list of instances and keeps it in sync with the backend.
(function () {
    'use strict';

    var resourcesFactory, $q, $notification, utils;

    angular.module('instancesFactory', []).factory("instancesFactory", ["$rootScope", "$q", "resourcesFactory", "$interval", "baseFactory", "$notification", "miscUtils", function ($rootScope, q, _resourcesFactory, $interval, BaseFactory, _notification, _utils) {

        // share resourcesFactory throughout
        resourcesFactory = _resourcesFactory;
        $q = q;
        $notification = _notification;
        utils = _utils;

        var newFactory = new BaseFactory(Instance, resourcesFactory.getServiceInstances);

        // alias some stuff for ease of use
        newFactory.instanceArr = newFactory.objArr;
        newFactory.instanceMap = newFactory.objMap;

        angular.extend(newFactory, {
            getByServiceId: function getByServiceId(id) {
                var results = [];
                for (var i in this.instanceMap) {
                    if (this.instanceMap[i].model.ServiceID === id) {
                        results.push(this.instanceMap[i]);
                    }
                }
                return results;
            },

            getByHostId: function getByHostId(id) {
                var results = [];
                for (var i in this.instanceMap) {
                    if (this.instanceMap[i].model.HostID === id) {
                        results.push(this.instanceMap[i]);
                    }
                }
                return results;
            }
        });

        newFactory.update = utils.after(newFactory.update, function () {
            // call update on all children
            newFactory.instanceArr.forEach(function (instance) {
                return instance.update();
            });
        }, newFactory);

        return newFactory;
    }]);

    // Instance object constructor
    // takes a instance object (backend instance object)
    // and wraps it with extra functionality and info
    function Instance(instance) {
        this.active = false;

        this.resources = {
            RAMCommitment: 0,
            RAMLast: 0,
            RAMMax: 0,
            RAMAverage: 0
        };

        this.healthChecks = {};
        this.update(instance);
    }

    Instance.prototype = {
        constructor: Instance,

        update: function update(instance) {
            if (instance) {
                this.updateInstanceDef(instance);
            }
        },

        updateInstanceDef: function updateInstanceDef(instance) {
            this.name = instance.Name;
            this.id = instance.ID;
            this.model = Object.freeze(instance);
            this.resources.RAMAverage = Math.max(0, instance.RAMAverage);
            this.resources.RAMLast = Math.max(0, instance.RAMLast);
            this.resources.RAMMax = Math.max(0, instance.RAMMax);
            this.resources.RAMCommitment = utils.parseEngineeringNotation(instance.RAMCommitment);

            var hc = {};
            for (var name in instance.HealthChecks) {
                hc[name] = instance.HealthChecks[name].Status;
            }
            this.healthChecks = hc;
        },

        stop: function stop() {
            var _this = this;

            resourcesFactory.killRunning(this.model.HostID, this.id).success(function () {
                _this.update();
            }).error(function (data, status) {
                $notification.create("Stop Instance failed", data.Detail).error();
            });
        },

        resourcesGood: function resourcesGood() {
            return this.resources.RAMLast < this.resources.RAMCommitment;
        }
    };
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

(function () {
    'use strict';

    var $serviceHealth = void 0,
        resourcesFactory = void 0;

    controlplane.factory('InternalService', InternalServiceFactory);

    var InternalServiceInstance = function () {
        function InternalServiceInstance(data) {
            _classCallCheck(this, InternalServiceInstance);

            this.id = data.InstanceID;
            this.name = data.ServiceName;
            this.model = Object.freeze(data);
            this.mode = data.Mode;
            this.numberOfConnections = data.Connections;
            this.currentState = this.getCurrentState(this.model.HealthStatus);

            this.touch();
        }

        _createClass(InternalServiceInstance, [{
            key: 'touch',
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: 'updateStatus',
            value: function updateStatus(status) {
                this.healthChecks = status.HealthStatus;
                this.mode = status.Stats.Mode;
                this.numberOfConnections = status.Stats.Connections;
                this.currentState = this.getCurrentState(status.HealthStatus);
            }
        }, {
            key: 'getCurrentState',
            value: function getCurrentState(healthStatus) {
                return healthStatus.running === "passed" ? "started" : "stopped";
            }
        }, {
            key: 'hasHost',
            value: function hasHost() {
                return this.model.HostID ? true : false;
            }
        }]);

        return InternalServiceInstance;
    }();

    var InternalService = function () {
        function InternalService(data) {
            _classCallCheck(this, InternalService);

            this.id = data.ID;
            this.name = data.Name;
            this.model = Object.freeze(data);

            this.touch();
        }

        _createClass(InternalService, [{
            key: 'touch',
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: 'isIsvc',
            value: function isIsvc() {
                return true;
            }
        }, {
            key: 'fetchInstances',
            value: function fetchInstances() {
                var _this = this;

                return resourcesFactory.v2.getInternalServiceInstances(this.id).then(function (data) {
                    return _this.instances = data.map(function (i) {
                        return new InternalServiceInstance(i);
                    });
                });
            }
        }, {
            key: 'updateStatus',
            value: function updateStatus(status) {
                this.desiredState = status.DesiredState;

                var statusMap = status.Status.reduce(function (map, s) {
                    map[s.InstanceID] = s;
                    return map;
                }, {});

                this.instances.forEach(function (i) {
                    var s = statusMap[i.id];
                    if (s) {
                        i.updateStatus(s);
                    } else {
                        console.log('Could not find status for instance ' + i.id);
                    }
                });

                this.status = $serviceHealth.evaluate(this, this.instances);
                this.touch();
            }
        }]);

        return InternalService;
    }();

    InternalServiceFactory.$inject = ['$serviceHealth', 'resourcesFactory'];
    function InternalServiceFactory(_$serviceHealth, _resourcesFactory) {

        $serviceHealth = _$serviceHealth;
        resourcesFactory = _resourcesFactory;

        return InternalService;
    }
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* InternalServiceDetailsController
 * Displays details for an internal service
 */
(function () {
    "use strict";

    var $q = void 0,
        resourcesFactory = void 0,
        authService = void 0,
        $interval = void 0,
        servicedConfig = void 0,
        InternalService = void 0,
        log = void 0,
        params = void 0;

    var InternalServiceDetailsController = function () {
        function InternalServiceDetailsController($scope) {
            var _this = this;

            _classCallCheck(this, InternalServiceDetailsController);

            authService.checkLogin(this);

            this.touch();

            $scope.instancesTable = {
                sorting: { id: "asc" },
                watchExpression: function watchExpression() {
                    return _this.lastUpdate;
                },
                searchColumns: ['id', 'model.CoreCapacity']
            };

            this.fetchInternalService(params.id).then(function () {
                return _this.service.fetchInstances();
            }).then(function () {
                return _this.refresh();
            }).then(function () {
                if (_this.service.model.Parent) {
                    $scope.breadcrumbs = [{ label: 'applications', url: '/apps' }, { label: _this.service.model.Parent.Name, url: '/internalservices' }, { label: _this.service.model.Name, itemClass: "active", id: _this.service.id }];
                } else {
                    $scope.breadcrumbs = [{ label: 'applications', url: '/apps' }, { label: _this.service.Name, itemClass: "active", id: _this.service.id }];
                }

                $scope.$emit("ready");
            });

            this.updateFrequency = 3000;
            servicedConfig.getConfig().then(function (config) {
                _this.updateFrequency = config.PollFrequency * 1000;
            }).catch(function (err) {
                var errMessage = err.data ? err.data.Detail : err.statusText;
                log.error("could not load serviced config:", errMessage);
            });

            this.startPolling();

            $scope.$on("$destroy", function () {
                return _this.stopPolling();
            });
        }

        _createClass(InternalServiceDetailsController, [{
            key: "touch",
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: "fetchInternalService",
            value: function fetchInternalService(id) {
                var _this2 = this;

                var deferred = $q.defer();
                resourcesFactory.v2.getInternalService(id).then(function (data) {
                    _this2.service = new InternalService(data);
                    _this2.touch();
                    deferred.resolve();
                }, function (error) {
                    console.warn(error);
                    deferred.reject();
                });
                return deferred.promise;
            }
        }, {
            key: "startPolling",
            value: function startPolling() {
                var _this3 = this;

                if (!this.updatePromise) {
                    this.updatePromise = $interval(function () {
                        return _this3.refresh();
                    }, this.updateFrequency);
                }
            }
        }, {
            key: "stopPolling",
            value: function stopPolling() {
                if (this.updatePromise) {
                    $interval.cancel(this.updatePromise);
                    this.updatePromise = null;
                }
            }
        }, {
            key: "refresh",
            value: function refresh() {
                var _this4 = this;

                return resourcesFactory.v2.getInternalServiceStatuses([this.service.id]).then(function (data) {
                    var statusMap = data.reduce(function (map, s) {
                        map[s.ServiceID] = s;
                        return map;
                    }, {});

                    _this4.service.updateStatus(statusMap[_this4.service.id]);

                    _this4.touch();
                });
            }
        }, {
            key: "isZooKeeper",
            value: function isZooKeeper() {
                return this.service && this.service.id === 'isvc-zookeeper';
            }
        }, {
            key: "getInstances",
            value: function getInstances() {
                if (this.service && this.service.instances) {
                    return this.service.instances;
                }

                return [];
            }
        }, {
            key: "clickHost",
            value: function clickHost(id) {
                if (id) {
                    resourcesFactory.routeToHost(id);
                }
            }
        }]);

        return InternalServiceDetailsController;
    }();

    controlplane.controller("InternalServiceDetailsController", ["$scope", "$q", "resourcesFactory", "authService", "$interval", "servicedConfig", "InternalService", "log", "$routeParams", function ($scope, _$q, _resourcesFactory, _authService, _$interval, _servicedConfig, _InternalService, _log, _$routeParams) {

        $q = _$q;
        resourcesFactory = _resourcesFactory;
        authService = _authService;
        $interval = _$interval;
        servicedConfig = _servicedConfig;
        InternalService = _InternalService;
        log = _log;
        params = _$routeParams;

        return new InternalServiceDetailsController($scope);
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* InternalServicesController
 * Displays details for internal services
 */
(function () {
    "use strict";

    var $q = void 0,
        resourcesFactory = void 0,
        authService = void 0,
        $interval = void 0,
        servicedConfig = void 0,
        InternalService = void 0,
        log = void 0;

    var InternalServicesController = function () {
        function InternalServicesController($scope) {
            var _this = this;

            _classCallCheck(this, InternalServicesController);

            authService.checkLogin(this);

            this.touch();

            $scope.internalServicesTable = {
                sorting: {
                    name: "asc"
                },
                watchExpression: function watchExpression() {
                    return _this.lastUpdate;
                }
            };

            this.updateFrequency = 3000;
            servicedConfig.getConfig().then(function (config) {
                _this.updateFrequency = config.PollFrequency * 1000;
            }).catch(function (err) {
                var errMessage = err.data ? err.data.Detail : err.statusText;
                log.error("could not load serviced config:", errMessage);
            });

            this.fetchInternalServices().then(function () {
                return _this.fetchInstances();
            }).then(function () {
                return _this.refresh();
            }).then(function () {
                $scope.breadcrumbs = [{ label: 'applications', url: '/apps' }, { label: _this.parent.model.Name, itemClass: 'active' }];

                $scope.$emit("ready");
            });

            this.startPolling();

            $scope.$on("$destroy", function () {
                return _this.stopPolling();
            });
        }

        _createClass(InternalServicesController, [{
            key: "touch",
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: "startPolling",
            value: function startPolling() {
                var _this2 = this;

                if (!this.updatePromise) {
                    this.updatePromise = $interval(function () {
                        return _this2.refresh();
                    }, this.updateFrequency);
                }
            }
        }, {
            key: "stopPolling",
            value: function stopPolling() {
                if (this.updatePromise) {
                    $interval.cancel(this.updatePromise);
                    this.updatePromise = null;
                }
            }
        }, {
            key: "fetchInternalServices",
            value: function fetchInternalServices() {
                var _this3 = this;

                var deferred = $q.defer();
                resourcesFactory.v2.getInternalServices().then(function (data) {
                    var internalService = data.map(function (result) {
                        return new InternalService(result);
                    });
                    var parentIndex = internalService.findIndex(function (i) {
                        return !i.Parent;
                    });
                    if (parentIndex > -1) {
                        _this3.parent = internalService.splice(parentIndex, 1)[0];
                        _this3.children = internalService;
                    }
                    _this3.touch();
                    deferred.resolve();
                }, function (error) {
                    console.warn(error);
                    deferred.reject();
                });
                return deferred.promise;
            }
        }, {
            key: "fetchInstances",
            value: function fetchInstances() {
                var promises = [];

                if (this.parent) {
                    promises.push(this.parent.fetchInstances());
                }

                if (this.children) {
                    this.children.forEach(function (c) {
                        return promises.push(c.fetchInstances());
                    });
                }

                return $q.all(promises);
            }
        }, {
            key: "refresh",
            value: function refresh() {
                var _this4 = this;

                return resourcesFactory.v2.getInternalServiceStatuses().then(function (data) {
                    var statusMap = data.reduce(function (map, s) {
                        map[s.ServiceID] = s;
                        return map;
                    }, {});

                    _this4.parent.updateStatus(statusMap[_this4.parent.id]);
                    _this4.children.forEach(function (c) {
                        return c.updateStatus(statusMap[c.id]);
                    });

                    _this4.touch();
                });
            }
        }, {
            key: "clickInternalService",
            value: function clickInternalService(id) {
                resourcesFactory.routeToInternalService(id);
            }
        }]);

        return InternalServicesController;
    }();

    controlplane.controller("InternalServicesController", ["$scope", "$q", "resourcesFactory", "authService", "$interval", "servicedConfig", "InternalService", "log", function ($scope, _$q, _resourcesFactory, _authService, _$interval, _servicedConfig, _InternalService, _log) {

        $q = _$q;
        resourcesFactory = _resourcesFactory;
        authService = _authService;
        $interval = _$interval;
        servicedConfig = _servicedConfig;
        InternalService = _InternalService;
        log = _log;

        return new InternalServicesController($scope);
    }]);
})();
"use strict";

/* LanguageController
 * toggle selected language
 */
(function () {
    'use strict';

    controlplane.controller("LanguageController", ["$scope", "$cookies", "$translate", "miscUtils", "log", function ($scope, $cookies, $translate, utils, log) {
        $scope.name = 'language';
        $scope.setUserLanguage = function () {
            log.log('User clicked', $scope.user.language);
            $cookies.put("Language", $scope.user.language);
            utils.updateLanguage($scope, $cookies, $translate);
        };
        $scope.getLanguageClass = function (language) {
            return $scope.user.language === language ? 'btn btn-primary active' : 'btn btn-primary';
        };
    }]);
})();
"use strict";

/* LoginController
 * login page
 */
(function () {
    'use strict';

    controlplane.controller("LoginController", ["$scope", "$location", "$notification", "$translate", "authService", function ($scope, $location, $notification, $translate, authService) {

        if (navigator.userAgent.indexOf("Trident") > -1 && navigator.userAgent.indexOf("MSIE 7.0") > -1) {
            $notification.create("", $translate.instant("compatibility_mode"), $("#loginNotifications")).warning(false);
        }

        enableLoginButton();

        $scope.$emit("ready");

        // Makes XHR POST with contents of login form
        $scope.login = function () {
            disableLoginButton();

            var creds = { "Username": $scope.username, "Password": $scope.password };
            authService.login(creds, function () {
                enableLoginButton();
                // Redirect to main page
                $location.path('/apps');
            }, function () {
                enableLoginButton();
                // display fail message to user
                $notification.create("", $translate.instant("login_fail"), $("#loginNotifications")).error();
            });
        };

        function enableLoginButton() {
            $scope.loginButtonText = "log_in";
            $scope.loginDisabled = false;
        }

        function disableLoginButton() {
            $scope.loginButtonText = "logging_in";
            $scope.loginDisabled = true;
        }
    }]);
})();
"use strict";

/* LogController
 * displays kibaba log iframe
 */
(function () {
    'use strict';

    controlplane.controller("LogController", ["$scope", "authService", function ($scope, authService) {
        authService.checkLogin($scope);
        $scope.breadcrumbs = [{ label: 'breadcrumb_logs', itemClass: 'active' }];

        $scope.$emit("ready");

        // force log iframe to fill screen
        setInterval(function () {
            var logsframe = document.getElementById("logsframe");

            if (logsframe && logsframe.contentWindow.document.body) {
                var h = logsframe.contentWindow.document.body.clientHeight;
                logsframe.height = h + "px";
            }
        }, 100);
    }]);
})();
"use strict";

/* globals controlplane: true */
/* NavbarController.js
 * Controls the navbar. what else were you thinking it would do?
 */
(function () {
    "use strict";

    controlplane.controller("NavbarController", ["$scope", "$rootScope", "$cookies", "$location", "$route", "$translate", "$notification", "authService", "resourcesFactory", "$modalService", "miscUtils", "LogSearch", function ($scope, $rootScope, $cookies, $location, $route, $translate, $notification, authService, resourcesFactory, $modalService, utils, LogSearch) {
        $scope.name = 'navbar';
        $scope.brand = { url: '#/apps', label: 'brand_cp' };

        $rootScope.messages = $notification.getMessages();
        $scope.$on('messageUpdate', function () {
            $rootScope.messages = $notification.getMessages();
            if (!$scope.$$phase) {
                $scope.$apply();
            }
        });
        $rootScope.markRead = function (message) {
            $notification.markRead(message);
        };
        $rootScope.clearMessages = function () {
            $notification.clearAll();
        };

        var logSearchLink = LogSearch.getDefaultURL();

        $scope.navlinks = [{ url: '#/apps', label: 'nav_apps', sublinks: ['#/services/'] }, { url: '#/pools', label: 'nav_pools', sublinks: ['#/pools/'] }, { url: '#/hosts', label: 'nav_hosts', sublinks: ['#/hosts/'] }, { url: logSearchLink, label: 'nav_logs', sublinks: [], target: "_blank" }, { url: '#/backuprestore', label: 'nav_backuprestore', sublinks: [] }];

        for (var i = 0; i < $scope.navlinks.length; i++) {
            var cls = '';
            var currUrl = '#' + $location.path();
            if ($scope.navlinks[i].url === currUrl) {
                cls = 'active';
            } else {
                for (var j = 0; j < $scope.navlinks[i].sublinks.length; j++) {
                    if (currUrl.indexOf($scope.navlinks[i].sublinks[j]) === 0) {
                        cls = 'active';
                    }
                }
            }
            $scope.navlinks[i].itemClass = cls;
        }

        $scope.subNavClick = function (crumb) {
            // if parent scope has defined a handler
            // for sub nav click, use it
            if ($scope.$parent && $scope.$parent.subNavClick) {
                $scope.$parent.subNavClick(crumb);
            } else {
                $location.path(crumb.url);
            }
        };

        // watch parent for new breadcrumbs
        $scope.$watch("$parent.breadcrumbs", function () {
            $scope.breadcrumbs = $scope.$parent.breadcrumbs;
        });

        // Create a logout function
        $scope.logout = function () {
            authService.logout();
        };

        $scope.modalUserDetails = function () {
            $modalService.create({
                templateUrl: "user-details.html",
                model: $scope,
                title: "title_user_details",
                bigModal: true
            });
        };

        $scope.modalAbout = function () {
            resourcesFactory.getVersion().success(function (data) {
                $scope.version = data;
            });

            $modalService.create({
                templateUrl: "about.html",
                model: $scope,
                title: "title_about"
            });
        };

        utils.updateLanguage($scope, $cookies, $translate);

        var helpMap = {
            '/static/partials/login.html': 'login.html',
            '/static/partials/view-subservices.html': 'subservices.html',
            '/static/partials/view-apps.html': 'apps.html',
            '/static/partials/view-hosts.html': 'hosts.html',
            '/static/partials/view-host-map.html': 'hostmap.html',
            '/static/partials/view-service-map.html': 'servicemap.html',
            '/static/partials/view-host-details.html': 'hostdetails.html',
            '/static/partials/view-devmode.html': 'devmode.html'
        };

        $scope.help = {
            url: function url() {
                return '/static/help/' + $scope.user.language + '/' + helpMap[$route.current.templateUrl];
            }
        };

        $scope.cookies = $cookies;
    }]);
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

(function () {
    'use strict';

    // share angular services outside of angular context

    var POOL_PERMISSIONS = void 0,
        $q = void 0,
        resourcesFactory = void 0,
        Host = void 0;

    controlplane.factory('Pool', PoolFactory);

    // Pool object constructor takes a pool object (backend pool object)
    // and wraps it with extra functionality and info

    var Pool = function () {
        function Pool(pool) {
            _classCallCheck(this, Pool);

            this.id = pool.ID;
            this.model = Object.freeze(pool);
            this.hosts = [];
            this.calculatePermissions();
            this.touch();
        }

        // mark services updated to trigger render via $watch


        _createClass(Pool, [{
            key: 'touch',
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: 'calculatePermissions',
            value: function calculatePermissions() {
                var _this = this;

                // build a list of permissions
                // this pool has
                // NOTE: permissions include description
                // and friendly label for the UI to display
                var val = this.model.Permissions;
                this.permissions = [];
                POOL_PERMISSIONS.forEach(function (perm) {
                    if ((val & perm.position) !== 0) {
                        _this.permissions.push(perm);
                    }
                });
            }
        }, {
            key: 'fetchHosts',
            value: function fetchHosts(force) {
                var _this2 = this;

                var deferred = $q.defer();
                if (this.hosts && !force) {
                    deferred.resolve();
                }
                resourcesFactory.v2.getPoolHosts(this.id).then(function (data) {
                    _this2.hosts = data.map(function (h) {
                        return new Host(h);
                    });
                    _this2.touch();
                    deferred.resolve();
                }, function (error) {
                    console.warn(error);
                    deferred.reject();
                });
                return deferred.promise;
            }
        }]);

        return Pool;
    }();

    PoolFactory.$inject = ['POOL_PERMISSIONS', '$q', 'resourcesFactory', 'Host'];

    function PoolFactory(_POOL_PERMISSIONS, _$q, _resourcesFactory, _Host) {

        // api access via angular context
        POOL_PERMISSIONS = _POOL_PERMISSIONS;
        $q = _$q;
        resourcesFactory = _resourcesFactory;
        Host = _Host;

        return Pool;
    }
})();
"use strict";

/* global controlplane: true */

/* PoolDetailsController
 * Displays details of a specific pool
 */
(function () {
    'use strict';

    controlplane.controller("PoolDetailsController", ["$scope", "$routeParams", "$location", "resourcesFactory", "authService", "$modalService", "$translate", "$notification", "miscUtils", "areUIReady", "POOL_PERMISSIONS", "Pool", "$rootScope", function ($scope, $routeParams, $location, resourcesFactory, authService, $modalService, $translate, $notification, utils, areUIReady, POOL_PERMISSIONS, Pool, $rootScope) {
        // Ensure logged in
        authService.checkLogin($scope);

        // allow templates to get the list
        // of permissions
        $scope.permissions = POOL_PERMISSIONS;

        $scope.clickRemoveVirtualIp = function (ip) {
            $modalService.create({
                template: $translate.instant("confirm_remove_virtual_ip") + " <strong>" + ip.IP + "</strong>",
                model: $scope,
                title: "remove_virtual_ip",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "remove_virtual_ip",
                    classes: "btn-danger",
                    action: function action() {
                        resourcesFactory.removePoolVirtualIP(ip.PoolID, ip.IP).success(function (data) {
                            $notification.create("Removed Virtual IP", ip.IP).success();
                            update();
                        }).error(function (data) {
                            $notification.create("Remove Virtual IP failed", data.Detail).error();
                        });
                        this.close();
                    }
                }]
            });
        };

        // Add Virtual Ip Modal - Add button action
        $scope.addVirtualIp = function (pool) {
            var ip = $scope.add_virtual_ip;

            return resourcesFactory.addPoolVirtualIP(ip.PoolID, ip.IP, ip.Netmask, ip.BindInterface).success(function (data, status) {
                $scope.add_virtual_ip = {};
                $notification.create("Added new pool virtual ip", ip).success();
                update();
            }).error(function (data, status) {
                $notification.create("Add Virtual IP failed", utils.escapeHTML(data.Detail)).error();
            });
        };

        // Open the virtual ip modal
        $scope.modalAddVirtualIp = function (pool) {
            areUIReady.lock();
            $scope.add_virtual_ip = { 'PoolID': pool.id, 'IP': "", 'Netmask': "", 'BindInterface': "" };
            $modalService.create({
                templateUrl: "pool-add-virtualip.html",
                model: $scope,
                title: "add_virtual_ip",
                actions: [{
                    role: "cancel",
                    action: function action() {
                        $scope.add_virtual_ip = {};
                        this.close();
                    }
                }, {
                    role: "ok",
                    label: "add_virtual_ip",
                    action: function action() {
                        if (this.validate()) {
                            // disable ok button, and store the re-enable function
                            var enableSubmit = this.disableSubmitButton();

                            $scope.addVirtualIp($scope.add_virtual_ip).success(function (data, status) {
                                this.close();
                            }.bind(this)).error(function (data, status) {
                                this.createNotification("Adding pool virtual ip failed", utils.escapeHTML(data.Detail)).error();
                                enableSubmit();
                            }.bind(this));
                        }
                    }
                }],
                onShow: function onShow() {
                    areUIReady.unlock();
                }
            });
        };

        // route host clicks to host page
        $scope.clickHost = function (hostId) {
            resourcesFactory.routeToHost(hostId);
        };

        $scope.editCurrentPool = function () {
            $scope.editablePool = {
                ID: $scope.currentPool.model.ID,
                ConnectionTimeout: utils.humanizeDuration($scope.currentPool.model.ConnectionTimeout),
                permissions: new utils.NgBitset(POOL_PERMISSIONS.length, $scope.currentPool.model.Permissions)
            };

            $modalService.create({
                templateUrl: "edit-pool.html",
                model: $scope,
                title: "title_edit_pool",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "btn_save_changes",
                    action: function action() {
                        var poolModel = angular.copy($scope.currentPool.model);
                        angular.extend(poolModel, $scope.editablePool);

                        if (this.validate()) {
                            // disable ok button, and store the re-enable function
                            var enableSubmit = this.disableSubmitButton();
                            // convert validated human input into ms for rest call
                            poolModel.ConnectionTimeout = utils.parseDuration($scope.editablePool.ConnectionTimeout);
                            // add the Permissions field and remove the NgBitset field
                            poolModel.Permissions = poolModel.permissions.val;
                            delete poolModel.permissions;
                            // update pool with recently edited pool
                            resourcesFactory.updatePool($scope.currentPool.model.ID, poolModel).success(function (data, status) {
                                $notification.create("Updated pool", utils.escapeHTML(poolModel.ID)).success();
                                update();
                                this.close();
                            }.bind(this)).error(function (data, status) {
                                this.createNotification("Update pool failed", utils.escapeHTML(data.Detail)).error();
                                enableSubmit();
                            }.bind(this));
                        }
                    }
                }],
                validate: function validate() {
                    var err = utils.validateDuration($scope.editablePool.ConnectionTimeout);
                    if (err) {
                        this.createNotification("Error", err).error();
                        return false;
                    }
                    return true;
                }
            });
        };

        function setCurrentPool(pool) {
            $scope.currentPool = new Pool(pool);
            $scope.currentPool.fetchHosts();
        }

        // update/refresh current pools data
        function update() {
            return resourcesFactory.getPool($scope.params.poolID).success(function (pool) {
                return setCurrentPool(pool);
            });
        }

        function init() {

            $scope.params = $routeParams;

            $scope.add_virtual_ip = {};

            $scope.breadcrumbs = [{ label: 'breadcrumb_pools', url: '/pools' }];

            $scope.virtualIPsTable = {
                sorting: {
                    IP: "asc"
                },
                searchColumns: ['IP', 'BindInterfaces']
            };

            $scope.hostsTable = {
                sorting: {
                    name: "asc"
                },
                searchColumns: ['name', 'model.Cores', 'model.KernelVersion']
            };

            // get the pool the do some first time setup
            update().then(function () {
                $scope.breadcrumbs.push({ label: $scope.currentPool.id, itemClass: 'active' });
                $rootScope.$emit("ready");
            });
        }

        init();
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* global controlplane: true */

/* PoolsControl
 * Displays list of pools
 */
(function () {
    'use strict';

    var resourcesFactory = void 0,
        authService = void 0,
        $modalService = void 0,
        $translate = void 0,
        $notification = void 0,
        areUIReady = void 0,
        $interval = void 0,
        servicedConfig = void 0,
        log = void 0,
        permissions = void 0,
        utils = void 0,
        Pool = void 0,
        $q = void 0;

    var PoolsController = function () {
        function PoolsController($scope) {
            var _this = this;

            _classCallCheck(this, PoolsController);

            authService.checkLogin(this);

            this.name = "pools";

            this.refreshPools().then(function () {
                return $scope.$emit("ready");
            });

            this.updateFrequency = 3000;
            servicedConfig.getConfig().then(function (config) {
                _this.updateFrequency = config.PollFrequency * 1000;
            }).catch(function (err) {
                var errMessage = err.data ? err.data.Detail : err.statusText;
                log.error("could not load serviced config:", errMessage);
            });

            $scope.poolsTable = {
                sorting: { id: "asc" },
                watchExpression: function watchExpression() {
                    return _this.lastUpdate;
                },
                searchColumns: ['id', 'model.CoreCapacity']
            };

            $scope.breadcrumbs = [{ label: 'breadcrumb_pools', itemClass: 'active' }];

            this.startPolling();

            $scope.$on("$destroy", function () {
                return _this.stopPolling();
            });

            // New scopes are created to use as models for the modals dialogs.
            // They require some additional methods that are on the global
            // scope.  Since we want to keep $scope limited to just the constructor,
            // this method can be used to create new scopes for modals.
            this.newScope = function () {
                return $scope.$new(true);
            };
        }

        _createClass(PoolsController, [{
            key: "touch",
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }
        }, {
            key: "isDefaultPool",
            value: function isDefaultPool(id) {
                return id === "default";
            }
        }, {
            key: "refreshPools",
            value: function refreshPools() {
                var _this2 = this;

                var deferred = $q.defer();
                resourcesFactory.v2.getPools().success(function (data) {
                    _this2.pools = data.map(function (result) {
                        return new Pool(result);
                    });
                    _this2.totalPoolCount = data.length;
                    _this2.touch();
                    deferred.resolve();
                }).error(function (data) {
                    var message = data && data.Detail || "";
                    console.warn("Unable to load pools.", message);
                    deferred.reject();
                });
                return deferred.promise;
            }
        }, {
            key: "startPolling",
            value: function startPolling() {
                var _this3 = this;

                if (!this.updatePromise) {
                    this.updatePromise = $interval(function () {
                        return _this3.refreshPools();
                    }, this.updateFrequency);
                }
            }
        }, {
            key: "stopPolling",
            value: function stopPolling() {
                if (this.updatePromise) {
                    $interval.cancel(this.updatePromise);
                    this.updatePromise = null;
                }
            }
        }, {
            key: "clickPool",
            value: function clickPool(id) {
                resourcesFactory.routeToPool(id);
            }
        }, {
            key: "clickRemovePool",
            value: function clickRemovePool(id) {
                var _this4 = this;

                if (this.isDefaultPool(id)) {
                    return;
                }

                var modalScope = this.newScope();
                modalScope.refreshPools = function () {
                    return _this4.refreshPools();
                };

                $modalService.create({
                    template: $translate.instant("confirm_remove_pool") + "<strong>" + utils.escapeHTML(id) + "</strong>",
                    model: modalScope,
                    title: "remove_pool",
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        label: "remove_pool",
                        classes: "btn-danger",
                        action: function action() {
                            resourcesFactory.removePool(id).success(function (data) {
                                $notification.create("Removed Pool", utils.escapeHTML(id)).success();
                                modalScope.refreshPools();
                            }).error(function (data) {
                                var message = data && data.Detail || "";
                                $notification.create("Remove Pool failed", utils.escapeHTML(message)).error();
                            });

                            this.close();
                        }
                    }]
                });
            }
        }, {
            key: "clickAddPool",
            value: function clickAddPool() {
                var _this5 = this;

                var modalScope = this.newScope();
                modalScope.refreshPools = function () {
                    return _this5.refreshPools();
                };
                modalScope.permissions = permissions;
                modalScope.newPool = {
                    permissions: new utils.NgBitset(permissions.length, 3)
                };

                areUIReady.lock();
                $modalService.create({
                    templateUrl: "add-pool.html",
                    model: modalScope,
                    title: "add_pool",
                    actions: [{
                        role: "cancel",
                        action: function action() {
                            this.close();
                        }
                    }, {
                        role: "ok",
                        label: "add_pool",
                        action: function action() {
                            if (this.validate()) {
                                // disable ok button, and store the re-enable function
                                var enableSubmit = this.disableSubmitButton();

                                // make a copy of the payload, add the permissions field, and remove the NgBitset
                                var payload = angular.copy(modalScope.newPool);
                                payload.Permissions = modalScope.newPool.permissions.val;
                                delete payload.permissions;

                                resourcesFactory.addPool(payload).success(function (data, status) {
                                    this.close();
                                    $notification.create("Added new Pool", utils.escapeHTML(data.Detail)).success();
                                    modalScope.refreshPools();
                                }.bind(this)).error(function (data, status) {
                                    this.createNotification("Adding pool failed", utils.escapeHTML(data.Detail)).error();
                                    enableSubmit();
                                }.bind(this));
                            }
                        }
                    }],
                    onShow: function onShow() {
                        return areUIReady.unlock();
                    }
                });
            }
        }]);

        return PoolsController;
    }();

    controlplane.controller("PoolsController", ["$scope", "resourcesFactory", "authService", "$modalService", "$translate", "$notification", "areUIReady", "$interval", "servicedConfig", "log", "POOL_PERMISSIONS", "miscUtils", "Pool", "$q", function ($scope, _resourcesFactory, _authService, _$modalService, _$translate, _$notification, _areUIReady, _$interval, _servicedConfig, _log, _POOL_PERMISSIONS, _miscUtils, _Pool, _$q) {

        resourcesFactory = _resourcesFactory;
        authService = _authService;
        $modalService = _$modalService;
        $translate = _$translate;
        $notification = _$notification;
        areUIReady = _areUIReady;
        $interval = _$interval;
        servicedConfig = _servicedConfig;
        log = _log;
        permissions = _POOL_PERMISSIONS;
        utils = _miscUtils;
        Pool = _Pool;
        $q = _$q;

        return new PoolsController($scope);
    }]);
})();
"use strict";

(function () {
    'use strict';
    // access permissions that apply to pools

    controlplane.constant("POOL_PERMISSIONS", [{
        label: "Admin",
        description: "admin_permissions",
        position: 1 << 0
    }, {
        label: "DFS",
        description: "dfs_permissions",
        position: 1 << 1
    }]);
})();
'use strict';

// poolsFactory
// - maintains a list of pools and keeps it in sync with the backend.
(function () {
    'use strict';

    var resourcesFactory, $q;

    angular.module('poolsFactory', []).factory("poolsFactory", ["$rootScope", "$q", "resourcesFactory", "$interval", "baseFactory", function ($rootScope, q, _resourcesFactory, $interval, BaseFactory) {

        // share resourcesFactory throughout
        resourcesFactory = _resourcesFactory;
        $q = q;

        var newFactory = new BaseFactory(Pool, resourcesFactory.getPools);
        newFactory.poolList = newFactory.objArr;
        newFactory.poolMap = newFactory.objMap;
        return newFactory;
    }]);

    // Pool object constructor
    // takes a pool object (backend pool object)
    // and wraps it with extra functionality and info
    function Pool(pool) {
        this.update(pool);
    }

    Pool.prototype = {
        constructor: Pool,

        update: function update(pool) {
            if (pool) {
                this.updatePoolDef(pool);
            }
        },

        updatePoolDef: function updatePoolDef(pool) {
            this.name = pool.Name;
            this.id = pool.ID;
            this.model = Object.freeze(pool);
        }
    };
})();
'use strict';

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* jshint multistr: true */
(function () {
    'use strict';

    // share angular services outside of angular context

    controlplane.factory('svcActions', SvcActionsFactory);

    var svcActions = function svcActions() {
        _classCallCheck(this, svcActions);
    };

    SvcActionsFactory.$inject = ['$serviceHealth'];
    function SvcActionsFactory(_serviceHealth) {

        // api access via angular context
        this.serviceHealth = _serviceHealth;

        return svcActions;
    }
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* serviceActionssDirective
 * directive for displaying processing state of a service/instance
 */
(function () {
    'use strict';

    angular.module('serviceActions', []).directive("serviceActions", ["svcActions", "$notification", function (svcActions, $notification) {
        var ServiceActionsController = function () {
            function ServiceActionsController() {
                // howdy

                _classCallCheck(this, ServiceActionsController);
            }

            _createClass(ServiceActionsController, [{
                key: 'actionClick',
                value: function actionClick(action, isEnabled) {
                    //let service = this.service;
                }
            }, {
                key: 'start',
                value: function start(force) {
                    this.service.start().error(function (data, status) {
                        $notification.create("Unable to start service", data.Detail).error();
                    });
                }
            }, {
                key: 'restart',
                value: function restart(force) {
                    this.service.restart().error(function (data, status) {
                        $notification.create("Unable to restart service", data.Detail).error();
                    });
                }
            }, {
                key: 'stop',
                value: function stop(force) {
                    this.service.stop().error(function (data, status) {
                        $notification.create("Unable to stop service", data.Detail).error();
                    });
                }
            }, {
                key: 'cancel',
                value: function cancel() {
                    this.service.cancelPending().error(function (data, status) {
                        $notification.create("Unable to cancel pending action", data.Detail).error();
                    });
                }
            }, {
                key: 'update',
                value: function update() {
                    if (this.service && !this.service.isContainer()) {
                        this.showValidActions(this.service.currentState);
                    } else {
                        this.showDefaultActions();
                    }
                }
            }]);

            return ServiceActionsController;
        }();

        var actsTemplate = '\n        <div class="svc-actionbar">\n\n            <div class="svcactions-starts">\n                <button\n                    class="btn btn-link action svcactions svcactions-start"\n                    ng-click="vm.start(false)"\n                    data-valid="stopping,stopped,unknown"\n                >\n                    <i class="glyphicon glyphicon-play"></i>\n                    <span translate>start</span>\n                </button>\n                <button\n                    class="btn btn-link action svcactions svcactions-startnow"\n                    ng-click="vm.start(true)"\n                    data-valid="pending_start"\n                >\n                    <i class="glyphicon glyphicon-play"></i>\n                    <span translate>btn_start_now</span>\n                </button>\n                <button\n                    class="btn btn-link action svcactions svcactions-restart"\n                    ng-click="vm.restart(false)"\n                    data-valid="started"\n                >\n                    <i class="glyphicon glyphicon-refresh"></i>\n                    <span translate>action_restart</span>\n                </button>\n                <button\n                    class="btn btn-link action svcactions svcactions-restartnow"\n                    ng-click="vm.restart(true)"\n                    data-valid="pending_restart"\n                >\n                    <i class="glyphicon glyphicon-refresh"></i>\n                    <span translate>btn_restart_now</span>\n                </button>\n                <span class="svcactions svcactions-na">\n                    <i class="glyphicon glyphicon-play"></i>\n                    <span translate>start</span>\n                </span>\n            </div>\n\n            <div class="svcactions-stops">\n                <button\n                    class="btn btn-link action svcactions svcactions-stop"\n                    ng-click="vm.stop(false)"\n                    data-valid="starting,started,pending_restart,restarting,unknown"\n                >\n                    <i class="glyphicon glyphicon-stop"></i>\n                    <span translate>stop</span>\n                </button>\n                <button\n                    class="btn btn-link action svcactions svcactions-stopnow"\n                    ng-click="vm.stop(true)"\n                    data-valid="pending_stop"\n                >\n                    <i class="glyphicon glyphicon-stop"></i>\n                    <span translate>btn_stop_now</span>\n                </button>\n                <span class="svcactions svcactions-na">\n                    <i class="glyphicon glyphicon-stop"></i>\n                    <span translate>stop</span>\n                </span>\n            </div>\n\n            <div class="svcactions-cancels">\n                <button\n                    class="btn btn-link action svcactions svcactions-cancel"\n                    ng-click="vm.cancel()"\n                    data-valid="pending_stop,pending_start,pending_restart"\n                >\n                    <i class="glyphicon glyphicon-remove"></i>\n                    <span translate>btn_cancel</span>\n                </button>\n                <span class="svcactions svcactions-na">\n                    <i class="glyphicon glyphicon-remove"></i>\n                    <span translate>btn_cancel</span>\n                </span>\n                <button\n                    class="btn btn-link action svcactions svcactions-container-restart"\n                    ng-click="vm.restart(false)"\n                    data-valid=""\n                >\n                    <i class="glyphicon glyphicon-refresh"></i>\n                    <span translate>action_restart</span>\n                </button>\n            </div>\n\n        </div>\n        ';

        return {
            restrict: "E",
            template: actsTemplate,
            scope: {
                service: "="
            },
            controller: ServiceActionsController,
            controllerAs: "vm",
            bindToController: true,
            link: function link($scope, element, attrs) {

                var allButtonEls = element.find(".svcactions");
                var startActions = element.find(".svcactions-starts");
                var stopActions = element.find(".svcactions-stops");
                var cancelActions = element.find(".svcactions-cancels");

                var showValidActions = function showValidActions(state) {
                    allButtonEls.hide();

                    var el = startActions.find("[data-valid*=" + state + "]");
                    if (el.length) {
                        el.show();
                    } else {
                        startActions.find(".svcactions-na").show();
                    }

                    el = stopActions.find("[data-valid*=" + state + "]");
                    if (el.length) {
                        el.show();
                    } else {
                        stopActions.find(".svcactions-na").show();
                    }

                    el = cancelActions.find("[data-valid*=" + state + "]");
                    if (el.length) {
                        el.show();
                    } else {
                        cancelActions.find(".svcactions-na").show();
                    }
                };

                var showDefaultActions = function showDefaultActions() {
                    allButtonEls.hide();
                    startActions.find(".svcactions-start").show();
                    stopActions.find(".svcactions-stop").show();
                    cancelActions.find(".svcactions-container-restart").show();
                };

                $scope.vm.showValidActions = showValidActions;
                $scope.vm.showDefaultActions = showDefaultActions;

                // if status object updates, update icon
                $scope.$watch("vm.service.currentState", $scope.vm.update.bind($scope.vm));

                // TODO - cleanup watch
                $scope.$on("$destroy", function () {});
            } };
    }]);
})();
"use strict";

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

/* globals controlplane: true */

/* AppsController
 * Displays top level apps
 */
(function () {
    'use strict';

    controlplane.controller("AppsController", ["$rootScope", "$scope", "$routeParams", "$location", "$notification", "resourcesFactory", "authService", "$modalService", "$translate", "$timeout", "$cookies", "miscUtils", "ngTableParams", "$filter", "Service", "InternalService", "$q", function ($rootScope, $scope, $routeParams, $location, $notification, resourcesFactory, authService, $modalService, $translate, $timeout, $cookies, utils, NgTableParams, $filter, Service, InternalService, $q) {

        // Ensure logged in
        authService.checkLogin($scope);

        // alias hostname instead of using localhost or IP
        $scope.defaultHostAlias = $location.host();

        // redirect to specific service details
        $scope.routeToService = function (service) {
            if (service.isIsvc()) {
                resourcesFactory.routeToInternalServices();
            } else {
                resourcesFactory.routeToService(service.id);
            }
        };

        // redirect to specific pool
        $scope.routeToPool = function (id) {
            resourcesFactory.routeToPool(id);
        };

        $scope.modal_deployWizard = function () {

            // the modal occasionally won't show on page load, so we use a timeout to get around that.
            $timeout(function () {
                $('#addApp').modal('show');

                // don't auto-show this wizard again
                // NOTE: $cookies can only deal with string values
                $cookies.put("autoRunWizardHasRun", "true");
            });
        };

        $scope.modal_addTemplate = function () {
            $modalService.create({
                templateUrl: "add-template.html",
                model: $scope,
                title: "template_add",
                actions: [{
                    role: "cancel",
                    action: function action() {
                        $scope.newHost = {};
                        this.close();
                    }
                }, {
                    role: "ok",
                    label: "template_add",
                    action: function action() {
                        if (this.validate()) {
                            var data = new FormData();

                            $.each($("#new_template_filename")[0].files, function (key, value) {
                                data.append("tpl", value);
                            });

                            // disable ok button, and store the re-enable function
                            var enableSubmit = this.disableSubmitButton();

                            resourcesFactory.addAppTemplate(data).success(function (data) {
                                $notification.create("Added template", data.Detail).success();
                                refreshTemplates();
                                this.close();
                            }.bind(this)).error(function (data) {
                                this.createNotification("Adding template failed", data.Detail).error();
                                enableSubmit();
                            }.bind(this));
                        }
                    }
                }]
            });
        };

        $scope.modal_removeService = function (service) {
            $modalService.create({
                template: $translate.instant("warning_remove_service"),
                model: $scope,
                title: "remove_service",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "remove_service",
                    classes: "btn-danger submit",
                    action: function action() {
                        var _this = this;

                        if (this.validate()) {
                            this.disableSubmitButton();

                            removeService(service).success(function () {
                                refreshApps().then(function () {
                                    $notification.create("Removed App", service.name).success();
                                });
                                _this.close();
                            }).error(function (data, status) {
                                $notification.create("Remove App failed", data.Detail).error();
                                _this.close();
                            });
                        }
                    }
                }]
            });
        };

        $scope.startService = function (service) {
            $scope.modal_startStopService(service, "start");
        };
        $scope.stopService = function (service) {
            $scope.modal_startStopService(service, "stop");
        };
        $scope.modal_startStopService = function (service, status) {
            var displayStatus = utils.capitalizeFirst(status);

            $modalService.create({
                template: $translate.instant("confirm_" + status + "_app"),
                model: $scope,
                title: displayStatus + " Services",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: displayStatus + " Services",
                    action: function action() {
                        service[status]();
                        this.close();
                    }
                }]
            });
        };

        // sets a service to start, stop or restart state
        $scope.setServiceState = function (service, state, skipChildren) {
            service[state](skipChildren).error(function (data, status) {
                $notification.create("Unable to " + state + " service", data.Detail).error();
            });
        };

        // clicks to a service's start, stop, or restart
        // button should first determine if the service has
        // children and ask the user to choose to start all
        // children or only the top service
        $scope.clickRunning = function (service, state) {
            var onStartService = function onStartService(modal) {
                // the arg here explicitly prevents child services
                // from being started
                $scope.setServiceState(service, state, true);
                modal.close();
            };
            var onStartServiceAndChildren = function onStartServiceAndChildren(modal) {
                $scope.setServiceState(service, state);
                modal.close();
            };

            Service.countAffectedDescendants(service, state).then(function (count) {
                $modalService.modals.confirmServiceStateChange(service, state, count, onStartService, onStartServiceAndChildren);
            }).catch(function (err) {
                console.warn("couldnt get descendant count", err);
                $modalService.modals.confirmServiceStateChange(service, state, 0, onStartService, onStartServiceAndChildren);
            });

            // let the user know they gonna have to hold onto
            // their horses for just one moment.
            $modalService.modals.oneMoment();
        };

        // verifies if use wants to start parent service, or parent
        // and all children
        $scope.modal_confirmSetServiceState = function (service, state, childCount) {
            $modalService.create({
                template: ["<h4>" + $translate.instant("choose_services_" + state) + "</h4><ul>", "<li>" + $translate.instant(state + "_service_name", { name: "<strong>" + service.name + "</strong>" }) + "</li>", "<li>" + $translate.instant(state + "_service_name_and_children", { name: "<strong>" + service.name + "</strong>", count: "<strong>" + childCount + "</strong>" }) + "</li></ul>"].join(""),
                model: $scope,
                title: $translate.instant(state + "_service"),
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    classes: " ",
                    label: $translate.instant(state + "_service"),
                    action: function action() {
                        // the arg here explicitly prevents child services
                        // from being started
                        $scope.setServiceState(service, state, true);
                        this.close();
                    }
                }, {
                    role: "ok",
                    label: $translate.instant(state + "_service_and_children", { count: childCount }),
                    action: function action() {
                        $scope.setServiceState(service, state);
                        this.close();
                    }
                }]
            });
        };

        $scope.modal_deleteTemplate = function (templateID) {
            $modalService.create({
                template: $translate.instant("template_remove_confirm") + "<strong>" + templateID + "</strong>",
                model: $scope,
                title: "template_remove",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "template_remove",
                    classes: "btn-danger",
                    action: function action() {
                        var _this2 = this;

                        deleteTemplate(templateID).success(function () {
                            $notification.create("Removed Template", templateID).success();
                            _this2.close();
                        }).error(function (data, status) {
                            $notification.create("Remove Template failed", data.Detail).error();
                        });
                    }
                }]
            });
        };

        /*
         * PRIVATE FUNCTIONS
         */
        function refreshTemplates() {
            resourcesFactory.getAppTemplates().success(function (templates) {
                $scope.templates.data = utils.mapToArr(templates);
            });
        }

        function refreshApps() {
            return fetchApps().then(fillOutApps).then(fetchServicesHealth).then(fetchInternalServicesHealth).then(function () {
                return touch();
            }).catch(function (error) {
                return console.warn(error);
            });
        }

        function fetchApps() {
            return $q.all([fetchInternalService(), fetchServices()]).then(function (results) {
                $scope.apps = [];

                var isvc = results[0];
                $scope.apps.push(isvc);

                var services = results[1];
                services.forEach(function (s) {
                    $scope.apps.push(s);
                });
            });
        }

        function fetchChildEndpoints(app) {
            return resourcesFactory.v2.getServiceChildPublicEndpoints(app.id).then(function (data) {
                app.publicEndpoints = data;
            });
        }

        function fillOutApps() {
            var promises = [];
            $scope.apps.forEach(function (a) {
                if (a.isIsvc()) {
                    promises.push(function () {
                        return a.fetchInstances();
                    });
                } else {
                    promises.push(fetchChildEndpoints(a));
                }
            });

            return $q.all(promises);
        }

        function fetchServices() {
            var deferred = $q.defer();
            resourcesFactory.v2.getTenants().then(function (data) {
                var services = data.map(function (s) {
                    return new Service(s);
                });
                deferred.resolve(services);
            }, function (error) {
                console.warn(error);
                deferred.reject();
            });
            return deferred.promise;
        }

        function fetchServicesHealth() {
            if (!$scope.apps) {
                return;
            }

            $scope.apps.forEach(function (app) {
                if (!app.isIsvc()) {
                    app.fetchAllStates();
                }
            });
        }

        function fetchInternalService() {
            var deferred = $q.defer();
            resourcesFactory.v2.getInternalServices().then(function (data) {
                var parent = data.find(function (i) {
                    return !i.Parent;
                });
                if (parent) {
                    var internalServices = new InternalService(parent);
                    deferred.resolve(internalServices);
                } else {
                    deferred.reject("Parent not found");
                }
            }, function (error) {
                console.warn(error);
                deferred.reject();
            });
            return deferred.promise;
        }

        function fetchInternalServicesHealth() {
            $scope.apps.forEach(function (app) {
                if (app.isIsvc()) {
                    app.fetchInstances().then(function () {
                        resourcesFactory.v2.getInternalServiceStatuses([app.id]).then(function (data) {
                            var statusMap = data.reduce(function (map, s) {
                                map[s.ServiceID] = s;
                                return map;
                            }, {});

                            app.updateStatus(statusMap[app.id]);
                        });
                    });
                }
            });
        }

        function fetchPoolUsage() {
            resourcesFactory.getStorage().then(function (data) {
                var _iteratorNormalCompletion = true;
                var _didIteratorError = false;
                var _iteratorError = undefined;

                try {
                    var _loop = function _loop() {
                        var _step$value = _slicedToArray(_step.value, 2),
                            n = _step$value[0],
                            s = _step$value[1];

                        s.MonitoringProfile.GraphConfigs.forEach(function (g) {
                            if (g.id === "storage.pool.data.usage") {
                                // in the case where we have more than one entry in storage
                                // we need our graph ids to be unique, so concat their index
                                g.id += "." + String(n);
                                $scope.graphConfigs.push(g);
                            }
                        });
                    };

                    for (var _iterator = data.entries()[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                        _loop();
                    }
                } catch (err) {
                    _didIteratorError = true;
                    _iteratorError = err;
                } finally {
                    try {
                        if (!_iteratorNormalCompletion && _iterator.return) {
                            _iterator.return();
                        }
                    } finally {
                        if (_didIteratorError) {
                            throw _iteratorError;
                        }
                    }
                }
            });
        }

        // poll for apps that are being deployed
        $scope.deployingServices = [];
        var lastPollResults = 0;
        function getDeploying() {
            resourcesFactory.getDeployingTemplates().success(function (data) {
                if (data) {
                    $scope.deployingServices = data;
                }

                //if we have fewer results than last poll, we need to refresh our table
                //TODO - better checking for deploying apps
                if (lastPollResults > $scope.deployingServices.length) {
                    refreshApps();
                }
                lastPollResults = $scope.deployingServices.length;
            });
        }

        function removeService(service) {
            return resourcesFactory.removeService(service.id).success(function () {
                // NOTE: this is here because services are
                // incrementally updated, which makes it impossible
                // to determine if a service has been removed
                // TODO - once the backend notifies on deleted
                // services, this should be removed
                // FIXME - should not modify servicesFactory's
                // objects!
                for (var i = 0; i < $scope.apps.length; i++) {
                    // find the removed service and remove it
                    if ($scope.apps[i].id === service.id) {
                        $scope.apps.splice(i, 1);
                        touch();
                        return;
                    }
                }
            });
        }

        function deleteTemplate(templateID) {
            return resourcesFactory.removeAppTemplate(templateID).success(refreshTemplates);
        }

        var lastUpdate;
        function touch() {
            lastUpdate = new Date().getTime();
        }

        // init stuff for this controller
        function init() {
            touch();

            if (utils.needsHostAlias($location.host())) {
                resourcesFactory.getHostAlias().success(function (data) {
                    $scope.defaultHostAlias = data.hostalias;
                });
            }

            // configure tables
            // TODO - move table config to view/directive
            $scope.breadcrumbs = [{ label: 'breadcrumb_deployed', itemClass: 'active' }];

            $scope.servicesTable = {
                sorting: {
                    name: "asc"
                },
                searchColumns: ['name', 'model.Description', 'model.DeploymentID', 'model.PoolID'],
                getData: function getData(data, params) {
                    // use built-in angular filter
                    var orderedData = params.sorting() ? $filter('orderBy')(data, params.orderBy()) : data;

                    if (!orderedData) {
                        return;
                    }

                    // mark any deploying services so they can be treated differently
                    orderedData.forEach(function (service) {
                        service.deploying = false;
                        $scope.deployingServices.forEach(function (deploying) {
                            if (service.model.DeploymentID === deploying.DeploymentID) {
                                service.deploying = true;
                            }
                        });
                    });

                    return orderedData;
                },
                watchExpression: function watchExpression() {
                    // TODO - check $scope.deployingServices as well
                    return lastUpdate;
                }
            };

            $scope.templates = { data: [] };
            // table config
            $scope.templatesTable = {
                sorting: {
                    Name: "asc"
                },
                searchColumns: ['Name', 'ID', 'Description']
            };

            // get configurations for graphs
            $scope.graphConfigs = [];
            fetchPoolUsage();

            // Get a list of templates
            refreshTemplates();

            // check for deploying apps
            getDeploying();

            refreshApps().then(function () {
                $scope.$emit("ready");

                // if only isvcs are deployed, and this is the first time
                // running deploy wizard, show the deploy apps modal
                if (!$cookies.get("autoRunWizardHasRun") && $scope.apps.length === 1) {
                    $scope.modal_deployWizard();
                }
            });

            //register polls
            resourcesFactory.registerPoll("deployingApps", getDeploying, 3000);
            resourcesFactory.registerPoll("templates", refreshTemplates, 5000);
            resourcesFactory.registerPoll("internalServiceHealth", fetchInternalServicesHealth, 3000);
            resourcesFactory.registerPoll("appHealth", fetchServicesHealth, 3000);

            //unregister polls on destroy
            $scope.$on("$destroy", function () {
                resourcesFactory.unregisterAllPolls();
            });

            // be sure to update apps table after deploywiz
            // finishes its dark magicks
            $rootScope.$on("wizard.deployed", function () {
                refreshApps();
            });
        }

        // kick this controller off
        init();

        $scope.$on("$destroy", function () {
            resourcesFactory.unregisterAllPolls();
        });
    }]);
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

(function () {
    'use strict';

    // share angular services outside of angular context

    var $notification = void 0,
        serviceHealth = void 0,
        $q = void 0,
        resourcesFactory = void 0,
        utils = void 0,
        Instance = void 0;

    var MAX_REQUEST_IDS = 15;

    controlplane.factory('Service', ServiceFactory);

    // DesiredState enum
    var START = 1,
        STOP = 0,
        RESTART = -1;

    // service types
    var ISVC = "isvc",
        // internal service
    APP = "app",
        // service with no parent
    META = "meta",
        // service with children but no startup command
    DEPLOYING = "deploying"; // service whose parent is still being deployed

    // Service Current State enum
    var SVCCSUnknown = "unknown",
        SVCCSStopped = "stopped",
        SVCCSPendingStart = "pending_start",
        SVCCSStarting = "starting",
        SVCCSRunning = "started",
        SVCCSPendingRestart = "pending_restart",
        SVCCSRestarting = "restarting",
        SVCCSPendingStop = "pending_stop",
        SVCCSStopping = "stopping",
        SVCCSPendingPause = "pending_pause",
        SVCCSPausing = "pausing",
        SVCCSPaused = "paused";
    //SVCCSPendingEmergencyStop = "pending_emergency_stop",
    //SVCCSEmergencyStopping    = "emergency_stopping",
    //SVCCSEmergencyStopped     = "emergency_stopped";

    // fetch retrieves something from the v2 api
    // endpoint and stores it on the `this` context
    function fetch(methodName, propertyName, force) {
        var _this = this;

        var deferred = $q.defer();

        if (this[propertyName] && !force) {
            deferred.resolve();
            return deferred.promise;
        }
        // NOTE: V2 API only
        // TODO: make sure methodName exists
        resourcesFactory.v2[methodName](this.id).then(function (data) {
            _this[propertyName] = data;
            _this.touch();
            deferred.resolve();
        }, function (error) {
            deferred.reject(error);
            console.warn(error);
        });

        return deferred.promise;
    }

    // given a service, accumulate all descendents into
    // a map keyed by service id
    function getDescendents(descendents, service) {
        service.subservices.forEach(function (svc) {
            getDescendents(descendents, svc);
            descendents[svc.id] = svc;
        });
        return descendents;
    }

    var Service = function () {
        function Service(model) {
            _classCallCheck(this, Service);

            this.subservices = [];
            this.instances = [];
            this.publicEndpoints = [];
            this.update(model);
        }

        _createClass(Service, [{
            key: 'update',
            value: function update(model) {

                // basically new-up with exisiting children and instances
                this.name = model.Name;
                this.id = model.ID;
                this.currentState = model.CurrentState;
                this.desiredState = model.DesiredState;
                this.emergencyShutdown = model.EmergencyShutdown;
                this.model = Object.freeze(model);
                this.evaluateServiceType();
                this.touch();
            }
        }, {
            key: 'evaluateServiceType',
            value: function evaluateServiceType() {
                // infer service type
                this.type = [];
                if (this.model.ID.indexOf("isvc-") !== -1) {
                    this.type.push(ISVC);
                }

                if (!this.model.ParentServiceID) {
                    this.type.push(APP);
                }

                if (this.subservices.length && !this.model.Startup) {
                    this.type.push(META);
                }

                if (this.parent && this.parent.isDeploying()) {
                    this.type.push(DEPLOYING);
                }
            }

            // fills out service object

        }, {
            key: 'fetchAll',
            value: function fetchAll(force) {
                this.fetchEndpoints(force);
                this.fetchAddresses(force);
                this.fetchConfigs(force);
                // NOTE: force-fetching children will wipe
                // out the entire service tree below this service
                this.fetchServiceChildren();
                this.fetchMonitoringProfile(force);
                this.fetchExportEndpoints(force);
            }
        }, {
            key: 'fetchAddresses',
            value: function fetchAddresses(force) {
                fetch.call(this, "getServiceIpAssignments", "addresses", force);
            }
        }, {
            key: 'fetchConfigs',
            value: function fetchConfigs(force) {
                fetch.call(this, "getServiceConfigs", "configs", force);
            }
        }, {
            key: 'fetchEndpoints',
            value: function fetchEndpoints(force) {
                var _this2 = this;

                var deferred = $q.defer();
                var statuses = void 0;
                // kick off request for statuses for public endpoint
                // service statuses
                this.getEndpointStatuses().then(function (s) {
                    s = s || [];
                    // convert array of endpoint service statuses
                    // to a map of serviceid -> endpoint status
                    statuses = s.reduce(function (acc, s) {
                        acc[s.ServiceID] = s;
                        return acc;
                    }, {});
                })
                // kick off request for public endpoints
                .then(function () {
                    return resourcesFactory.v2.getServicePublicEndpoints(_this2.id);
                }).then(function (response) {
                    _this2.publicEndpoints = response.map(function (ept) {
                        // TODO - dont modify model data :(
                        ept.Value = ept.ServiceName + ' - ' + ept.Application;
                        // if this endpoint has a service status,
                        // add that service's desiredState so that
                        // the endpoint knows if its accessible or not
                        if (statuses[ept.ServiceID]) {
                            ept.desiredState = statuses[ept.ServiceID].DesiredState;
                        }
                        return ept;
                    });
                    deferred.resolve();
                }).catch(function (error) {
                    console.warn(error);
                    deferred.reject();
                });
                return deferred.promise;
            }
        }, {
            key: 'fetchExportEndpoints',
            value: function fetchExportEndpoints(force) {
                var _this3 = this;

                var deferred = $q.defer();
                resourcesFactory.v2.getServiceExportEndpoints(this.id).then(function (response) {
                    _this3.exportedServiceEndpoints = response.filter(function (ept) {
                        return ept.Protocol === "tcp";
                    }).map(function (ept) {
                        // TODO - dont modify model data :(
                        ept.Value = ept.ServiceName + ' - ' + ept.Application;
                        return ept;
                    });
                    deferred.resolve();
                }, function (error) {
                    console.warn(error);
                    deferred.reject();
                });

                return deferred.promise;
            }
        }, {
            key: 'fetchMonitoringProfile',
            value: function fetchMonitoringProfile(force) {
                fetch.call(this, "getServiceMonitoringProfile", "monitoringProfile", force);
            }
        }, {
            key: 'fetchInstances',
            value: function fetchInstances() {
                var _this4 = this;

                var deferred = $q.defer();
                resourcesFactory.v2.getServiceInstances(this.id).then(function (results) {
                    if (results.length < _this4.instances.length) {
                        // If our results count decreased, we need to refresh our data to
                        // eliminate stale data (ie: iid [0, 1] and 0 drops off).
                        _this4.instances = [];
                    }
                    results.forEach(function (data) {
                        // new-ing instances will cause UI bounce and force rebuilding
                        // of the popover. To minimize UI churn, update/merge status info
                        // into exisiting instance objects
                        var iid = data.InstanceID;
                        if (_this4.instances[iid]) {
                            _this4.instances[iid].update(data);
                        } else {
                            // add into the proper instance slot here
                            _this4.instances[iid] = new Instance(data);
                        }
                    });
                    deferred.resolve();
                }, function (error) {
                    console.warn(error);
                    deferred.reject();
                });

                return deferred.promise;
            }
        }, {
            key: 'fetchServiceChildren',
            value: function fetchServiceChildren(force) {
                var _this5 = this;

                var deferred = $q.defer();
                if (this.subservices.length && !force) {
                    deferred.resolve();
                }
                resourcesFactory.v2.getServiceChildren(this.id).then(function (data) {
                    // TODO - dont blow away existing children
                    _this5.subservices = data.map(function (s) {
                        return new Service(s);
                    });
                    _this5.touch();
                    deferred.resolve();
                }, function (error) {
                    console.warn(error);
                    deferred.reject();
                });
                return deferred.promise;
            }

            // fast-moving state for this service and its instances
            // note: returns a promise that resolves with a single status object

        }, {
            key: 'getStatus',
            value: function getStatus() {
                var _this6 = this;

                var deferred = $q.defer();

                resourcesFactory.v2.getServiceStatus(this.id).then(function (results) {
                    if (results.length) {
                        // getServiceStatus returns an array of results
                        // but we only want a single result
                        deferred.resolve(results[0]);
                    } else {
                        deferred.reject('Could not get service status for id ' + _this6.id);
                    }
                }, function (error) {
                    deferred.reject(error);
                });
                return deferred.promise;
            }
        }, {
            key: 'getEndpointStatuses',
            value: function getEndpointStatuses() {
                var eps = this.publicEndpoints.reduce(function (acc, ep) {
                    acc[ep.ServiceID] = ep;
                    return acc;
                }, {});
                var ids = Object.keys(eps);
                return this.getServiceStatuses(ids);
            }

            // fetch and update service statuses for all
            // descendents of this service

        }, {
            key: 'updateDescendentStatuses',
            value: function updateDescendentStatuses() {
                var deferred = $q.defer();
                var descendents = getDescendents({}, this);
                var ids = Object.keys(descendents);
                this.getServiceStatuses(ids).then(function (results) {
                    if (results && results.length) {
                        results.forEach(function (stat) {
                            // TODO - handle stat.NotFound
                            var svc = descendents[stat.ServiceID];
                            svc.updateState(stat);
                        });
                        deferred.resolve();
                    }
                }, function (error) {
                    deferred.reject(error);
                });
                return deferred.promise;
            }

            // the list of ids can get extrememly long, which
            // can push the acceptable limits of URL length,
            // so split the request up

        }, {
            key: 'getServiceStatuses',
            value: function getServiceStatuses(ids) {
                var promises = [];

                var count = Math.ceil(ids.length / MAX_REQUEST_IDS);
                for (var i = 0; i < count; i++) {
                    var start = i * MAX_REQUEST_IDS;
                    // either slice to the end of this array, or
                    // the next MAX_REQUEST_IDS elements
                    var end = Math.min(start + MAX_REQUEST_IDS, ids.length);
                    var idsSlice = ids.slice(start, end);
                    promises.push(resourcesFactory.v2.getServiceStatuses(idsSlice));
                }

                // NOTE - this will cancel all on the first failure
                // which may not be the desired behavior
                var all = $q.all(promises).then(function (results) {
                    // results will be an array of results, one
                    // for each promise. the caller is expecting
                    // a single array of results, so lets squish
                    // em all together
                    var statuses = results.reduce(function (arr, r) {
                        return arr.concat(r);
                    }, []);
                    return $q.when(statuses);
                }).catch(function (err) {
                    console.warn("failure getting service statuses", err);
                });

                // TODO - optionally return [all, promises]
                return all;
            }
        }, {
            key: 'hasInstances',
            value: function hasInstances() {
                return !!this.instances.length;
            }
        }, {
            key: 'isIsvc',
            value: function isIsvc() {
                return !!~this.type.indexOf(ISVC);
            }
        }, {
            key: 'hasChildren',
            value: function hasChildren() {
                return this.model.HasChildren;
            }
        }, {
            key: 'isContainer',
            value: function isContainer() {
                return this.hasChildren() && !this.model.Startup;
            }

            // start, stop, or restart this service

        }, {
            key: 'start',
            value: function start(skipChildren) {
                var _this7 = this;

                var promise = resourcesFactory.startService(this.id, skipChildren),
                    oldDesiredState = this.desiredState;

                this.desiredState = START;

                // if something breaks, return desired
                // state to its previous value
                return promise.error(function () {
                    _this7.desiredState = oldDesiredState;
                });
            }
        }, {
            key: 'stop',
            value: function stop(skipChildren) {
                var _this8 = this;

                var promise = resourcesFactory.stopService(this.id, skipChildren),
                    oldDesiredState = this.desiredState;

                this.desiredState = STOP;

                // if something breaks, return desired
                // state to its previous value
                return promise.error(function () {
                    _this8.desiredState = oldDesiredState;
                });
            }
        }, {
            key: 'restart',
            value: function restart(skipChildren) {
                var _this9 = this;

                var promise = resourcesFactory.restartService(this.id, skipChildren),
                    oldDesiredState = this.desiredState;

                this.desiredState = RESTART;

                // if something breaks, return desired
                // state to its previous value
                return promise.error(function () {
                    _this9.desiredState = oldDesiredState;
                });
            }
        }, {
            key: 'stopInstance',
            value: function stopInstance(instance) {
                var _this10 = this;

                resourcesFactory.killRunning(instance.model.HostID, instance.id).success(function () {
                    _this10.touch();
                }).error(function (data, status) {
                    var detail = data.Detail || data || "";
                    $notification.create("Stop Instance failed", detail).error();
                });
            }
        }, {
            key: 'cancelPending',
            value: function cancelPending() {
                if (this.currentState === "pending_start") {
                    return this.stop();
                } else if (this.currentState === "pending_stop") {
                    return this.start();
                } else if (this.currentState === "pending_restart") {
                    return this.start();
                }
            }

            // mark services updated to trigger render via $watch

        }, {
            key: 'touch',
            value: function touch() {
                this.lastUpdate = new Date().getTime();
            }

            // kicks off request to update fast-moving instances and service state

        }, {
            key: 'fetchAllStates',
            value: function fetchAllStates() {
                var _this11 = this;

                return $q.all([this.fetchInstances(), this.getStatus(), this.getEndpointStatuses()]).then(function (results) {
                    var myStatus = results[1],
                        otherStatuses = results[2];
                    _this11.updateState(myStatus, otherStatuses);
                }, function (error) {
                    console.warn("Unable to fetch instance states");
                });
            }

            // update fast-moving service and instance state

        }, {
            key: 'updateState',
            value: function updateState(myStatus, otherStatuses) {
                var _this12 = this;

                // update service status
                this.desiredState = myStatus.DesiredState;
                this.currentState = myStatus.CurrentState;
                this.emergencyShutdown = myStatus.EmergencyShutdown;

                // update public endpoints
                if (otherStatuses) {
                    otherStatuses = otherStatuses.reduce(function (acc, s) {
                        acc[s.ServiceID] = s;
                        return acc;
                    }, {});
                    this.publicEndpoints.forEach(function (ept) {
                        ept.desiredState = otherStatuses[ept.ServiceID].DesiredState;
                    });
                }

                var instanceMap = this.instances.reduce(function (map, i) {
                    map[i.model.InstanceID] = i;
                    return map;
                }, {});

                // iterate instance health and either update the service
                // instance with the health, or create a temporary instace
                // object to hold the health for evaluation
                var instances = [];
                myStatus.Status.forEach(function (instanceStatus) {
                    var instance = instanceMap[instanceStatus.InstanceID];
                    if (!instance) {
                        // create a temporary instance object to
                        // use the status object
                        instance = new Instance({
                            InstanceID: instanceStatus.InstanceID,
                            ServiceID: _this12.id,
                            HealthStatus: instanceStatus.HealthStatus,
                            MemoryUsage: instanceStatus.MemoryUsage,
                            // NOTE - fake values!
                            HostID: 0,
                            RAMCommitment: myStatus.RAMCommitment
                        });
                    }
                    instance.updateState(instanceStatus);
                    instances.push(instance);
                });

                // get health for this service and its instances
                this.status = serviceHealth.evaluate(this, instances);
                this.resourcesGood = true;
                for (var i = 0; i < instances.length; i++) {
                    if (!instances[i].resourcesGood()) {
                        this.resourcesGood = false;
                        break;
                    }
                }

                this.touch();
            }
        }]);

        return Service;
    }();

    // class methods

    // Returns counts for affected descendants if they click on the
    // 'start all', 'stop all', 'restart all' buttons.


    Service.countAffectedDescendants = function (service, state) {
        var deferred = $q.defer();
        resourcesFactory.v2.getDescendantCounts(service.id).then(function (data, status) {
            var count = 0;
            switch (state) {
                case "start":
                    // Start only affects these states, with the "auto" start method.
                    var affected = [SVCCSUnknown, SVCCSStopped, SVCCSPendingStart, SVCCSPendingRestart, SVCCSRestarting, SVCCSPendingStop, SVCCSStopping, SVCCSPendingPause, SVCCSPausing, SVCCSPaused];
                    if (data.auto) {
                        affected.forEach(function (s) {
                            count += data.auto[s] || 0;
                        });
                    }
                    break;
                case "restart":
                    // Restart will restart services with any of these states, both manual and auto started.
                    var affected = [SVCCSUnknown, SVCCSStopped, SVCCSPendingStart, SVCCSStarting, SVCCSRunning, SVCCSPendingRestart, SVCCSPendingStop, SVCCSStopping, SVCCSPendingPause, SVCCSPausing, SVCCSPaused];
                    if (data.auto) {
                        affected.forEach(function (s) {
                            count += data.auto[s] || 0;
                        });
                    }
                    if (data.manual) {
                        affected.forEach(function (s) {
                            count += data.manual[s] || 0;
                        });
                    }
                    break;
                case "stop":
                    // Stop will stop all services with any of these states, both manual and auto started.
                    var affected = [SVCCSUnknown, SVCCSPendingStart, SVCCSStarting, SVCCSRunning, SVCCSPendingRestart, SVCCSRestarting, SVCCSPendingStop, SVCCSPendingPause, SVCCSPausing, SVCCSPaused];
                    if (data.auto) {
                        affected.forEach(function (s) {
                            count += data.auto[s] || 0;
                        });
                    }
                    if (data.manual) {
                        affected.forEach(function (s) {
                            count += data.manual[s] || 0;
                        });
                    }
                    break;
            }
            deferred.resolve(count);
        }).catch(function (data, status) {
            deferred.reject(data);
        });
        return deferred.promise;
    };

    ServiceFactory.$inject = ['$notification', '$serviceHealth', '$q', 'resourcesFactory', 'miscUtils', 'Instance'];
    function ServiceFactory(_$notification, _serviceHealth, _$q, _resourcesFactory, _utils, _Instance) {

        // api access via angular context
        $notification = _$notification;
        serviceHealth = _serviceHealth;
        $q = _$q;
        resourcesFactory = _resourcesFactory;
        utils = _utils;
        Instance = _Instance;

        return Service;
    }
})();
"use strict";

/* globals controlplane: true */

/* ServiceDetailsController
 * Displays details of a specific service
 */
(function () {
    'use strict';

    // share angular services outside of angular context

    var $notification = void 0,
        $q = void 0,
        resourcesFactory = void 0,
        utils = void 0;

    controlplane.controller("ServiceDetailsController", ["$scope", "$q", "$routeParams", "$location", "resourcesFactory", "authService", "$modalService", "$translate", "$notification", "$timeout", "miscUtils", "Service", "CCUIState", "$cookies", "areUIReady", "LogSearch", "$filter", "Pool", function ($scope, _$q, $routeParams, $location, _resourcesFactory, authService, $modalService, $translate, _$notification, $timeout, _utils, Service, CCUIState, $cookies, areUIReady, LogSearch, $filter, Pool) {

        // api access via angular context
        $notification = _$notification;
        $q = _$q;
        resourcesFactory = _resourcesFactory;
        utils = _utils;

        // Ensure logged in
        authService.checkLogin($scope);

        $scope.defaultHostAlias = $location.host();
        if (utils.needsHostAlias($location.host())) {
            resourcesFactory.getHostAlias().success(function (data) {
                $scope.defaultHostAlias = data.hostalias;
            });
        }

        //add Public Endpoint data
        $scope.publicEndpoints = { add: {} };

        //add service endpoint data
        $scope.exportedServiceEndpoints = {};

        $scope.clickPool = function (id) {
            resourcesFactory.routeToPool(id);
        };

        $scope.clickHost = function (id) {
            resourcesFactory.routeToHost(id);
        };

        $scope.modalAddPublicEndpoint = function () {

            areUIReady.lock();
            $scope.protocols = [];
            $scope.protocols.push({ Label: "HTTPS", UseTLS: true, Protocol: "https" });
            $scope.protocols.push({ Label: "HTTP", UseTLS: false, Protocol: "http" });
            $scope.protocols.push({ Label: "Other, secure (TLS)", UseTLS: true, Protocol: "" });
            $scope.protocols.push({ Label: "Other, non-secure", UseTLS: false, Protocol: "" });

            // default public endpoint options
            $scope.publicEndpoints.add = {
                type: "port",
                endpoint: $scope.currentService.exportedServiceEndpoints[0],
                name: "",
                host: $scope.defaultHostAlias,
                port: "",
                protocol: $scope.protocols[0]
            };

            // returns an error string if newPublicEndpoint's vhost is invalid
            var validateVHost = function validateVHost(newPublicEndpoint) {
                var name = newPublicEndpoint.name;

                // if no port
                if (!name || !name.length) {
                    return "Missing Name";
                }

                // if name already exists
                for (var i in $scope.publicEndpoints.data) {
                    if (name === $scope.publicEndpoints.data[i].Name) {
                        return "Name already exists: " + newPublicEndpoint.name;
                    }
                }

                // if invalid characters
                var re = /^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$/;
                if (!re.test(name)) {
                    return $translate.instant("vhost_name_invalid") + " " + utils.escapeHTML(newPublicEndpoint.name);
                }
            };

            // returns an error string if newPublicEndpoint's port is invalid
            var validatePort = function validatePort(newPublicEndpoint) {
                var host = newPublicEndpoint.host;
                var port = newPublicEndpoint.port;

                if (!host || !host.length) {
                    return "Missing host name";
                }

                // if invalid characters
                var re = /^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$/;
                if (!re.test(host)) {
                    return $translate.instant("host_name_invalid") + ": " + utils.escapeHTML(host);
                }

                // if no port
                if (!port || !port.length) {
                    return "Missing port";
                }

                if (+port < 1 || +port > 65536) {
                    return "Port must be between 1 and 65536";
                }
            };

            $modalService.create({
                templateUrl: "add-public-endpoint.html",
                model: $scope,
                title: "add_public_endpoint",
                actions: [{
                    role: "cancel",
                    action: function action() {
                        this.close();
                    }
                }, {
                    role: "ok",
                    label: "add_public_endpoint_confirm",
                    action: function action() {
                        var newPublicEndpoint = $scope.publicEndpoints.add;

                        if (this.validate(newPublicEndpoint)) {
                            // disable ok button, and store the re-enable function
                            var enableSubmit = this.disableSubmitButton();

                            $scope.addPublicEndpoint(newPublicEndpoint).success(function (data, status) {
                                // reload the table
                                refreshEndpoints();
                                $notification.create("Added public endpoint").success();
                                this.close();
                            }.bind(this)).error(function (data, status) {
                                this.createNotification("Unable to add public endpoint", data.Detail).error();
                                enableSubmit();
                            }.bind(this));
                        }
                    }
                }],

                validate: function validate(newPublicEndpoint) {
                    // if no service endpoint selected
                    if (!newPublicEndpoint.endpoint) {
                        this.createNotification("Unable to add Public Endpoint", "No service endpoint selected").error();
                        return false;
                    }

                    // perform type specific validation
                    if (newPublicEndpoint.type === "vhost") {
                        var err = validateVHost(newPublicEndpoint);
                        if (err) {
                            this.createNotification("Unable to add Public Endpoint", err).error();
                        } else {
                            return true;
                        }
                    } else if (newPublicEndpoint.type === "port") {
                        var err = validatePort(newPublicEndpoint);
                        if (err) {
                            this.createNotification("Unable to add Public Endpoint", err).error();
                            return false;
                        } else {
                            return true;
                        }
                    }
                },
                onShow: function onShow() {
                    areUIReady.unlock();
                }
            });
        };

        $scope.addPublicEndpoint = function (newPublicEndpoint) {
            var serviceId = newPublicEndpoint.endpoint.ServiceID;
            var serviceName = newPublicEndpoint.endpoint.ServiceName;
            var serviceEndpoint = newPublicEndpoint.endpoint.Application;
            if (newPublicEndpoint.type === "vhost") {
                var vhostName = newPublicEndpoint.name;
                return resourcesFactory.addVHost(serviceId, serviceName, serviceEndpoint, vhostName);
            } else if (newPublicEndpoint.type === "port") {
                var port = newPublicEndpoint.host + ":" + newPublicEndpoint.port;
                var usetls = newPublicEndpoint.protocol.UseTLS;
                var protocol = newPublicEndpoint.protocol.Protocol;
                return resourcesFactory.addPort(serviceId, serviceName, serviceEndpoint, port, usetls, protocol);
            }
        };

        // modalAssignIP opens a modal view to assign an ip address to a service
        $scope.modalAssignIP = function (ip, poolID) {
            var modalScope = $scope.$new(true);
            modalScope.assignments = { 'ip': ip, 'value': null };
            resourcesFactory.getPoolIPs(poolID).success(function (data) {
                var options = [{ 'Value': 'Automatic', 'IPAddr': '' }];
                var i = void 0,
                    IPAddr = void 0,
                    value = void 0;
                //host ips
                if (data && data.HostIPs) {
                    for (i = 0; i < data.HostIPs.length; ++i) {
                        IPAddr = data.HostIPs[i].IPAddress;
                        value = 'Host: ' + IPAddr + ' - ' + data.HostIPs[i].InterfaceName;
                        options.push({ 'Value': value, 'IPAddr': IPAddr });
                        modalScope.assignments.ip.Application = ip.Application;

                        // set the default value to the currently assigned value
                        if (modalScope.assignments.ip.IPAddress === IPAddr) {
                            modalScope.assignments.value = options[options.length - 1];
                        }
                    }
                }

                //virtual ips
                if (data && data.VirtualIPs) {
                    for (i = 0; i < data.VirtualIPs.length; ++i) {
                        IPAddr = data.VirtualIPs[i].IP;
                        value = "Virtual IP: " + IPAddr;
                        options.push({ 'Value': value, 'IPAddr': IPAddr });
                        // set the default value to the currently assigned value
                        if (modalScope.assignments.ip.IPAddr === IPAddr) {
                            modalScope.assignments.value = options[options.length - 1];
                        }
                    }
                }

                //default to automatic if necessary
                if (!modalScope.assignments.value) {
                    modalScope.assignments.value = options[0];
                }
                modalScope.assignments.options = options;

                $modalService.create({
                    templateUrl: "assign-ip.html",
                    model: modalScope,
                    title: "assign_ip",
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        label: "assign_ip",
                        action: function action() {
                            if (this.validate()) {
                                // disable ok button, and store the re-enable function
                                var enableSubmit = this.disableSubmitButton();

                                var serviceID = modalScope.assignments.ip.ServiceID;
                                var IP = modalScope.assignments.value.IPAddr;
                                resourcesFactory.assignIP(serviceID, IP).success(function (data, status) {
                                    $notification.create("Added IP", data.Detail).success();
                                    $scope.currentService.fetchAddresses(true);
                                    this.close();
                                }.bind(this)).error(function (data, status) {
                                    this.createNotification("Unable to Assign IP", data.Detail).error();
                                    enableSubmit();
                                }.bind(this));
                            }
                        }
                    }]
                });
            }).error(function (data, status) {
                $notification.create("Unable to retrieve IPs", data.Detail).error();
            });
        };

        $scope.anyServicesExported = function (service) {
            if ($scope.currentService && $scope.currentService.exportedServiceEndpoints) {
                return $scope.currentService.exportedServiceEndpoints.length > 0;
            } else {
                return false;
            }
        };

        $scope.publicEndpointProtocol = function (publicEndpoint) {
            if ($scope.getEndpointType(publicEndpoint) === "vhost") {
                return "https";
            } else {
                if (publicEndpoint.Protocol !== "") {
                    return publicEndpoint.Protocol;
                }
                if (publicEndpoint.UseTLS) {
                    return "other (TLS)";
                }
                return "other";
            }
        };

        $scope.indent = function (depth) {
            return { 'padding-left': 24 * depth + "px" };
        };

        // sets a service to start, stop or restart state
        $scope.setServiceState = function (service, state, skipChildren) {
            // service[state]() ends up translating to something like
            // service.start() or service.stop()
            service[state](skipChildren).error(function (data, status) {
                $notification.create("Unable to " + state + " service", data.Detail).error();
            });
        };

        $scope.getEndpointType = function (endpoint) {
            return endpoint.VHostName ? "vhost" : "port";
        };

        // clicks to a service's start, stop, or restart
        // button should first determine if the service has
        // children and ask the user to choose to start all
        // children or only the top service
        $scope.clickRunning = function (service, state, force) {
            // if force, we dont need no stinkin confirmation
            // from the user.
            if (force) {
                $scope.setServiceState(service, state);
                return;
            }

            var onStartService = function onStartService(modal) {
                // the arg here explicitly prevents child services
                // from being started
                $scope.setServiceState(service, state, true);
                modal.close();
            };
            var onStartServiceAndChildren = function onStartServiceAndChildren(modal) {
                $scope.setServiceState(service, state);
                modal.close();
            };

            Service.countAffectedDescendants(service, state).then(function (count) {
                $modalService.modals.confirmServiceStateChange(service, state, count, onStartService, onStartServiceAndChildren);
            }).catch(function (err) {
                console.warn("couldnt get descendant count", err);
                $modalService.modals.confirmServiceStateChange(service, state, 0, onStartService, onStartServiceAndChildren);
            });

            // let the user know they gonna have to hold onto
            // their horses for just one moment.
            $modalService.modals.oneMoment();
        };

        $scope.clickEndpointEnable = function (publicEndpoint) {
            if ($scope.getEndpointType(publicEndpoint) === "vhost") {
                resourcesFactory.enableVHost(publicEndpoint.ServiceID, publicEndpoint.ServiceName, publicEndpoint.Application, publicEndpoint.VHostName).success(function () {
                    // reload the table
                    refreshEndpoints();
                }).error(function (data, status) {
                    $notification.create("Enable Public Endpoint failed", data.Detail).error();
                });
            } else if ($scope.getEndpointType(publicEndpoint) === "port") {
                resourcesFactory.enablePort(publicEndpoint.ServiceID, publicEndpoint.ServiceName, publicEndpoint.Application, publicEndpoint.PortAddress).success(function () {
                    // reload the table
                    refreshEndpoints();
                }).error(function (data, status) {
                    $notification.create("Enable Public Endpoint failed", data.Detail).error();
                });
            }
        };

        $scope.clickEndpointDisable = function (publicEndpoint) {
            if ($scope.getEndpointType(publicEndpoint) === "vhost") {
                resourcesFactory.disableVHost(publicEndpoint.ServiceID, publicEndpoint.ServiceName, publicEndpoint.Application, publicEndpoint.VHostName).success(function () {
                    // reload the table
                    refreshEndpoints();
                }).error(function (data, status) {
                    $notification.create("Disable Public Endpoint failed", data.Detail).error();
                });
            } else if ($scope.getEndpointType(publicEndpoint) === "port") {
                resourcesFactory.disablePort(publicEndpoint.ServiceID, publicEndpoint.ServiceName, publicEndpoint.Application, publicEndpoint.PortAddress).success(function () {
                    // reload the table
                    refreshEndpoints();
                }).error(function (data, status) {
                    $notification.create("Disable Public Endpoint failed", data.Detail).error();
                });
            }
        };

        $scope.clickEditContext = function (contextFileId) {
            //edit variables (context) of current service
            var modalScope = $scope.$new(true);

            resourcesFactory.v2.getServiceContext(contextFileId).then(function (data) {

                //set editor options for context editing
                modalScope.codemirrorOpts = {
                    lineNumbers: true,
                    mode: "properties"
                };

                // this is the text bound to the modal texarea
                modalScope.Context = makeEditableContext(data);

                // now that we have the text of the file, create modal dialog
                $modalService.create({
                    templateUrl: "edit-context.html",
                    model: modalScope,
                    title: $translate.instant("edit_context"),
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        label: $translate.instant("btn_save"),
                        action: function action() {
                            // disable ok button, and store the re-enable function
                            var enableSubmit = this.disableSubmitButton();
                            var storableContext = makeStorableContext(modalScope.Context);

                            resourcesFactory.v2.updateServiceContext(contextFileId, storableContext).success(function (data, status) {
                                $notification.create("Updated variables for", $scope.currentService.name).success();
                                this.close();
                            }.bind(this)).error(function (data, status) {
                                this.createNotification("Update variables failed", data.Detail).error();
                                enableSubmit();
                            }.bind(this));
                        }
                    }],
                    onShow: function onShow() {
                        modalScope.codemirrorRefresh = true;
                        modalScope.$apply();
                    },
                    onHide: function onHide() {
                        modalScope.codemirrorRefresh = false;
                    }
                });
            });
        };

        function makeEditableContext(context) {
            var editableContext = "";
            for (var key in context) {
                editableContext += key + " " + context[key] + "\n";
            }
            if (!editableContext) {
                editableContext = "";
            }
            return editableContext;
        }

        function makeStorableContext(context) {
            //turn editableContext into a JSON object
            var lines = context.split("\n"),
                storable = {};

            lines.forEach(function (line) {
                var delimitIndex, key, val;

                if (line !== "") {
                    delimitIndex = line.indexOf(" ");
                    if (delimitIndex !== -1) {
                        key = line.substr(0, delimitIndex);
                        val = line.substr(delimitIndex + 1);
                        storable[key] = val;
                    } else {
                        context[line] = "";
                    }
                }
            });

            return JSON.stringify(storable);
        }

        $scope.clickRemovePublicEndpoint = function (publicEndpoint) {

            $modalService.create({
                template: $translate.instant("remove_public_endpoint") + ": <strong>" + (publicEndpoint.ServiceName ? publicEndpoint.ServiceName : "port " + publicEndpoint.PortAddress) + "</strong><br><br>",
                model: $scope,
                title: "remove_public_endpoint",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "remove_public_endpoint_confirm",
                    classes: "btn-danger",
                    action: function action() {
                        if ($scope.getEndpointType(publicEndpoint) === "vhost") {
                            resourcesFactory.removeVHost(publicEndpoint.ServiceID, publicEndpoint.Application, publicEndpoint.VHostName).success(function () {
                                // reload the table
                                refreshEndpoints();
                                $notification.create("Removed Public Endpoint", publicEndpoint.Application).success();
                            }).error(function (data, status) {
                                $notification.create("Remove Public Endpoint failed", data.Detail).error();
                            });
                        } else if ($scope.getEndpointType(publicEndpoint) === "port") {
                            resourcesFactory.removePort(publicEndpoint.ServiceID, publicEndpoint.Application, publicEndpoint.PortAddress).success(function () {
                                // reload the table
                                refreshEndpoints();
                                $notification.create("Removed Public Endpoint", publicEndpoint.PortName).success();
                            }).error(function (data, status) {
                                $notification.create("Remove Public Endpoint failed", data.Detail).error();
                            });
                        }
                        this.close();
                    }
                }]
            });
        };

        $scope.editConfig = function (configFileId) {
            var modalScope = $scope.$new(true);

            // TODO - pop the modal up FIRST and show
            // a loading animation while the request is filled
            resourcesFactory.v2.getServiceConfig(configFileId).then(function (data) {

                //set editor options for context editing
                modalScope.codemirrorOpts = {
                    lineNumbers: true,
                    mode: utils.getModeFromFilename(data.Filename)
                };

                // this is the text bound to the modal texarea
                angular.extend(modalScope, data);

                // now that we have the text of the file, create modal dialog
                $modalService.create({
                    templateUrl: "edit-config.html",
                    model: modalScope,
                    title: $translate.instant("title_edit_config") + " - " + modalScope.Filename,
                    bigModal: true,
                    actions: [{
                        role: "cancel"
                    }, {
                        role: "ok",
                        label: $translate.instant("btn_save"),
                        action: function action() {
                            if (this.validate()) {
                                // disable ok button, and store the re-enable function
                                var enableSubmit = this.disableSubmitButton();

                                resourcesFactory.v2.updateServiceConfig(configFileId, modalScope).success(function (data, status) {
                                    $notification.create("Updated configuration file", data.Filename).success();
                                    this.close();
                                }.bind(this)).error(function (data, status) {
                                    this.createNotification("Update configuration failed", data.Detail).error();
                                    enableSubmit();
                                }.bind(this));
                            }
                        }
                    }],
                    validate: function validate() {
                        // TODO - actually validate
                        return true;
                    },
                    onShow: function onShow() {
                        modalScope.codemirrorRefresh = true;
                        modalScope.$apply();
                    },
                    onHide: function onHide() {
                        modalScope.codemirrorRefresh = false;
                    }
                });
            });
        };

        $scope.viewLog = function (instance) {
            var logScope = $scope.$new(true);

            resourcesFactory.getInstanceLogs(instance.model.ServiceID, instance.id).success(function (log) {
                logScope.log = log.Detail;
                $modalService.create({
                    templateUrl: "view-log.html",
                    model: logScope,
                    title: "title_log",
                    bigModal: true,
                    actions: [{
                        role: "cancel",
                        label: "close"
                    }, {
                        classes: "btn-primary",
                        label: "refresh",
                        icon: "glyphicon-repeat",
                        action: function action() {
                            var _this = this;

                            var textarea = this.$el.find("textarea");
                            resourcesFactory.getInstanceLogs(instance.model.ServiceID, instance.id).success(function (log) {
                                logScope.log = log.Detail;
                                textarea.scrollTop(textarea[0].scrollHeight - textarea.height());
                            }).error(function (data, status) {
                                _this.createNotification("Unable to fetch logs", data.Detail).error();
                            });
                        }
                    }, {
                        classes: "btn-primary",
                        label: "download",
                        action: function action() {
                            utils.downloadFile('/services/' + instance.model.ServiceID + '/' + instance.id + '/logs/download');
                        },
                        icon: "glyphicon-download"
                    }],
                    onShow: function onShow() {
                        var textarea = this.$el.find("textarea");
                        textarea.scrollTop(textarea[0].scrollHeight - textarea.height());
                    }
                });
            }).error(function (data, status) {
                $notification.create("Unable to fetch logs", data.Detail).error();
            });
        };

        $scope.subNavClick = function (crumb) {
            if (crumb.id) {
                $scope.routeToService(crumb.id);
            } else {
                // TODO - just call subnavs usual function
                $location.path(crumb.url);
            }
        };

        // grab default kibana search configs and adjust
        // the query to look for this specific service
        $scope.getServiceLogURL = function (service) {
            if (!service) {
                return "";
            }
            var appConfig = LogSearch.getDefaultAppConfig(),
                globalConfig = LogSearch.getDefaultGlobalConfig();

            appConfig.query = {
                query_string: {
                    analyze_wildcard: true,
                    query: "fields.service:" + service.id + " AND fields.instance:*"
                }
            };
            appConfig.columns = ["fields.instance", "message"];

            return LogSearch.getURL(appConfig, globalConfig);
        };

        // grab default kibana search configs and adjust
        // the query to look for this specific service instance
        $scope.getInstanceLogURL = function (instance) {
            var appConfig = LogSearch.getDefaultAppConfig(),
                globalConfig = LogSearch.getDefaultGlobalConfig();

            appConfig.query = {
                query_string: {
                    analyze_wildcard: true,
                    query: "fields.service:" + instance.model.ServiceID + " AND fields.instance:" + instance.model.InstanceID
                }
            };
            appConfig.columns = ["message"];

            return LogSearch.getURL(appConfig, globalConfig);
        };

        // updates URL and current service ID
        // which triggers UI update
        $scope.routeToService = function (id, e) {
            // if an event is present, we may
            // need to prevent it from performing
            // default navigation behavior
            if (e) {
                // ctrl click opens in new tab,
                // so allow that to happen and don't
                // bother routing the current view
                if (e.ctrlKey) {
                    return;
                }

                // if middle click, don't update
                // current view
                if (e.button === 1) {
                    return;
                }

                // otherwise, prevent default so
                // we can handle the view routing
                e.preventDefault();
            }

            $location.update_path("/services/" + id, true);
            $scope.params.serviceId = id;
        };

        // restart all running instances for this service
        $scope.killRunningInstances = function (app) {
            resourcesFactory.restartService(app.ID).error(function (data, status) {
                $notification.create("Stop Service failed", data.Detail).error();
            });
        };

        $scope.hostNames = {};
        $scope.getHostName = function (id) {
            return $scope.hostNames[id];
        };

        // expand/collapse state of service tree nodes
        $scope.serviceTreeState = CCUIState.get($cookies.get("ZUsername"), "serviceTreeState");
        // servicedTreeState is a collection of objects
        // describing if nodes in a service tree are hidden or collapsed.
        // It is first keyed by the id of the current service context (the
        // service who's name is at the top of the page), then keyed by
        // the service in question. eg:
        //
        // current service id
        //      -> desendant service id
        //          -> hidden
        //          -> collapsed
        //          -> parentId
        //      -> desendant service id
        //          -> hidden
        //          -> collapsed
        //          -> parentId
        //      ...

        $scope.toggleChildren = function (service) {
            if (!$scope.currentService) {
                console.warn("Cannot store toggle state: no current service");
                return;
            }
            if ($scope.currentTreeState[service.id].collapsed) {
                $scope.currentTreeState[service.id].collapsed = false;

                if (service.subservices.length) {
                    $scope.showChildren(service);
                } else {
                    // show loading animation row
                    $scope.currentTreeState[service.id].isLoading = true;
                    $scope.flattenServicesTree();
                    service.fetchServiceChildren().then(function () {
                        // remove loading animation row
                        $scope.currentTreeState[service.id].isLoading = false;
                        $scope.flattenServicesTree();
                        $scope.currentService.updateDescendentStatuses();
                        service.subservices.forEach(function (sub) {
                            $scope.currentTreeState[sub.id].parentId = service.id;
                            $scope.currentTreeState[sub.id].hidden = false;
                        });
                    });
                }
            } else {
                $scope.currentTreeState[service.id].collapsed = true;
                $scope.flattenServicesTree();
                $scope.currentService.updateDescendentStatuses();
                $scope.hideChildren(service);
            }
        };

        $scope.hideChildren = function (service) {
            // get the state of the current service's tree
            var treeState = $scope.currentTreeState;

            if (service.subservices.length) {
                service.subservices.forEach(function (child) {
                    treeState[child.id].hidden = true;
                    $scope.hideChildren(child);
                });
            }
        };

        $scope.showChildren = function (service) {
            var treeState = $scope.currentTreeState;

            if (service.subservices.length) {
                service.subservices.forEach(function (child) {
                    treeState[child.id].hidden = false;

                    // if this child service is not marked
                    // as collapsed, show its children
                    if (!treeState[child.id].collapsed) {
                        $scope.showChildren(child);
                    }
                });
            }
        };

        $scope.getServiceEndpoints = function (id) {
            var deferred = $q.defer();
            resourcesFactory.v2.getServiceEndpoints(id).then(function (response) {
                console.log("got service endpoints for id " + id);
                deferred.resolve(response.data);
            }, function (response) {
                console.warn(response.status + " " + response.statusText);
                deferred.reject(response.statusText);
            });
            return deferred.promise;
        };

        //we need to bring this function into scope so we can use ng-hide if an object is empty
        $scope.isEmptyObject = function (obj) {
            return angular.equals({}, obj);
        };

        $scope.isIsvc = function (service) {
            return service.isIsvc();
        };

        $scope.hasCurrentInstances = function () {
            return $scope.currentService && $scope.currentService.hasInstances();
        };

        $scope.editCurrentService = function () {
            var modalModel = $scope.$new(true);
            // clone service for editing
            $scope.editableService = angular.copy($scope.currentService.model);
            modalModel.model = angular.copy($scope.currentService.model);
            modalModel.pools = [];

            // this modal needs to know all the pools,
            // so axe for all the pools!
            // TODO - cache this list?
            (function getPools() {
                resourcesFactory.v2.getPools().then(function (data) {
                    modalModel.pools = data.map(function (result) {
                        return new Pool(result);
                    });
                }).catch(function (data) {
                    console.warn("Could not load pools, trying again in 1s");
                    $timeout(getPools, 1000);
                });
            })();

            $modalService.create({
                templateUrl: "edit-service.html",
                model: modalModel,
                title: "title_edit_service",
                actions: [{
                    role: "cancel"
                }, {
                    role: "ok",
                    label: "btn_save_changes",
                    action: function action() {
                        if (this.validate()) {

                            // disable ok button, and store the re-enable function
                            var enableSubmit = this.disableSubmitButton();

                            // update service with recently edited service
                            resourcesFactory.v2.updateService(modalModel.model.ID, modalModel.model).success(function (data, status) {
                                $notification.create("Updated service", modalModel.model.Name).success();
                                update();
                                this.close();
                            }.bind(this)).error(function (data, status) {
                                this.createNotification("Update service failed", data.Detail).error();
                                enableSubmit();
                            }.bind(this));
                        }
                    }
                }],
                validate: function validate() {
                    if (modalModel.model.InstanceLimits.Min > modalModel.model.Instances || modalModel.model.Instances === undefined) {
                        return false;
                    }
                    var err = utils.validateRAMLimit(modalModel.model.RAMCommitment, modalModel.model.MemoryLimit);
                    if (err) {
                        this.createNotification("Error", err).error();
                        return false;
                    }

                    return true;
                }
            });
        };

        // TODO - clean up magic numbers
        $scope.calculateIndent = function (depth) {
            var offset = 1;
            if ($scope.currentService && $scope.currentService.parent) {
                offset = $scope.currentService.parent.depth + 2;
            }
            return $scope.indent(depth - offset);
        };

        $scope.restoreTreeState = function () {

            if (!$scope.currentService) {
                return;
            }
            // initialize at first call
            if (!$scope.serviceTreeState[$scope.currentService.id]) {
                $scope.serviceTreeState[$scope.currentService.id] = {};
            }
            // delete hidden services state upon re-entry
            var treeState = $scope.serviceTreeState[$scope.currentService.id];
            Object.keys(treeState).forEach(function (k) {
                if (treeState[k].hidden) {
                    delete treeState[k];
                }
            });
            $scope.serviceTreeState[$scope.currentService.id] = treeState;

            $scope.updateTreeState();
            $scope.currentTreeState = treeState;
        };

        $scope.updateTreeState = function () {
            var treeState = $scope.serviceTreeState[$scope.currentService.id];
            $scope.currentService.subservices.forEach(function recurse(service) {
                // initialize on page load
                if (!treeState[service.id]) {
                    treeState[service.id] = {
                        collapsed: true,
                        hidden: false
                    };
                    return;
                }
                // collapsed node - we're done here
                if (treeState[service.id].collapsed === true) {
                    return;
                }
                // expanded node - get subservices
                service.fetchServiceChildren().then(function () {
                    // toggle the UI row & set currentDescendents
                    $scope.flattenServicesTree();
                    // recurse for each child service
                    service.subservices.forEach(function (subservice) {
                        recurse(subservice);
                    });
                });
            });
        };

        $scope.flattenServicesTree = function () {
            // flatten the current service's subservices tree.
            var rows = [];
            var treeState = $scope.currentTreeState;
            (function flatten(service, depth) {
                if (!treeState[service.id]) {
                    treeState[service.id] = {
                        collapsed: true,
                        hidden: false
                    };
                }
                var rowState = treeState[service.id];
                var rowItem = {
                    service: service,
                    depth: depth,
                    collapsed: rowState.collapsed,
                    hidden: rowState.hidden
                };
                rows.push(rowItem);

                // if expanding node, add dummy row for loading animation
                if (rowState.isLoading) {
                    var loaderRow = {
                        isDummy: true
                    };
                    rows.push(loaderRow);
                }

                if (service.subservices.length) {
                    $filter('orderBy')(service.subservices, 'name').forEach(function (svc) {
                        return flatten(svc, depth + 1);
                    });
                }
            })($scope.currentService, 0);

            // rows[0] is always the top level service, so slice that off
            $scope.currentDescendents = rows.slice(1);
        };

        $scope.fetchBreadcrumbs = function () {
            resourcesFactory.v2.getServiceAncestors($scope.currentService.id).then(function (current) {
                $scope.breadcrumbs = makeCrumbs(current);
            }, function (error) {
                console.warn(error);
            });
        };

        // constructs a new current service
        $scope.setCurrentService = function () {
            var first = false;
            // if this is the first time setting the service,
            // be sure to emit "ready" after things are settled.
            // the ready event clears the big loading jellyfish
            if ($scope.currentService === undefined) {
                first = true;
            }

            $scope.currentService = undefined;
            resourcesFactory.v2.getService($scope.params.serviceId).then(function (model) {
                $scope.currentService = new Service(model);

                $scope.currentDescendents = [];
                $scope.currentService.fetchServiceChildren().then(function () {
                    $scope.restoreTreeState();
                    $scope.flattenServicesTree();
                    $scope.currentService.updateDescendentStatuses();
                });

                // sets $scope.breadcrumbs
                $scope.fetchBreadcrumbs();

                // fetchAll() will trigger update at completion
                $scope.currentService.fetchAll(true);

                // update fast-moving statuses
                $scope.currentService.fetchAllStates();

                if (first) {
                    $scope.$root.$emit("ready");
                }
            });
        };

        $scope.shouldDisable = function (service, button) {
            if (service === undefined) {
                return false;
            }
            if (button === 'start') {
                return service.desiredState === 1 || service.emergencyShutdown;
            } else if (button === 'stop') {
                return service.desiredState === 0;
            } else if (button === 'restart') {
                return service.desiredState === 0 || service.emergencyShutdown;
            }
            return false;
        };

        function refreshEndpoints() {
            $scope.currentService.fetchEndpoints(true);
        }

        function update() {
            // update service model data
            resourcesFactory.v2.getService($scope.params.serviceId).then(function (model) {
                $scope.currentService.update(model);
            });

            // update fast-moving statuses
            $scope.currentService.fetchAllStates();
            $scope.currentService.updateDescendentStatuses();
        }

        function init() {

            $scope.name = "servicedetails";
            $scope.params = $routeParams;

            $scope.breadcrumbs = [{ label: 'breadcrumb_deployed', url: '/apps' }];

            $scope.publicEndpointsTable = {
                sorting: {
                    ServiceName: "asc"
                },
                searchColumns: ['ServiceName', 'Application', 'Protocol']
            };
            $scope.ipsTable = {
                sorting: {
                    ServiceName: "asc"
                },
                searchColumns: ['ServiceName', 'PoolID', 'IPAddress', 'Port']
            };
            $scope.configTable = {
                sorting: {
                    Filename: "asc"
                },
                searchColumns: ['Filename']
            };
            $scope.instancesTable = {
                sorting: {
                    "model.InstanceID": "asc"
                },
                searchColumns: ['model.InstanceID', 'model.ContainerID'],
                // instead of watching for a change, always
                // reload at a specified interval
                watchExpression: function () {
                    var last = new Date().getTime(),
                        now,
                        interval = 1000;

                    return function () {
                        now = new Date().getTime();
                        if (now - last > interval) {
                            last = now;
                            return now;
                        }
                    };
                }()
            };

            // servicesTable should not be sortable since it
            // is a hierarchy.
            $scope.servicesTable = {
                disablePagination: true
            };

            $scope.ips = {};

            // get host status to create a map of
            // host id to name
            (function getHostNames() {
                resourcesFactory.v2.getHostStatuses().then(function (result) {
                    $scope.hostNames = result.reduce(function (acc, s) {
                        acc[s.HostID] = s.HostName;
                        return acc;
                    }, {});
                }).catch(function (err) {
                    console.warn("Could not fetch host names, retrying in 1s", err);
                    $timeout(getHostNames, 1000);
                });
            })();

            // if the current service changes, update
            // various service controller thingies
            $scope.$watch("params.serviceId", $scope.setCurrentService);

            // TODO - use UI_POLL_INTERVAL
            var intervalVal = setInterval(function () {
                if ($scope.currentService) {
                    $scope.currentService.fetchAllStates();
                    $scope.currentService.updateDescendentStatuses();
                }
            }, 3000);

            $scope.$on("$destroy", function () {
                clearInterval(intervalVal);
            });
        }

        // kick off controller
        init();

        function makeCrumbs(current) {

            var crumbs = [{
                label: current.Name,
                itemClass: "active",
                id: current.ID
            }];

            (function recurse(service) {
                if (service) {
                    crumbs.unshift({
                        label: service.Name,
                        url: "/services/" + service.ID,
                        id: service.ID
                    });
                    recurse(service.Parent);
                }
            })(current.Parent);

            crumbs.unshift({
                label: "Applications",
                url: "/apps"
            });

            return crumbs;
        }
    }]);
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* appNameDirective
 * directive for displaying name and status of a top-level service (application)
 */
(function () {
    'use strict';

    angular.module('appName', []).directive('appName', ["resourcesFactory", function (resourcesFactory) {
        var template = '\n            <div class="appName">\n                <div ng-show="app.isEmergencyShutdown()" ng-class="app.getStatusClass()">\n                    <i class="healthIcon glyphicon"></i>\n                </div>\n                <span ng-if="!app.service.deploying" ng-click="app.routeToService()" class="link" ng-class="app.getStatusClass()">{{app.service.name}}<span class="version" ng-show="app.service.model.Version"> (v{{app.service.model.Version}})</span></span>\n                <span ng-if="app.service.deploying">{{app.service.name}}<span class="version" ng-show="app.service.model.Version"> (v{{app.service.model.Version}})</span></span>\n            </div>\n            ';

        var popoverContentTemplate = function popoverContentTemplate(m) {
            return '\n            <div class="emergencyTooltip">\n              <h3>Emergency Shutdown</h3>\n              <div>due to low disk space.</div>\n              <a href="/static/doc/feature/state/emergency-shutdown.html" type="button" class="btn btn-danger">\n                <span ng-show="icon" class="glyphicon glyphicon-book"></span>\n                More Info\n              </a>\n            </div>\n            ';
        };

        var Controller = function () {
            function Controller() {
                // hi.

                _classCallCheck(this, Controller);
            }

            _createClass(Controller, [{
                key: 'isEmergencyShutdown',
                value: function isEmergencyShutdown() {
                    if (!this.service) {
                        return false;
                    }
                    return this.service.emergencyShutdown;
                }
            }, {
                key: 'routeToService',
                value: function routeToService() {
                    if (this.service.isIsvc()) {
                        resourcesFactory.routeToInternalServices();
                    } else {
                        resourcesFactory.routeToService(this.service.id);
                    }
                }
            }, {
                key: 'getStatusClass',
                value: function getStatusClass() {
                    if (!this.service.status) {
                        return "";
                    }
                    return this.service.status.status;
                }
            }, {
                key: 'updatePopover',
                value: function updatePopover() {
                    var p = this.popover;
                    p.options.content = popoverContentTemplate(this);
                    p.setContent();

                    // if the popover is currently visible, update
                    // it immediately, but turn off animation to
                    // prevent it fading in
                    if (p.$tip.is(":visible")) {
                        p.options.animation = false;
                        p.show();
                        p.options.animation = true;
                    }
                }
            }]);

            return Controller;
        }();

        return {
            restrict: "EA",
            scope: {
                service: "="
            },
            controller: Controller,
            controllerAs: "app",
            bindToController: true,
            template: template,
            link: function link(scope, element, attrs) {
                var $appname = $(element).find(".appName");
                $appname.popover({
                    trigger: "hover",
                    placement: "bottom",
                    delay: {
                        show: 100,
                        hide: 400
                    },
                    html: true
                });

                // NOTE: directly accessing the bootstrap popover
                // data object here.
                scope.app.popover = $appname.data("bs.popover");

                // Don't show a popover for services that aren't emergency
                // shutdown.
                $appname.on('show.bs.popover', function () {
                    return scope.app.isEmergencyShutdown() || false;
                });

                // Override the popover's default hide behavior so that it stays
                // visible when the mouse is in the popover itself, allowing
                // clickable links.
                $appname.on('hide.bs.popover', function () {
                    var popover = scope.app.popover;
                    var container = popover.$tip;
                    if (container.is(':visible') && container.is(':hover')) {
                        container.one('mouseleave', function () {
                            setTimeout(function () {
                                popover.hide();
                            }, popover.options.delay.hide);
                        });
                        return false;
                    }
                });

                scope.app.updatePopover();

                scope.$watch(function () {
                    return scope.app.isEmergencyShutdown();
                }, function (newVal, oldVal) {
                    scope.app.updatePopover();
                });
            }
        };
    }]);
})();
'use strict';

/* publicEndpointLink
 * directive for displaying the link for a public
 * endpoint.  May be a link, label, with or without
 * hover text.
 */
(function () {
    'use strict';

    angular.module('publicEndpointLink', []).directive("publicEndpointLink", ["$compile", "$location", "servicesFactory", "$translate", "resourcesFactory", function ($compile, $location, servicesFactory, $translate, resourcesFactory) {
        return {
            restrict: "E",
            scope: {
                publicEndpoint: "=",
                state: "@",
                hostAlias: "="
            },
            link: function link($scope, element, attrs) {
                var publicEndpoint = $scope.publicEndpoint;
                var hostAlias = $scope.hostAlias;

                // A method to return the displayed URL for an endpoint.
                var getUrl = function getUrl(publicEndpoint) {
                    // Form the url based on the endpoint properties.
                    var url = "";
                    if ("VHostName" in publicEndpoint) {
                        var port = $location.port() === "" || +$location.port() === 443 ? "" : ":" + $location.port();
                        var host = publicEndpoint.VHostName.indexOf('.') === -1 ? publicEndpoint.VHostName + '.' + hostAlias : publicEndpoint.VHostName;
                        url = $location.protocol() + "://" + host + port;
                    } else if ("PortAddress" in publicEndpoint) {
                        // Port public endpoint
                        var portAddress = publicEndpoint.PortAddress;
                        var protocol = publicEndpoint.Protocol.toLowerCase();
                        if (portAddress.startsWith(":")) {
                            portAddress = '' + hostAlias + portAddress;
                        }
                        // Remove the port for standard http/https ports.
                        if (protocol === "http" || protocol === "https") {
                            var parts = portAddress.split(":");
                            if (protocol === "http" && parts[1] === "80") {
                                portAddress = parts[0];
                            } else if (protocol === "https" && parts[1] === "443") {
                                portAddress = parts[0];
                            }
                            url = protocol + "://" + portAddress;
                        } else {
                            url = portAddress;
                        }
                    }
                    return url;
                };

                var isServiceRunning = function isServiceRunning(id) {
                    // when Service created public endpoints, it attached
                    // its own desiredState to the public endpoint
                    return publicEndpoint.desiredState === 1;
                };

                var addPopover = function addPopover(element, translation) {
                    // Set the popup with the content data.
                    element.popover({
                        trigger: "hover",
                        placement: "top",
                        delay: 0,
                        content: $translate.instant(translation)
                    });
                };

                function updateVhostLink() {
                    var url = getUrl(publicEndpoint, $scope),
                        html = "",
                        popover = false;

                    // Check the service and endpoint and..
                    if (!isServiceRunning(publicEndpoint) || !publicEndpoint.Enabled) {
                        // .. show the url as a url label (not clickable) with a bootstrap popover..
                        html = '<span><b>' + url + '</b></span>';
                        popover = true;
                    } else if (publicEndpoint.Protocol !== '') {
                        // ..or show the url as a clickable link.
                        html = '<a target="_blank" class="link" href="' + url + '">' + url + '</a>';
                    } else {
                        // ..or just show the host:port for the port endpoint.
                        html = '<span>' + url + '</span>';
                    }

                    // Replace the element's html with our new hot content
                    element.html(html);

                    // Either set or unset the popover on the element
                    if (popover) {
                        addPopover(element, "vhost_unavailable");
                    } else if (element.popover) {
                        element.popover('destroy');
                    }
                }

                // TODO: Use a controller for this garbage
                // Register a watcher to update the link when desiredState changes
                $scope.$watch("publicEndpoint.desiredState", function (newVal, oldVal) {
                    updateVhostLink();
                });
            }
        };
    }]);
})();
'use strict';

// servicesFactory
// - maintains a list of services and keeps it in sync with the backend.
// - links services with their parents and children
// - aggregates and caches service information (such as descendents)
(function () {
    'use strict';

    var resourcesFactory, $q, serviceHealth, instancesFactory, utils;

    angular.module('servicesFactory', []).factory("servicesFactory", ["$rootScope", "$q", "resourcesFactory", "$interval", "$serviceHealth", "instancesFactory", "baseFactory", "miscUtils", function ($rootScope, q, _resourcesFactory, $interval, _serviceHealth, _instancesFactory, BaseFactory, _utils) {

        // share resourcesFactory throughout
        resourcesFactory = _resourcesFactory;
        instancesFactory = _instancesFactory;
        serviceHealth = _serviceHealth;
        utils = _utils;
        $q = q;

        var UPDATE_PADDING = 1000;

        var newFactory = new BaseFactory(Service, resourcesFactory.getServices);

        // alias some stuff for ease of use
        newFactory.serviceTree = newFactory.objArr;
        newFactory.serviceMap = newFactory.objMap;

        angular.extend(newFactory, {
            // TODO - update list by application instead
            // of all services ever?
            update: function update(force, skipUpdateInstances) {
                var _this = this;

                var deferred = $q.defer(),
                    now = new Date().getTime(),
                    requestTime = now,
                    since;

                // if this is the first update, request
                // all services
                if (this.lastRequest === undefined || force) {
                    since = 0;

                    // request all data since the last request
                    // was made to ensure any new data that came
                    // in DURING the request is filled
                } else {
                    since = now - this.lastRequest + UPDATE_PADDING;
                }

                resourcesFactory.getServices(since).success(function (data, status) {
                    // TODO - change backend to send
                    // updated, created, and deleted
                    // separately from each other
                    data.forEach(function (serviceDef) {
                        var currentParent, service;

                        // update
                        if (_this.serviceMap[serviceDef.ID]) {
                            service = _this.serviceMap[serviceDef.ID];
                            currentParent = service.parent;

                            // if the service parent has changed,
                            // update its tree stuff (parent, depth, etc)
                            if (currentParent && serviceDef.ParentServiceID !== service.parent.id) {
                                _this.serviceMap[serviceDef.ID].update(serviceDef);
                                _this.addServiceToTree(service);

                                // otherwise, just update the service
                            } else {
                                _this.serviceMap[serviceDef.ID].update(serviceDef);
                            }

                            // new
                        } else {
                            _this.serviceMap[serviceDef.ID] = new Service(serviceDef);
                            _this.addServiceToTree(_this.serviceMap[serviceDef.ID]);
                        }

                        // TODO - deleted service
                    });

                    // check to see if orphans found parents
                    for (var id in _this.serviceMap) {
                        if (_this.serviceMap[id].isOrphan) {
                            _this.addServiceToTree(_this.serviceMap[id]);
                        }
                    }

                    // HACK - services should update themselves?
                    _this.updateHealth();

                    // notify the first services request is done
                    $rootScope.$emit("ready");

                    // time last SUCCESSFUL request began
                    _this.lastRequest = requestTime;
                    _this.lastUpdate = new Date().getTime();

                    deferred.resolve();
                });

                // keep instances up to date
                if (!skipUpdateInstances) {
                    instancesFactory.update();
                }

                return deferred.promise;
            },

            // adds a service object to the service tree
            // in the appropriate place
            addServiceToTree: function addServiceToTree(service) {
                var parent;
                // if this is not a top level service
                if (service.model.ParentServiceID) {
                    parent = this.serviceMap[service.model.ParentServiceID];

                    // if the parent isn't available, mark
                    // as an orphaned service and early return
                    if (!parent) {
                        service.isOrphan = true;
                        return;
                    }

                    service.isOrphan = false;

                    parent.addChild(service);

                    // if this is a top level service
                } else {
                    this.serviceTree.push(service);
                    //this.serviceTree.sort(sortServicesByName);
                }

                // ICKY GROSS HACK!
                // iterate tree and store tree depth on
                // individual services
                // TODO - find a more elegant way to keep track of depth
                // TODO - remove apps from service tree if they get a parent
                this.serviceTree.forEach(function (topService) {
                    topService.depth = 0;
                    topService.children.forEach(function recurse(service) {
                        service.depth = service.parent.depth + 1;
                        service.children.forEach(recurse);
                    });
                });
            },

            // TODO - debounce this guy
            updateHealth: function updateHealth() {
                var statuses = serviceHealth.update(this.serviceMap);
                for (var id in statuses) {
                    // attach status to associated service
                    if (this.serviceMap[id]) {
                        this.serviceMap[id].status = statuses[id];
                    }
                }
            }
        });

        return newFactory;
    }]);

    function sortServicesByName(a, b) {
        return a.name.toLowerCase() < b.name.toLowerCase() ? -1 : 1;
    }

    // Service object constructor
    // takes a service object (backend service object)
    // and wraps it with extra functionality and info
    function Service(service, parent) {
        this.parent = parent;
        this.children = [];
        this.instances = [];

        // tree depth
        this.depth = 0;

        // cache for computed values
        this.cache = new Cache(["addresses", "descendents", "publicEndpoints", "exportedServiceEndpoints"]);

        this.resources = {
            RAMCommitment: 0,
            RAMAverage: 0
        };

        this.update(service);

        // this newly created child should be
        // registered with its parent
        // TODO - this makes parent update twice...
        if (this.parent) {
            this.parent.addChild(this);
        }
    }

    // service types
    // internal service
    var ISVC = "isvc",

    // a service with no parent
    APP = "app",

    // a service with children but no
    // startup command
    META = "meta",

    // a service who's parent is still
    // being deployed
    DEPLOYING = "deploying";

    // DesiredState enum
    var START = 1,
        STOP = 0,
        RESTART = -1;

    Service.prototype = {
        constructor: Service,

        // updates the immutable service object
        // and marks any computed properties dirty
        update: function update(service) {
            if (service) {
                this.updateServiceDef(service);
            }

            // update service health
            // TODO - should service update itself, its controller
            // update the service, or serviceHealth update all services?
            this.status = serviceHealth.get(this.id);

            this.evaluateServiceType();

            // invalidate caches
            this.markDirty();

            // notify parent that this is now dirty
            if (this.parent) {
                this.parent.update();
            }
        },

        updateServiceDef: function updateServiceDef(service) {
            // these properties are for convenience
            this.name = service.Name;
            this.id = service.ID;
            // NOTE: desiredState is mutable to improve UX
            this.desiredState = service.DesiredState;

            // make service immutable
            this.model = Object.freeze(service);
        },

        // invalidate all caches. This is needed
        // when descendents update
        markDirty: function markDirty() {
            this.cache.markAllDirty();
        },

        evaluateServiceType: function evaluateServiceType() {
            // infer service type
            this.type = [];
            if (this.model.ID.indexOf("isvc-") !== -1) {
                this.type.push(ISVC);
            }

            if (!this.model.ParentServiceID) {
                this.type.push(APP);
            }

            if (this.children.length && !this.model.Startup) {
                this.type.push(META);
            }

            if (this.parent && this.parent.isDeploying()) {
                this.type.push(DEPLOYING);
            }
        },

        addChild: function addChild(service) {
            // if this service is not already in the list
            if (this.children.indexOf(service) === -1) {
                this.children.push(service);

                // make sure this child knows who
                // its parent is
                service.setParent(this);

                // alpha sort children
                this.children.sort(sortServicesByName);

                this.update();
            }
        },

        removeChild: function removeChild(service) {
            var childIndex = this.children.indexOf(service);

            if (childIndex !== -1) {
                this.children.splice(childIndex, 1);
            }
            this.update();
        },

        setParent: function setParent(service) {
            // if this is already the parent, IM OUT!
            if (this.parent === service) {
                return;
            }

            // if a parent is already set, remove
            // this service from its childship
            if (this.parent) {
                this.parent.removeChild(this);
            }

            this.parent = service;
            this.parent.addChild(this);
            this.update();
        },

        // start, stop, or restart this service
        start: function start(skipChildren) {
            var _this2 = this;

            var promise = resourcesFactory.startService(this.id, skipChildren),
                oldDesiredState = this.desiredState;

            this.desiredState = START;

            // if something breaks, return desired
            // state to its previous value
            return promise.error(function () {
                _this2.desiredState = oldDesiredState;
            });
        },
        stop: function stop(skipChildren) {
            var _this3 = this;

            var promise = resourcesFactory.stopService(this.id, skipChildren),
                oldDesiredState = this.desiredState;

            this.desiredState = STOP;

            // if something breaks, return desired
            // state to its previous value
            return promise.error(function () {
                _this3.desiredState = oldDesiredState;
            });
        },
        restart: function restart(skipChildren) {
            var _this4 = this;

            var promise = resourcesFactory.restartService(this.id, skipChildren),
                oldDesiredState = this.desiredState;

            this.desiredState = RESTART;

            // if something breaks, return desired
            // state to its previous value
            return promise.error(function () {
                _this4.desiredState = oldDesiredState;
            });
        },

        // gets a list of running instances of this service.
        // NOTE: this isn't using a cache because this can be
        // invalidated at any time, so it should always be checked
        getServiceInstances: function getServiceInstances() {
            this.instances = instancesFactory.getByServiceId(this.id);
            this.instances.sort(function (a, b) {
                return a.model.InstanceID > b.model.InstanceID;
            });
            return this.instances;
        },

        resourcesGood: function resourcesGood() {
            var instances = this.getServiceInstances();
            for (var i = 0; i < instances.length; i++) {
                if (!instances[i].resourcesGood()) {
                    return false;
                }
            }
            return true;
        },

        // some convenience methods
        isIsvc: function isIsvc() {
            return !!~this.type.indexOf(ISVC);
        },

        isApp: function isApp() {
            return !!~this.type.indexOf(APP);
        },

        isDeploying: function isDeploying() {
            return !!~this.type.indexOf(DEPLOYING);
        },

        // HACK: this is a temporary fix to mark
        // services deploying.
        markDeploying: function markDeploying() {
            this.type.push(DEPLOYING);
        },

        // if any cache is dirty, this whole object
        // is dirty
        isDirty: function isDirty() {
            return this.cache.anyDirty();
        },

        hasInstances: function hasInstances() {
            return !!this.instances.length;
        }
    };

    Object.defineProperty(Service.prototype, "descendents", {
        get: function get() {
            var descendents = this.cache.getIfClean("descendents");

            if (descendents) {
                return descendents;
            }

            descendents = this.children.reduce(function (acc, child) {
                acc.push(child);
                return acc.concat(child.descendents);
            }, []);

            Object.freeze(descendents);
            this.cache.cache("descendents", descendents);
            return descendents;
        }
    });

    Object.defineProperty(Service.prototype, "addresses", {
        get: function get() {
            var addresses = this.cache.getIfClean("addresses");

            // if valid cache, early return it
            if (addresses) {
                return addresses;
            }

            // otherwise, get some new data
            var services = this.descendents.slice();

            // we also want to see the Endpoints for this
            // service, so add it to the list
            services.push(this);

            // iterate services
            addresses = services.reduce(function (acc, service) {

                var result = [];

                // if Endpoints, iterate Endpoints
                if (service.model.Endpoints) {
                    result = service.model.Endpoints.reduce(function (acc, endpoint) {
                        if (endpoint.AddressConfig.Port > 0 && endpoint.AddressConfig.Protocol) {
                            acc.push({
                                ID: endpoint.AddressAssignment.ID,
                                AssignmentType: endpoint.AddressAssignment.AssignmentType,
                                EndpointName: endpoint.AddressAssignment.EndpointName,
                                IPAddr: endpoint.AddressAssignment.IPAddr,
                                Port: endpoint.AddressConfig.Port,
                                HostID: endpoint.AddressAssignment.HostID,
                                PoolID: service.model.PoolID,
                                ServiceID: service.id,
                                ServiceName: service.name
                            });
                        }
                        return acc;
                    }, []);
                }

                return acc.concat(result);
            }, []);

            Object.freeze(addresses);
            this.cache.cache("addresses", addresses);
            return addresses;
        }
    });

    // fetch public endpoints for service and all descendents
    Object.defineProperty(Service.prototype, "publicEndpoints", {
        get: function get() {
            var publicEndpoints = this.cache.getIfClean("publicEndpoints");

            // if valid cache, early return it
            if (publicEndpoints) {
                return publicEndpoints;
            }

            // otherwise, get some data
            var services = this.descendents.slice();

            // we also want to see the Endpoints for this
            // service, so add it to the list
            services.push(this);

            // iterate services
            publicEndpoints = services.reduce(function (acc, service) {

                var result = [];

                // if Endpoints, iterate Endpoints
                if (service.model.Endpoints) {
                    result = service.model.Endpoints.reduce(function (acc, endpoint) {
                        // if VHosts, iterate VHosts
                        if (endpoint.VHostList) {
                            endpoint.VHostList.forEach(function (VHost) {
                                acc.push({
                                    Name: VHost.Name,
                                    Enabled: VHost.Enabled,
                                    Application: service.name,
                                    ServiceEndpoint: endpoint.Application,
                                    ApplicationId: service.id,
                                    Value: service.name + " - " + endpoint.Application,
                                    type: "vhost"
                                });
                            });
                        }
                        // if ports, iterate ports
                        if (endpoint.PortList) {
                            endpoint.PortList.forEach(function (port) {
                                acc.push({
                                    PortAddr: port.PortAddr,
                                    Enabled: port.Enabled,
                                    Application: service.name,
                                    ServiceEndpoint: endpoint.Application,
                                    ApplicationId: service.id,
                                    Value: service.name + " - " + endpoint.Application,
                                    UseTLS: port.UseTLS,
                                    Protocol: port.Protocol,
                                    type: "port"
                                });
                            });
                        }

                        return acc;
                    }, []);
                }

                return acc.concat(result);
            }, []);

            Object.freeze(publicEndpoints);
            this.cache.cache("publicEndpoints", publicEndpoints);
            return publicEndpoints;
        }
    });

    // fetch public endpoints for service and all descendents
    Object.defineProperty(Service.prototype, "exportedServiceEndpoints", {
        get: function get() {
            var exportedServiceEndpoints = this.cache.getIfClean("exportedServiceEndpoints");

            // if valid cache, early return it
            if (exportedServiceEndpoints) {
                return exportedServiceEndpoints;
            }

            // otherwise, get some data
            var services = this.descendents.slice();

            // we also want to see the Endpoints for this
            // service, so add it to the list
            services.push(this);

            // iterate services
            exportedServiceEndpoints = services.reduce(function (acc, service) {
                var result = [];

                // if Endpoints, iterate Endpoints
                if (service.model.Endpoints) {
                    result = service.model.Endpoints.reduce(function (acc, endpoint) {

                        // if this exports tcp, add it to our list.
                        if (endpoint.Purpose === "export" && endpoint.Protocol === "tcp") {
                            acc.push({
                                Application: service.name,
                                ServiceEndpoint: endpoint.Application,
                                ApplicationId: service.id,
                                Value: service.name + " - " + endpoint.Application
                            });
                        }

                        return acc;
                    }, []);
                }

                return acc.concat(result);
            }, []);

            Object.freeze(exportedServiceEndpoints);
            this.cache.cache("exportedServiceEndpoints", exportedServiceEndpoints);
            return exportedServiceEndpoints;
        }
    });

    // simple cache object
    // TODO - angular has this sorta stuff built in
    function Cache(caches) {
        this.caches = {};
        if (caches) {
            caches.forEach(function (name) {
                this.addCache(name);
            }.bind(this));
        }
    }
    Cache.prototype = {
        constructor: Cache,
        addCache: function addCache(name) {
            this.caches[name] = {
                data: null,
                dirty: false
            };
        },
        markDirty: function markDirty(name) {
            this.mark(name, true);
        },
        markAllDirty: function markAllDirty() {
            for (var key in this.caches) {
                this.markDirty(key);
            }
        },
        markClean: function markClean(name) {
            this.mark(name, false);
        },
        markAllClean: function markAllClean() {
            for (var key in this.caches) {
                this.markClean(key);
            }
        },
        cache: function cache(name, data) {
            this.caches[name].data = data;
            this.caches[name].dirty = false;
        },
        get: function get(name) {
            return this.caches[name].data;
        },
        getIfClean: function getIfClean(name) {
            if (!this.caches[name].dirty) {
                return this.caches[name].data;
            }
        },
        mark: function mark(name, flag) {
            this.caches[name].dirty = flag;
        },
        isDirty: function isDirty(name) {
            return this.caches[name].dirty;
        },
        anyDirty: function anyDirty() {
            for (var i in this.caches) {
                if (this.caches[i].dirty) {
                    return true;
                }
            }
            return false;
        }
    };
})();
"use strict";

/* StatusController
 * Displays system stats
 */
(function () {
    'use strict';

    controlplane.controller("StatusController", ["$scope", "authService", function ($scope, authService) {
        authService.checkLogin($scope);
        $scope.breadcrumbs = [{ label: 'breadcrumb_status', itemClass: 'active' }];

        $scope.$emit("ready");
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* CCUIState.js
 * preserve state through ui navigations
 */
(function () {
    "use strict";

    // TODO - persist to local storage

    var CCUIState = function () {
        function CCUIState() {
            _classCallCheck(this, CCUIState);

            // -> user name
            //    -> store name
            //       -> stored object
            this.store = {
                // shared state
                _shared: {}
            };
        }

        _createClass(CCUIState, [{
            key: "get",
            value: function get(userName, storeName) {
                // get the shared state
                if (!userName) {
                    return this.store._shared;
                }

                var userStore = this.getUserStore(userName);

                // if the store doesnt exist for this user,
                // create it
                if (!userStore[storeName]) {
                    // TODO - formalize creation of this object
                    userStore[storeName] = {};
                }

                return userStore[storeName];
            }

            // creates and returns a user store for the specified
            // user, or returns existing user store for the user

        }, {
            key: "getUserStore",
            value: function getUserStore(name) {
                var users = Object.keys(this.store);

                // if this user doesn't have a store,
                // create one
                if (users.indexOf(name) === -1) {
                    this.store[name] = {};
                }

                return this.store[name];
            }
        }]);

        return CCUIState;
    }();

    angular.module("CCUIState", []).service("CCUIState", [CCUIState]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* globals rison: true */
/* log.js
 * logging, pure of heart.
 */
(function () {
    "use strict";

    var $location = void 0;

    var KIBANA_PATH = "/api/controlplane/kibana";
    var DEFAULT_INDEX = "logstash-*";

    var DEFAULT_APPCONFIG = {
        columns: ["fields.type", "message"],
        filters: [],
        index: DEFAULT_INDEX,
        interval: "auto",
        query: {
            query_string: {
                analyze_wildcard: true,
                query: "fields.type:*"
            }
        },
        sort: ["@timestamp", "desc"],
        vis: {}
    };

    var DEFAULT_GLOBALCONFIG = {
        refreshInterval: {
            display: "Off",
            pause: false,
            value: 0
        },
        time: {
            from: "now-30d",
            mode: "quick",
            to: "now"
        }
    };

    function generateKibanaURL(baseURL, appConfig, globalConfig, index) {
        return "\n" + baseURL + "/app/kibana?#/discover?\n_g=" + rison.encode(globalConfig) + "&\n_a=" + rison.encode(appConfig) + "&\nindexPattern=" + index + "&type=histogram";
    }

    var LogSearch = function () {
        function LogSearch() {
            _classCallCheck(this, LogSearch);

            var port = $location.port() ? ":" + $location.port() : "",
                host = $location.host(),
                protocol = $location.protocol(),
                origin = protocol + "://" + host + port;

            this.baseURL = "" + origin + KIBANA_PATH;
            console.log(this.baseURL);
        }

        // given an app config and global config, generate
        // a search url


        _createClass(LogSearch, [{
            key: "getURL",
            value: function getURL(appConfig, globalConfig) {
                return generateKibanaURL(this.baseURL, appConfig, globalConfig, DEFAULT_INDEX);
            }

            // generate the default search url

        }, {
            key: "getDefaultURL",
            value: function getDefaultURL() {
                return generateKibanaURL(this.baseURL, DEFAULT_APPCONFIG, DEFAULT_GLOBALCONFIG, DEFAULT_INDEX);
            }

            // give other users some defaults
            // to make new requests from

        }, {
            key: "getDefaultAppConfig",
            value: function getDefaultAppConfig() {
                return angular.copy(DEFAULT_APPCONFIG);
            }
        }, {
            key: "getDefaultGlobalConfig",
            value: function getDefaultGlobalConfig() {
                return angular.copy(DEFAULT_GLOBALCONFIG);
            }
        }]);

        return LogSearch;
    }();

    angular.module("LogSearch", []).factory("LogSearch", ["$location", function (_$location) {
        $location = _$location;
        return new LogSearch();
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* areUIReady.js
 * provides a means of locking the UI to
 * prevent interaction when it is not ready
 */
(function () {
    "use strict";

    var rgx = /\(([^)]+)\)/;
    // gets name of the calling function from
    // stack trace. this is hardcoded to step up
    // 3 levels
    var getCallingFn = function getCallingFn() {
        try {
            var e = new Error("stack");
            var match = e.stack.split("\n")[3].match(rgx);
            return match && match[1];
        } catch (e) {
            return;
        }
    };

    var ReadyState = function () {
        function ReadyState(log) {
            _classCallCheck(this, ReadyState);

            this.log = log;
            this.locked = false;
            this.lockCount = 0;
            this.onLock = function () {};
            this.onUnlock = function () {};
        }

        _createClass(ReadyState, [{
            key: "lock",
            value: function lock() {
                if (!this.locked) {
                    this.locked = true;
                    this.onLock(this);
                }
                this.lockCount++;
                this.log.info("lock count is now", this.lockCount, getCallingFn());
            }
        }, {
            key: "unlock",
            value: function unlock() {
                /*
                // NOTE - uncomment to reimplement lock counting
                if(this.lockCount === 0){
                    // can't unlock because none are locked
                    this.log.info("unable to unlock UI, UI is not locked");
                    return;
                }*/

                this.lockCount--;
                this.log.info("lock count is now", this.lockCount);

                // NOTE - uncomment to reimplement lock counting
                //if(this.lockCount === 0){
                this.log.info("ui is unlocked!", getCallingFn());
                this.locked = false;
                this.onUnlock(this);
                //}
            }
        }, {
            key: "isLocked",
            value: function isLocked() {
                return this.locked;
            }
        }]);

        return ReadyState;
    }();

    angular.module("areUIReady", []).service("areUIReady", ["log", ReadyState]);
})();
"use strict";

/* authService.js
 * determine if user is authorized
 */
(function () {
    "use strict";

    angular.module("authService", []).factory("authService", ["$cookies", "$cookieStore", "$location", "$http", "$notification", "miscUtils", "log", function ($cookies, $cookieStore, $location, $http, $notification, utils, log) {
        var loggedIn = false;
        var userName = null;

        var setLoggedIn = function setLoggedIn(truth, username) {
            loggedIn = truth;
            userName = username;
        };
        return {

            /*
             * Called when we have positively determined that a user is or is not
             * logged in.
             *
             * @param {boolean} truth Whether the user is logged in.
             */
            setLoggedIn: setLoggedIn,

            login: function login(creds, successCallback, failCallback) {
                $http.post('/login', creds).success(function (data, status) {
                    // Ensure that the auth service knows that we are logged in
                    setLoggedIn(true, creds.Username);

                    successCallback();
                }).error(function (data, status) {
                    // Ensure that the auth service knows that the login failed
                    setLoggedIn(false);

                    failCallback();
                });
            },

            logout: function logout() {
                $http.delete('/login').success(function (data, status) {
                    // On successful logout, redirect to /login
                    $location.path('/login');
                }).error(function (data, status) {
                    // On failure to logout, note the error
                    // TODO error screen
                    log.error('Unable to log out. Were you logged in to begin with?');
                });
            },

            /*
             * Check whether the user appears to be logged in. Update path if not.
             *
             * @param {object} scope The 'loggedIn' property will be set if true
             */
            checkLogin: function checkLogin($scope) {
                $scope.dev = $cookieStore.get("ZDevMode");
                if (loggedIn || $cookies.get("ZCPToken")) {
                    $scope.loggedIn = true;
                    $scope.user = {
                        username: $cookies.get("ZUsername")
                    };
                    return;
                }
                utils.unauthorized($location);
            }
        };
    }]);
})();
'use strict';

/*
 * baseFactory.js
 * baseFactory constructs a factory object that can be used
 * to keep the UI in sync with the backend. The returned factory
 * will use the provided update function (which should return a
 * promise good for an map of id to object), create new objects using
 * the provided ObjConstructor, and cache those objects.
 *
 * When it hits the update function again, it will compare the new
 * list to the cached list and intelligently new, update, and
 * remove objects as needed.
 *
 * NOTE: you can override update, mixin methods, etc to make this
 * thing more useful
 */

(function () {
    'use strict';

    var DEFAULT_UPDATE_FREQUENCY = 3000;
    var updateFrequency = DEFAULT_UPDATE_FREQUENCY;

    var $q, $interval, $rootScope, log;

    angular.module('baseFactory', []).factory("baseFactory", ["$q", "$interval", "$rootScope", "servicedConfig", "log", function (_$q, _$interval, _$rootScope, servicedConfig, _log) {

        $q = _$q;
        $interval = _$interval;
        $rootScope = _$rootScope;
        log = _log;

        servicedConfig.getConfig().then(function (config) {
            updateFrequency = config.PollFrequency * 1000;
        }).catch(function (err) {
            var errMessage = err.statusText;
            if (err.data && err.data.Detail) {
                errMessage = err.data.Detail;
            }
            log.error("could not load serviced config:", errMessage);
        });

        return BaseFactory;
    }]);

    // BaseFactory creates and returns a new factory/cache
    // @param {function} ObjConstructor - constructor function to be new'd up
    //      with each object from the backend. NOTE: ObjConstructor must provide
    //      update and updateObjDef methods.
    // @param {function} updateFn - function to be called to update the object
    //      cache. NOTE: this function must return a promise that yields a map
    //      of id to object.
    function BaseFactory(ObjConstructor, updateFn) {
        // map of cached objects by id
        this.objMap = {};
        // array of cached objects
        this.objArr = [];
        this.updateFn = updateFn;
        this.ObjConstructor = ObjConstructor;
    }

    BaseFactory.prototype = {
        constructor: BaseFactory,

        // TODO - debounce
        // update calls the provided update function, iterates the results,
        // compares them to cached results and updates, creates, or deletes
        // objects based on id
        update: function update() {
            var _this = this;

            var deferred = $q.defer();
            this.updateFn().success(function (data, status) {
                var included = [];

                for (var id in data) {
                    var obj = data[id];

                    // update
                    if (_this.objMap[id]) {
                        _this.objMap[id].update(obj);

                        // new
                    } else {
                        _this.objMap[id] = new _this.ObjConstructor(obj);
                        _this.objArr.push(_this.objMap[id]);
                    }

                    included.push(id);
                }

                // delete
                if (included.length !== Object.keys(_this.objMap).length) {
                    // iterate objMap and find keys
                    // not present in included list
                    for (var _id in _this.objMap) {
                        if (included.indexOf(_id) === -1) {
                            _this.objArr.splice(_this.objArr.indexOf(_this.objMap[_id]), 1);
                            delete _this.objMap[_id];
                        }
                    }
                }

                deferred.resolve();
            }).error(function (data, status) {
                log.warn("Unable to update factory", data);
                // TODO - include status?
                deferred.reject(data);
            }).finally(function () {
                // notify the first request is complete
                if (!_this.lastUpdate) {
                    $rootScope.$emit("ready");
                }

                _this.lastUpdate = new Date().getTime();
            });
            return deferred.promise;
        },

        // begins auto-update
        activate: function activate() {
            var _this2 = this;

            if (!this.updatePromise) {
                this.updatePromise = $interval(function () {
                    return _this2.update();
                }, updateFrequency);
            }
        },

        // stops auto-update
        deactivate: function deactivate() {
            if (this.updatePromise) {
                $interval.cancel(this.updatePromise);
                this.updatePromise = null;
            }
        },

        // returns an object by id
        get: function get(id) {
            return this.objMap[id];
        }
    };

    /*
     * example of a type that could be passed
     * in as ObjectConstructor
    
            function Obj(obj){
                this.update(obj);
    
                // do more init stuff here
            }
    
            Obj.prototype = {
                constructor: Obj,
                update: function(obj){
                    // if obj is provided, update
                    // immutable internal representation
                    // of that object
                    if(obj){
                        this.updateObjDef(obj);
                    }
    
                    // do more update stuff here
                },
    
                // update immutable copy of the object
                // from the backend
                updateObjDef: function(obj){
                    // alias some properties for easy access
                    this.name = obj.Name;
                    this.id = obj.ID;
                    this.model = Object.freeze(obj);
    
                    // do more update stuff here
                },
            };
    */
})();
'use strict';

/* globals jstz: true */
/* tableDirective.js
 * Wrapper for ngTable that gives a bit more
 * control and customization
 */

/*
 *TODO
 *generate unique id thing for ng-table property? (jellyTable1)
 *
 *
 */
(function () {
    'use strict';

    var count = 0;
    var PAGE_SIZE = 15; // TODO: pull from config file

    angular.module('jellyTable', []).directive("jellyTable", ["$interval", "ngTableParams", "$filter", "$animate", "$compile", "miscUtils", "$parse", function ($interval, NgTableParams, $filter, $animate, $compile, utils, $parse) {
        return {
            restrict: "A",
            // inherit parent scope
            scope: true,
            // ensure this directive accesses the template
            // before ng-repeat and ng-table do
            priority: 1002,
            // do not continue parsing the template
            terminal: true,
            compile: function compile(table) {

                var $wrap, tableID, fn;

                // wrap the table up real nice
                $wrap = $('<div class="jelly-table"></div>');
                table.after($wrap);
                $wrap.append(table);

                // unique property name for this table
                tableID = "jellyTable" + count++;

                // add loading and no data elements
                table.find("tr").last().after('<tr class="noData"><td colspan="100%" translate>no_data</td></tr>').after('<tr class="loader"><td colspan="100%">&nbsp;</td></tr>');

                // add table status bar
                table.append('\n                    <tfoot><tr>\n                        <td colspan="100%" class="statusBar">\n                            <ul>\n                                <li class="entry"><span translate>last_update</span><strong>{{' + tableID + '.lastUpdate | fromNow}}</strong></li>\n                                <li class="entry"><strong>{{' + tableID + '.resultsLength}}</strong>\n                                    <span translate>{{' + tableID + '.resultsLength === 1 ? "result" : "results"}}</span>\n                                </li>\n                            </ul>\n                        </td>\n                    </tr></tfoot>\n                ');

                $wrap.prepend('\n                        <div class="jelly-search">\n                            <input type="text" class="form-control" placeholder="Search" name="searchTerm"/>\n                        </div>\n                ');

                // mark this guy as an ng-table
                table.attr("ng-table", tableID);
                table.attr("template-pagination", "/static/partials/jellyPager.html");

                // avoid compile loop
                table.removeAttr("jelly-table");

                // enable linker to compile and bind scope
                fn = $compile(table);

                // return link function
                return function ($scope, element, attrs) {
                    // bind scope to html
                    fn($scope);

                    var $loader, $noData, $search, toggleLoader, toggleNoData, getData, pageConfig, dataConfig, searchTerm, timezone, orderBy;

                    searchTerm = {};
                    var config = utils.propGetter($scope, attrs.config);
                    var data = utils.propGetter($scope, attrs.data);
                    var onUpdate = utils.propGetter($scope, attrs.update);

                    orderBy = $filter("orderBy");

                    // setup some config defaults
                    // TODO - create a defaults object and merge
                    // TODO - create a "defaultSort" property and use
                    // it to compose the `sorting` config option
                    config().counts = config().counts || [];
                    config().watchExpression = config().watchExpression || function () {
                        return data();
                    };
                    config().pgsize = PAGE_SIZE;

                    timezone = jstz.determine().name();

                    // TODO - errors for missing data

                    $loader = $wrap.find(".loader");
                    $noData = $wrap.find(".noData");
                    $search = $wrap.find(".jelly-search > input");

                    $search.keyup(function () {
                        searchTerm.jellySearch = $search.val().toLowerCase();
                        $scope[tableID].reload();
                    });

                    toggleLoader = function toggleLoader(newVal, oldVal) {
                        if (oldVal === newVal) {
                            return;
                        }

                        // show loading spinner
                        if (newVal) {
                            $loader.show();
                            $animate.removeClass($loader, "disappear");

                            // hide loading spinner
                        } else {
                            $animate.addClass($loader, "disappear").then(function () {
                                $loader.hide();
                            });
                        }
                    };
                    toggleNoData = function toggleNoData(val) {
                        if (val) {
                            $noData.show();
                        } else {
                            $noData.hide();
                        }
                    };

                    getData = function getData($defer, params) {
                        var allItems = data(),
                            totalItemCount = 0,
                            sortedItems = [],
                            tableEntries = [];

                        if (angular.isUndefined(allItems)) {

                            // show loading animation and hide no-data message
                            $scope[tableID].loading = true;
                            toggleNoData(false);
                        } else {

                            $scope[tableID].loading = false;

                            if (angular.isObject(allItems) && !angular.isArray(allItems)) {
                                // make allItems an array if necessary
                                allItems = utils.mapToArr(allItems);
                            } else if (allItems === null) {
                                allItems = [];
                            }

                            if (config().getData) {
                                // call overriden getData if available (eg services)
                                sortedItems = config().getData(allItems, params);
                            } else {
                                // use default getData (eg pools hosts)
                                sortedItems = params.sorting() ? orderBy(allItems, params.orderBy()) : allItems;
                            }

                            // apply filters
                            if (config().searchColumns) {
                                if (params.filter().jellySearch) {
                                    var sortedItems;

                                    (function () {
                                        var term = params.filter().jellySearch.toLowerCase();
                                        sortedItems = sortedItems.filter(function (item) {
                                            var match = false;
                                            config().searchColumns.forEach(function (col) {
                                                var data = $parse(col)(item);
                                                if (data) {
                                                    var z = data.toString().toLowerCase();
                                                    match |= z.indexOf(term) > -1;
                                                }
                                            });
                                            return match;
                                        });
                                    })();
                                }
                            }

                            totalItemCount = sortedItems.length;
                            // if no results show no data message
                            toggleNoData(!totalItemCount);

                            // pagination
                            if (config().disablePagination || !config().searchColumns) {
                                // supress pagination via configuration or lack of configuration
                                tableEntries = sortedItems;
                                $wrap.find(".jelly-search").addClass("hidden");
                            } else {
                                // slice sorted results array for current page
                                var lower = (params.page() - 1) * config().pgsize;
                                var upper = Math.min(lower + config().pgsize, totalItemCount);
                                tableEntries = sortedItems.slice(lower, upper);

                                if (totalItemCount > config().pgsize) {
                                    table.addClass("has-pagination");
                                } else {
                                    table.removeClass("has-pagination");
                                }
                                // ngtable pagination requires total item count
                                params.total(totalItemCount);
                            }
                        }

                        if (onUpdate && onUpdate()) {
                            onUpdate()(tableEntries);
                        }

                        $scope[tableID].resultsLength = totalItemCount;
                        $scope[tableID].lastUpdate = moment.utc().tz(timezone);
                        $defer.resolve(tableEntries);
                    };

                    // setup config for ngtable
                    pageConfig = {
                        // count: hide pagination when total count less than this number
                        count: config().pgsize,
                        sorting: config().sorting,
                        filter: searchTerm
                    };
                    dataConfig = {
                        // counts: dynamic items-per-page widget. empty array will supress.
                        counts: config().counts,
                        // pager:  dynamic items-per-page widget.
                        getData: getData
                    };

                    // configure ngtable
                    $scope[tableID] = new NgTableParams(pageConfig, dataConfig);
                    $scope[tableID].loading = true;
                    toggleNoData(false);

                    // watch data for changes
                    $scope.$watch(config().watchExpression, function () {
                        $scope[tableID].reload();
                    });

                    $scope.$watch(tableID + ".loading", toggleLoader);
                };
            }
        };
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* log.js
 * logging, pure of heart.
 */
(function () {
    "use strict";

    var _logFunctions;

    var getCallingFn = function getCallingFn(index) {
        try {
            var e = new Error("stack");
            return e.stack.split("\n")[index].trim().replace("at ", "");
        } catch (e) {
            return "";
        }
    };

    var DEBUG = "debug",
        LOG = "log",
        INFO = "info",
        WARN = "warn",
        ERROR = "error";

    var logLevels = [DEBUG, LOG, INFO, WARN, ERROR];

    // number of steps up the stack to get out of the
    // logging library and back to the actual caller
    var DEBUG_DEPTH = 3;

    var $log = void 0;

    var logFunctions = (_logFunctions = {}, _defineProperty(_logFunctions, DEBUG, function () {
        var _$log2;

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        (_$log2 = $log).debug.apply(_$log2, ["[DEBUG: " + getCallingFn(DEBUG_DEPTH) + "] "].concat(args));
    }), _defineProperty(_logFunctions, LOG, function () {
        var _$log3;

        for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
            args[_key2] = arguments[_key2];
        }

        (_$log3 = $log).log.apply(_$log3, ["[LOG: " + getCallingFn(DEBUG_DEPTH) + "] "].concat(args));
    }), _defineProperty(_logFunctions, INFO, function () {
        var _$log4;

        for (var _len3 = arguments.length, args = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
            args[_key3] = arguments[_key3];
        }

        (_$log4 = $log).info.apply(_$log4, ["[INFO: " + getCallingFn(DEBUG_DEPTH) + "] "].concat(args));
    }), _defineProperty(_logFunctions, WARN, function () {
        var _$log5;

        for (var _len4 = arguments.length, args = Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
            args[_key4] = arguments[_key4];
        }

        (_$log5 = $log).warn.apply(_$log5, ["[WARN: " + getCallingFn(DEBUG_DEPTH) + "] "].concat(args));
    }), _defineProperty(_logFunctions, ERROR, function () {
        var _$log6;

        for (var _len5 = arguments.length, args = Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
            args[_key5] = arguments[_key5];
        }

        (_$log6 = $log).error.apply(_$log6, ["[ERROR: " + getCallingFn(DEBUG_DEPTH) + "] "].concat(args));
    }), _logFunctions);

    var noop = function noop() {};

    var Log = function () {
        function Log() {
            var _level;

            _classCallCheck(this, Log);

            this.level = (_level = {}, _defineProperty(_level, DEBUG, DEBUG), _defineProperty(_level, LOG, LOG), _defineProperty(_level, INFO, INFO), _defineProperty(_level, WARN, WARN), _defineProperty(_level, ERROR, ERROR), _level);
            this.setLogLevel(WARN);
        }

        _createClass(Log, [{
            key: "setLogLevel",
            value: function setLogLevel(newLevel) {
                var _this = this;

                var newLevelIndex = logLevels.indexOf(newLevel);

                if (newLevelIndex === -1) {
                    $log.warn("could not set log level '" + newLevel + "'");
                    return;
                }

                logLevels.forEach(function (level, i) {
                    if (i >= newLevelIndex) {
                        _this[level] = logFunctions[level];
                    } else {
                        _this[level] = noop;
                    }
                });
            }
        }]);

        return Log;
    }();

    angular.module("log", []).factory("log", ["$log", function (_$log) {
        $log = _$log;
        return new Log();
    }]);
})();
'use strict';

/* miscDirectives.js
 * a place for miscellaneous directives
 */
(function () {
    "use strict";

    controlplane
    /**
     * This is a fix for https://jira.zenoss.com/browse/ZEN-10263
     * It makes sure that inputs that are filled in by autofill (like when the browser remembers the password)
     * are updated in the $scope. See the partials/login.html for an example
     **/
    .directive('formAutofillFix', [function () {
        return function (scope, elem, attrs) {
            // Fixes Chrome bug: https://groups.google.com/forum/#!topic/angular/6NlucSskQjY
            elem.prop('method', 'POST');

            // Fix autofill issues where Angular doesn't know about autofilled inputs
            if (attrs.ngSubmit) {
                window.setTimeout(function () {
                    elem.unbind('submit').submit(function (e) {
                        e.preventDefault();
                        elem.find('input, textarea, select').trigger('input').trigger('change').trigger('keydown');
                        scope.$apply(attrs.ngSubmit);
                    });
                }, 0);
            }
        };
    }]).directive('popover', [function () {
        return function (scope, elem, attrs) {
            $(elem).popover({
                title: attrs.popoverTitle,
                trigger: "hover",
                html: true,
                content: attrs.popover
            });
        };
    }]).directive('scroll', ["$rootScope", "$window", "$timeout", function ($rootScope, $window, $timeout) {
        return {
            link: function link(scope, elem, attr) {
                $window = angular.element($window);
                var handler = function handler() {
                    var winEdge, elEdge, dataHidden;
                    winEdge = $window.height() + $window.scrollTop();
                    elEdge = elem.offset().top + elem.height();
                    dataHidden = elEdge - winEdge;
                    if (dataHidden < parseInt(attr.scrollSize, 10)) {
                        if ($rootScope.$$phase) {
                            if (scope.$eval(attr.scroll)) {
                                $timeout(handler, 100);
                            }
                        } else {
                            if (scope.$apply(attr.scroll)) {
                                $timeout(handler, 100);
                            }
                        }
                    }
                };
                if (attr.scrollHandlerObj && attr.scrollHandlerField) {
                    var obj = scope[attr.scrollHandlerObj];
                    obj[attr.scrollHandlerField] = handler;
                }
                $window.on('scroll', handler);
                $window.on('resize', handler);
                scope.$on('$destroy', function () {
                    $window.off('scroll', handler);
                    $window.off('resize', handler);
                    return true;
                });
                return $timeout(function () {
                    return handler();
                }, 100);
            }
        };
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* miscUtils.js
 * miscellaneous utils and stuff that
 * doesn't quite fit in elsewhere
 */
(function () {
    "use strict";

    var TIMEMULTIPLIER = { w: 6048e5, d: 864e5, h: 36e5, m: 6e4, s: 1e3, ms: 1 };

    angular.module("miscUtils", []).factory("miscUtils", ["$parse", "log", function ($parse, log) {

        //polyfill endsWith so phantomjs won't complain :/
        if (!String.prototype.endsWith) {
            String.prototype.endsWith = function (searchString, position) {
                var subjectString = this.toString();
                if (typeof position !== 'number' || !isFinite(position) || Math.floor(position) !== position || position > subjectString.length) {
                    position = subjectString.length;
                }
                position -= searchString.length;
                var lastIndex = subjectString.indexOf(searchString, position);
                return lastIndex !== -1 && lastIndex === position;
            };
        }

        // polyfill find so IE doesnt complain :\
        if (!Array.prototype.find) {
            Object.defineProperty(Array.prototype, 'find', {
                value: function value(predicate) {
                    if (this === null || this === undefined) {
                        throw new TypeError('Array.prototype.find called on null or undefined');
                    }
                    if (typeof predicate !== 'function') {
                        throw new TypeError('predicate must be a function');
                    }
                    var list = Object(this);
                    var length = list.length >>> 0;
                    var thisArg = arguments[1];
                    var value;

                    for (var i = 0; i < length; i++) {
                        value = list[i];
                        if (predicate.call(thisArg, value, i, list)) {
                            return value;
                        }
                    }
                    return undefined;
                }
            });
        }

        // fix for chrome 48 and up, as described here:
        // https://github.com/cpettitt/dagre-d3/issues/202
        SVGElement.prototype.getTransformToElement = SVGElement.prototype.getTransformToElement || function (elem) {
            return elem.getScreenCTM().inverse().multiply(this.getScreenCTM());
        };

        // creates a biset of specified size and
        // sets the value to to val. Also attaches
        // getter/setter functions angular can bind
        // to to toggle fields

        var NgBitset = function () {
            function NgBitset(size, val) {
                var _this = this;

                _classCallCheck(this, NgBitset);

                this.val = val;
                this.size = size;

                // create angular getterSetters so that
                // this bitset can bind to checkboxes in the UI

                var _loop = function _loop(i) {
                    _this[i] = function (val) {
                        // if val, toggle the bit
                        // TODO - act based on val?
                        if (val !== undefined) {
                            _this.toggle(i);
                        }
                        return _this.isSet(i);
                    };
                };

                for (var i = 0; i < 1 << size; i = 1 << i) {
                    _loop(i);
                }
            }

            _createClass(NgBitset, [{
                key: "isSet",
                value: function isSet(i) {
                    return (this.val & i) !== 0;
                }
            }, {
                key: "toggle",
                value: function toggle(i) {
                    this.val = this.val ^ i;
                }

                // TODO - set/unset

            }]);

            return NgBitset;
        }();

        var utils = {

            // TODO - use angular $location object to make this testable
            unauthorized: function unauthorized() {
                log.error('You don\'t appear to be logged in.');
                // show the login page and then refresh so we lose any incorrect state. CC-279
                window.location.href = "/#/login";
                window.location.reload();
            },

            indentClass: function indentClass(depth) {
                return 'indent' + (depth - 1);
            },

            downloadFile: function downloadFile(url) {
                window.location = url;
            },

            // http://stackoverflow.com/a/18197341
            downloadText: function downloadText(filename, text) {
                var element = document.createElement('a');
                element.setAttribute('href', 'data:text/plain;charset=utf-8,' + encodeURIComponent(text));
                element.setAttribute('download', filename);
                element.style.display = 'none';
                document.body.appendChild(element);
                element.click();
                document.body.removeChild(element);
            },


            getModeFromFilename: function getModeFromFilename(filename) {
                var re = /(?:\.([^.]+))?$/;
                var ext = re.exec(filename)[1];
                var mode;
                switch (ext) {
                    case "conf":
                        mode = "properties";
                        break;
                    case "xml":
                        mode = "xml";
                        break;
                    case "yaml":
                        mode = "yaml";
                        break;
                    case "txt":
                        mode = "plain";
                        break;
                    case "json":
                        mode = "javascript";
                        break;
                    default:
                        mode = "shell";
                        break;
                }

                return mode;
            },

            updateLanguage: function updateLanguage($scope, $cookies, $translate) {
                var ln = $cookies.get("Language") || "en_US";
                if ($scope.user) {
                    $scope.user.language = ln;
                }
                $translate.use(ln);
            },

            capitalizeFirst: function capitalizeFirst(str) {
                return str.slice(0, 1).toUpperCase() + str.slice(1);
            },

            // call fn b after fn a
            after: function after(a, b, context) {
                return function () {
                    var results;
                    results = a.apply(context, arguments);
                    // TODO - send results to b?
                    b.call(context);
                    return results;
                };
            },

            mapToArr: function mapToArr(data) {
                var arr = [];
                for (var key in data) {
                    arr.push(data[key]);
                }
                return arr;
            },

            // cache function results based on hash function.
            // NOTE: unlike regular memoize, the caching is entirely
            // based on hash function, not on arguments
            memoize: function memoize(fn, hash) {
                var cache = {};
                return function () {
                    var key = hash.apply(this, arguments),
                        val;

                    // if value isnt cached, evaluate and cache
                    if (!(key in cache)) {
                        val = fn.apply(this, arguments);
                        cache[key] = val;
                    } else {
                        val = cache[key];
                    }

                    return val;
                };
            },

            isIpAddress: function isIpAddress(addr) {
                var re = /\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/;
                return re.test(addr);
            },

            needsHostAlias: function needsHostAlias(host) {
                // check is location.hostname is an IP
                return this.isIpAddress(host) || host === "localhost";
            },

            parseEngineeringNotation: function parseEngineeringNotation(str) {
                // Converts nK/k, nM/m, nG/g, nT/t to a number. e.g. 1K returns 1024.
                if (str === "" || str === undefined) {
                    return 0;
                }

                // if this is already a regular, boring, ol number
                if (isFinite(+str)) {
                    return +str;
                }

                var prefix = parseFloat(str);
                var suffix = str.slice(prefix.toString().length);
                switch (suffix) {
                    case "K":
                    case "k":
                        prefix *= 1 << 10;
                        break;
                    case "M":
                    case "m":
                        prefix *= 1 << 20;
                        break;
                    case "G":
                    case "g":
                        prefix *= 1 << 30;
                        break;
                    case "T":
                    case "t":
                        prefix *= 1 << 40;
                        break;
                    default:
                        prefix = undefined;
                        break;
                }
                return prefix;
            },

            // returns a function that will parse the
            // expression `attr` on scope object $scope
            // and return that value
            propGetter: function propGetter($scope, attr) {
                var getter = $parse(attr);
                return function () {
                    return getter($scope);
                };
            },

            // TODO - make services that should not count configurable
            // eg: started, stopped, manual, etc
            countTheKids: function countTheKids(parentService) {
                var filterFunction = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {
                    return true;
                };

                var children = parentService.children || [],
                    childCount = 0;

                // count number of descendent services that will start
                childCount = children.reduce(function countTheKids(acc, service) {
                    // if a service is not set to manual launch and
                    // has a startup command, it probably should count
                    var shouldCount = service.model.Launch !== "manual" && service.model.Startup;

                    // if shouldCount and the filter function returns
                    // true, this definitely counts
                    if (shouldCount && filterFunction(service)) {
                        acc++;
                    }

                    // if the service has children, check em
                    if (service.children) {
                        return service.children.reduce(countTheKids, acc);
                    }
                }, 0);

                return childCount;
            },

            humanizeDuration: function humanizeDuration(msecs) {
                // converts millisecons to a time duration such as 4h45m20s

                if (msecs === 0) {
                    return "0";
                }

                var humanized = "";
                var ttoken = Object.keys(TIMEMULTIPLIER);

                for (var i = 0; i < ttoken.length; i++) {
                    var d = Math.floor(msecs / TIMEMULTIPLIER[ttoken[i]]);
                    if (d) {
                        humanized += d.toString() + ttoken[i];
                        msecs -= d * TIMEMULTIPLIER[ttoken[i]];
                    }
                }
                // unused or duplicate tokens means bad input
                return humanized;
            },

            parseDuration: function parseDuration(humanTime) {
                // converts time duration such as 4h45m20s into milliseconds
                // accepts weeks thru milliseconds as: w d h m s ms.
                // 23m45s8ms  1425008

                var human = humanTime.toString().toLowerCase().replace(/ /g, '');
                if (human === "0" || human === "") {
                    return 0;
                }

                var badchars = human.match(/[^\da-z]/g);
                if (badchars) {
                    throw new Error("Found " + badchars.length + " unallowed characters in time entry: \"" + badchars.toString() + "\"");
                }
                var nounit = human.match(/\d+$/g);
                if (nounit) {
                    throw new Error("Numeric value " + nounit[0] + " lacks time unit");
                }
                var nonum = human.match(/^[a-z]+/g);
                if (nonum) {
                    throw new Error(nonum[0] + " is not a valid time duration");
                }

                var humanTokens = human.match(/\d+[a-z]+/g);
                var msecs = humanTokens.reduce(function (prev, tok) {
                    var tokPart = tok.match(/(\d+)([a-z]+)/);
                    if (!(tokPart[2] in TIMEMULTIPLIER)) {
                        // throw new Error("Unable to convert input " + humanTime + ": invalid time unit " + tokPart[0]);
                        throw new Error("Unable to convert input " + humanTime + ": invalid time unit \"" + tokPart[2] + "\"");
                    }
                    return parseFloat(tokPart[1]) * TIMEMULTIPLIER[tokPart[2]] + prev;
                }, 0);
                return msecs;
            },

            validateDuration: function validateDuration(durationStr) {
                try {
                    utils.parseDuration(durationStr);
                } catch (e) {
                    return e.message;
                }
            },

            validateHostName: function validateHostName(hostStr, $translate) {
                if (hostStr === undefined || hostStr === '') {
                    return $translate.instant("content_wizard_invalid_host");
                }

                return null;
            },

            validatePortNumber: function validatePortNumber(port, $translate) {
                if (port === undefined || port === '') {
                    return $translate.instant("port_number_invalid");
                }
                if (isNaN(+port)) {
                    return $translate.instant("port_number_invalid");
                }
                if (+port < 1 || +port > 65535) {
                    return $translate.instant("port_number_invalid_range");
                }

                return null;
            },

            validateRAMLimit: function validateRAMLimit(limitStr) {
                var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Infinity;


                if (limitStr === undefined || limitStr === '') {
                    return null;
                }

                var isPercent = limitStr.endsWith("%");
                var isEngineeringNotation = /.*[KkMmGgTt]$/.test(limitStr);

                if (!isPercent && !isEngineeringNotation) {
                    return "Invalid RAM Limit value, must specify % or unit of K, M, G, or T";
                }

                // if this is a percent, ensure its between 1 and 100
                if (isPercent) {
                    var val = +limitStr.slice(0, -1);
                    if (val > 100) {
                        return "RAM Limit cannot exceed 100%";
                    }
                    if (val <= 0) {
                        return "RAM Limit must be at least 1%";
                    }

                    // if this is a byte value, ensure its less than host memory
                } else {
                    var _val = utils.parseEngineeringNotation(limitStr);
                    if (isNaN(_val) || _val === undefined) {
                        return "Invalid RAM Limit value";
                    }
                    if (_val > max) {
                        return "RAM Limit exceeds available host memory";
                    }
                    if (_val <= 0) {
                        return "RAM Limit must be at least 1";
                    }
                }
                return null;
            },

            NgBitset: NgBitset,

            arrayEmpty: function arrayEmpty(array) {
                return typeof array === "undefined" || array === null || array.length <= 0;
            },

            escapeHTML: function escapeHTML(snippet) {
                return snippet.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#039;");
            }
        };

        return utils;
    }]);
})();
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* jshint multistr: true */
(function () {
    'use strict';

    angular.module('modalService', []).factory("$modalService", ["$rootScope", "$templateCache", "$http", "$interpolate", "$compile", "$translate", "$notification", "miscUtils", "CCUIState", function ($rootScope, $templateCache, $http, $interpolate, $compile, $translate, $notification, utils, CCUIState) {

        // accessing certain properties forces a DOM reflow,
        // which is useful if you want some CSS changes to
        // be applied to force the next CSS change to trigger
        // a transition
        function pokeDOM() {
            return document.body.scrollTop;
        }

        // global, reusable, handy-dandy modal
        // backdrop element, guaranteed to reduce all
        // other content down to about 50% of its original
        // brightness or your money back!

        var ModalDarkener = function () {
            function ModalDarkener() {
                _classCallCheck(this, ModalDarkener);

                this.el = document.createElement("div");
                this.el.className = "modal-darkener";
                document.body.appendChild(this.el);
            }

            _createClass(ModalDarkener, [{
                key: 'show',
                value: function show() {
                    this.el.style.display = "block";
                    pokeDOM();
                    this.el.classList.add("show");
                }
            }, {
                key: 'hide',
                value: function hide() {
                    var _this = this;

                    this.el.classList.remove("show");
                    // TODO - css transition end
                    setTimeout(function () {
                        _this.el.style.display = "none";
                    }, 250);
                }
            }]);

            return ModalDarkener;
        }();

        var darkener = new ModalDarkener();

        var defaultModalTemplate = function defaultModalTemplate(model) {
            return '\n                    <div class="modal fade" tabindex="-1" role="dialog" aria-hidden="true">\n                        <div class="modal-dialog ' + model.bigModal + '">\n                            <div class="modal-content">\n                                <div class="modal-header">\n                                    ' + (model.unclosable ? '' : '<button type="button" class="close glyphicon glyphicon-remove-circle" data-dismiss="modal" aria-hidden="true"></button>') + '\n                                    <span class="modal-title">' + model.title + '</span>\n                                </div>\n                                <div class="modal-notify"></div>\n                                <div class="modal-body">' + model.template + '</div>\n                                <div class="modal-footer"></div>\n                            </div>\n                        </div>\n                    </div>';
        };

        var actionButtonTemplate = '<button type="button" class="btn {{classes}}"><span ng-show="icon" class="glyphicon {{icon}}"></span> {{label}}</button>';

        var defaultRoles = {
            "cancel": {
                label: "btn_cancel",
                icon: "glyphicon-remove",
                classes: "btn-link minor",
                action: function action() {
                    this.close();
                }
            },
            "ok": {
                label: "Ok",
                icon: "glyphicon-ok",
                classes: "btn-primary submit",
                action: function action() {
                    this.close();
                }
            }
        };

        /**
         * Modal window
         */
        function Modal(template, model, config) {
            var _this2 = this;

            var $modalFooter;

            // inject user provided template into modal template
            var modalTemplate = defaultModalTemplate({
                template: template,
                title: $translate.instant(config.title),
                bigModal: config.bigModal ? "big" : "",
                unclosable: config.unclosable
            });

            var bootstrapModalConfig = {
                backdrop: false,
                keyboard: !config.unclosable
            };

            // bind user provided model to final modal template
            this.$el = $($compile(modalTemplate)(model)).modal(bootstrapModalConfig);

            // enforce disabling animation on modals if necessary
            if (CCUIState.get().disableAnimation) {
                console.log("disabling animation");
                this.$el.removeClass("fade");
            }

            $modalFooter = this.$el.find(".modal-footer");
            // cache a reference to the notification holder
            this.$notificationEl = this.$el.find(".modal-notify");

            // create action buttons
            config.actions.forEach(function (action) {

                // if this action has a role on it, merge role defaults
                if (action.role && defaultRoles[action.role]) {
                    for (var i in defaultRoles[action.role]) {
                        action[i] = action[i] || defaultRoles[action.role][i];
                    }
                }

                // translate button label
                action.label = $translate.instant(action.label);

                var $button = $($interpolate(actionButtonTemplate)(action));
                $button.on("click", action.action.bind(this));
                $modalFooter.append($button);
            }.bind(this));

            // if no actions, remove footer
            if (!config.actions.length) {
                $modalFooter.remove();
            }

            // setup/default validation function
            this.validateFn = config.validate || function (args) {
                return true;
            };

            // listen for hide event and completely remove modal
            // after it is hidden
            this.$el.on("hidden.bs.modal", function () {
                darkener.hide();
                this.destroy();
            }.bind(this));

            // NOTE - internal boostrap modal event that we need
            // to hook into to hide the modal if the darkener is clicked
            this.$el.on("click.dismiss.modal", function (e) {
                // if clicking the backdrop or clicking an element
                // marked with class "close", close things
                if (e.target === e.currentTarget || e.target.classList.contains("close")) {
                    _this2.destroy();
                    darkener.hide();
                }
            });
        }

        Modal.prototype = {
            constructor: Modal,
            close: function close() {
                this.$el.modal("hide");
                darkener.hide();
            },
            show: function show() {
                this.$el.modal("show");
                this.disableScroll();
                darkener.show();
            },
            validate: function validate(args) {
                return this.validateFn(args);
            },
            destroy: function destroy() {
                this.$el.remove();
                this.enableScroll();
            },
            // convenience method for attaching notifications to the modal
            createNotification: function createNotification(title, message) {
                return $notification.create(title, message, this.$notificationEl);
            },

            disableAction: function disableAction(classname) {
                this.$el.find(".modal-footer button." + classname).addClass("disabled");
            },
            enableAction: function enableAction(classname) {
                this.$el.find(".modal-footer button." + classname).removeClass("disabled");
            },
            disableScroll: function disableScroll() {
                var bodyEl = $("body");
                bodyEl.css("overflow", "hidden");
            },
            enableScroll: function enableScroll() {
                $("body").css("overflow", "scroll");
            },


            // convenience method to disable the default ok/submit button
            disableSubmitButton: function disableSubmitButton(selector, disabledText) {
                selector = selector || ".submit";
                disabledText = disabledText || "Submitting...";

                var $button = this.$el.find(selector),
                    $buttonClone,
                    buttonContent,
                    startWidth,
                    endWidth;

                // button wasnt found
                if (!$button.length) {
                    return;
                }

                // explicitly set width so it can be animated
                startWidth = $button.width();

                // clone the button and set the ending text so the
                // explicit width can be calculated
                $buttonClone = $button.clone().width("auto").text(disabledText).appendTo("body");
                endWidth = $buttonClone.width();
                $buttonClone.remove();

                $button.width(startWidth);

                buttonContent = $button.html();
                $button.prop("disabled", true).addClass("disabled").text(disabledText).width(endWidth);

                // return a function used to reenable the button
                return function () {
                    $button.prop("disabled", false).removeClass("disabled").html(buttonContent).width(startWidth);
                };
            }
        };

        var modalsPath = "/static/partials/",

        // keep track of existing modals so that they can be
        // close/destroyed when a new one is created
        // TODO - remove modals from this list when they are hidden
        modals = [];

        /**
         * Fetches modal template and caches it in $templateCache.
         * returns a promise for the http request
         */
        function fetchModalTemplate(name) {
            var url = modalsPath + name;
            return $http.get(url, { cache: $templateCache });
        }

        /**
         * fetches modal template and passes it along to be attached
         * to the DOM
         */
        function create(config) {

            config = config || {};
            // TODO - default config object
            config.actions = config.actions || [];
            config.onShow = config.onShow || function () {};
            config.onHide = config.onHide || function () {};
            var model = config.model || {};

            // if the template was provided, use that
            if (config.template) {
                _create(config.template, model, config);

                // otherwise, request the template
                // TODO - pop a modal with load spinner?
            } else {
                fetchModalTemplate(config.templateUrl).then(function (res) {
                    _create(res.data, model, config);
                });
            }
        }

        function _create(template, model, config) {
            // immediately destroy any existing modals
            modals.forEach(function (momo) {
                momo.destroy();
            });

            var modal = new Modal(template, model, config);
            modal.show();

            modals = [modal];

            // perform onShow function after modal is visible
            modal.$el.one("shown.bs.modal.", function () {
                // search for and autofocus the focusme element
                // unless disableAnimation is set, which probably
                // indicates this is an acceptance test is horrendously
                // slow and prone to breaking
                if (!CCUIState.get().disableAnimation) {
                    modal.$el.find("[focusme]").first().focus();
                }

                // call user provided onShow function
                setTimeout(function () {
                    config.onShow.call(modal);
                }, 0);
            });

            modal.$el.one("hidden.bs.modal.", config.onHide.bind(modal));
        }

        var displayHostKeys = function displayHostKeys(keys, registered, name) {
            var model = $rootScope.$new(true);
            model.keys = keys;
            model.name = name;
            model.registered = registered;

            create({
                templateUrl: "display-host-keys.html",
                model: model,
                title: $translate.instant("title_host_keys"),
                actions: [{
                    label: $translate.instant("btn_download_keys"),
                    action: function action() {
                        utils.downloadText(name + ".keys", keys);
                    },
                    icon: "glyphicon-download"
                }, {
                    role: "ok"
                }],
                onShow: function onShow() {
                    var _this3 = this;

                    // TODO - dont touch the DOM!
                    var keysWrapEl = this.$el.find(".keys-wrap"),
                        keysEl = keysWrapEl.find(".keys");
                    if (model.registered) {
                        this.createNotification("", "Host keys registered automatically").success();
                    }
                    keysWrapEl.on("click", function (e) {
                        // TODO - if already selected, this deselects
                        keysEl.select();
                        try {
                            var success = document.execCommand('copy');
                            if (success) {
                                _this3.createNotification("", "Keys copied to clipboard").info();
                            } else {
                                _this3.createNotification("", "Press Ctrl+C or Cmd+C to copy keys").info();
                            }
                        } catch (err) {
                            _this3.createNotification("", "Press Ctrl+C or Cmd+C to copy keys").info();
                        }
                    });
                }
            });
        };

        var oneMoment = function oneMoment(message) {
            var model = $rootScope.$new(true);
            model.message = message || $translate.instant("one_moment");
            var html = '\n                    <div style="width: 100%; text-align: center;">\n                        <img src="static/img/loading.gif">\n                        <div style="max-width: 75%; margin: 10px auto;">' + model.message + '</div>\n                    </div>';

            create({
                template: html,
                model: model,
                title: $translate.instant("one_moment"),
                unclosable: true
            });
        };

        var confirmServiceStateChange = function confirmServiceStateChange(service, state, childCount, onStartService, onStartServiceAndChildren) {
            var manyTemplate = function manyTemplate(model) {
                return '\n                        <h4>' + $translate.instant("choose_services_" + model.state) + '</h4>\n                        <ul>\n                            <li>' + $translate.instant(state + "_service_name", { name: "<strong>" + model.service.name + "</strong>" }) + '</li>\n                            <li>' + $translate.instant(state + "_service_name_and_children", {
                    name: '<strong>' + model.service.name + '</strong>',
                    count: '<strong>' + model.childCount + '</strong>' }) + '</li>\n                        </ul>';
            };

            var singleTemplate = function singleTemplate(model) {
                return $translate.instant("service_will_" + model.state, { name: '<strong>' + model.service.name + '</strong>' });
            };

            var model = $rootScope.$new(true);
            model = angular.extend(model, { service: service, state: state, childCount: childCount });
            var html = void 0;
            // button actions for the modal
            var actions = [{
                role: "cancel"
            }, {
                role: "ok",
                classes: " ",
                label: $translate.instant(state + "_service"),
                action: function action() {
                    onStartService(this);
                }
            }];

            // If there are any child nodes affected (1+ children), give them the
            // option to just start the service or service + 1 child.
            if (childCount >= 1) {
                html = manyTemplate(model);
                actions.push({
                    role: "ok",
                    label: $translate.instant(state + "_service_and_children", { count: childCount }),
                    action: function action() {
                        onStartServiceAndChildren(this);
                    }
                });
            } else {
                html = singleTemplate(model);
            }

            create({
                template: html,
                model: model,
                title: $translate.instant(state + "_service"),
                actions: actions
            });
        };

        return {
            create: create,
            // some shared modals that anyone can enjoy!
            modals: {
                displayHostKeys: displayHostKeys,
                oneMoment: oneMoment,
                confirmServiceStateChange: confirmServiceStateChange
            }
        };
    }]);
})();
"use strict";

/* globals controlplane: true */
(function () {

    var REQUEST_TIMEOUT = 30000;
    var GET = "get";
    var PUT = "put";
    var DELETE = "delete";
    var POST = "post";

    controlplane.factory("resourcesFactory", ["$http", "$location", "$notification", "CacheFactory", "$q", "$interval", "miscUtils", function ($http, $location, $notification, CacheFactory, $q, $interval, utils) {
        // add function to $http service to allow for noCacheGet requests
        $http.noCacheGet = function (location) {
            return $http({ url: location, method: "GET", params: { 'time': new Date().getTime() } });
        };

        var pollingFunctions = {};

        var redirectIfUnauthorized = function redirectIfUnauthorized(status) {
            if (status === 401) {
                utils.unauthorized($location);
            }
        };

        /*
         * a methodConfig is used to create a resources
         * factory interface method. The methodConfig object
         * has the following properties:
         *
         * @prop {string} method        - GET, POST, PUT, DELETE
         * @prop {string|function} url  - a string representing the url, or a function
         *                                that can generate the url. the function will
         *                                receive arguments passed to the factory method
         * @prop {function} [payload]   - function that returns the payload to be
         *                                delivered for POST or PUT request. the function
         *                                will receive arguments passed to the factory
         *                                method
         */
        var methodConfigs = {
            assignIP: {
                method: PUT,
                url: function url(id, ip) {
                    var url = "/services/" + id + "/ip";
                    if (ip) {
                        url += "/" + ip;
                    }
                    return url;
                }
            },
            getPools: {
                method: GET,
                url: "/pools"
            },
            getPool: {
                method: GET,
                url: function url(id) {
                    return "/pools/" + id;
                }
            },
            getPoolIPs: {
                method: GET,
                url: function url(id) {
                    return "/pools/" + id + "/ips";
                }
            },
            addVHost: {
                method: PUT,
                url: function url(serviceID, serviceName, endpointName, vhostName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/vhosts/" + vhostName;
                },
                payload: function payload(serviceID, serviceName) {
                    return JSON.stringify({
                        'ServiceName': serviceName });
                }
            },
            removeVHost: {
                method: DELETE,
                url: function url(serviceID, endpointName, vhostName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/vhosts/" + vhostName;
                }
            },
            enableVHost: {
                method: POST,
                url: function url(serviceID, serviceName, endpointName, vhostName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/vhosts/" + vhostName;
                },
                payload: function payload(serviceID, serviceName) {
                    return JSON.stringify({
                        'ServiceName': serviceName, /* Used in messages/logs */
                        'IsEnabled': true
                    });
                }
            },
            disableVHost: {
                method: POST,
                url: function url(serviceID, serviceName, endpointName, vhostName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/vhosts/" + vhostName;
                },
                payload: function payload(serviceID, serviceName) {
                    return JSON.stringify({
                        'ServiceName': serviceName, /* Used in messages/logs */
                        'IsEnabled': false
                    });
                }
            },
            addPort: {
                method: PUT,
                url: function url(serviceID, serviceName, endpointName, portName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/ports/" + portName;
                },
                payload: function payload(serviceID, serviceName, endpointName, portName, usetls, protocol) {
                    return JSON.stringify({
                        'ServiceName': serviceName, /* Used in messages/logs */
                        'UseTLS': usetls,
                        'Protocol': protocol
                    });
                }
            },
            removePort: {
                method: DELETE,
                url: function url(serviceID, endpointName, portName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/ports/" + portName;
                }
            },
            enablePort: {
                method: POST,
                url: function url(serviceID, serviceName, endpointName, portName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/ports/" + portName;
                },
                payload: function payload(serviceID, serviceName) {
                    return JSON.stringify({
                        'ServiceName': serviceName, /* Used in messages/logs */
                        'IsEnabled': true
                    });
                }
            },
            disablePort: {
                method: POST,
                url: function url(serviceID, serviceName, endpointName, portName) {
                    return "/services/" + serviceID + "/endpoint/" + endpointName + "/ports/" + portName;
                },
                payload: function payload(serviceID, serviceName) {
                    return JSON.stringify({
                        'Application': serviceName,
                        'IsEnabled': false
                    });
                }
            },
            getServiceInstances: {
                method: GET,
                url: "/servicestatus"
            },
            addPool: {
                method: POST,
                url: "/pools/add",
                payload: function payload(pool) {
                    return pool;
                }
            },
            removePool: {
                method: DELETE,
                url: function url(id) {
                    return "/pools/" + id;
                }
            },
            updatePool: {
                method: PUT,
                url: function url(id) {
                    return "/pools/" + id;
                },
                payload: function payload(id, pool) {
                    return pool;
                }
            },
            addPoolVirtualIP: {
                method: PUT,
                url: function url(poolID) {
                    return "/pools/" + poolID + "/virtualip";
                },
                payload: function payload(poolID, ip, netmask, bindInterface) {
                    return JSON.stringify({
                        PoolID: poolID,
                        IP: ip,
                        Netmask: netmask,
                        BindInterface: bindInterface
                    });
                }
            },
            removePoolVirtualIP: {
                method: DELETE,
                url: function url(poolID, ip) {
                    return "/pools/" + poolID + "/virtualip/" + ip;
                }
            },
            killRunning: {
                method: DELETE,
                url: function url(hostID, instanceID) {
                    return "/hosts/" + hostID + "/" + instanceID;
                }
            },
            getHosts: {
                method: GET,
                url: "/hosts"
            },
            addHost: {
                method: POST,
                url: "/hosts/add",
                payload: function payload(host) {
                    return host;
                }
            },
            getHost: {
                method: GET,
                url: function url(id) {
                    return "/hosts/" + id;
                }
            },
            updateHost: {
                method: PUT,
                url: function url(id) {
                    return "/hosts/" + id;
                },
                payload: function payload(id, host) {
                    return host;
                }
            },
            resetHostKeys: {
                method: POST,
                url: function url(id) {
                    return "/hosts/" + id + "/key";
                }
            },
            removeHost: {
                method: DELETE,
                url: function url(id) {
                    return "/hosts/" + id;
                }
            },
            getRunningHosts: {
                method: GET,
                url: "/hosts/running"
            },
            getServices: {
                method: GET,
                url: function url(since) {
                    return "/services" + (since ? "?since=" + since : "");
                }
            },
            getInstanceLogs: {
                method: GET,
                url: function url(serviceID, instanceID) {
                    return "/services/" + serviceID + "/" + instanceID + "/logs";
                }
            },
            dockerIsLoggedIn: {
                method: GET,
                url: "/dockerIsLoggedIn"
            },
            getAppTemplates: {
                method: GET,
                url: "/templates"
            },
            removeAppTemplate: {
                method: DELETE,
                url: function url(id) {
                    return "/templates/" + id;
                }
            },
            updateService: {
                method: PUT,
                url: function url(id) {
                    return "/services/" + id;
                },
                payload: function payload(id, service) {
                    return service;
                }
            },
            deployAppTemplate: {
                method: POST,
                url: "/templates/deploy",
                payload: function payload(template) {
                    return template;
                }
            },
            removeService: {
                method: DELETE,
                url: function url(id) {
                    return "/services/" + id;
                }
            },
            startService: {
                method: PUT,
                url: function url(id, skip) {
                    return "/services/" + id + "/startService" + (skip ? "?auto=false" : "");
                }
            },
            stopService: {
                method: PUT,
                url: function url(id, skip) {
                    return "/services/" + id + "/stopService" + (skip ? "?auto=false" : "");
                }
            },
            restartService: {
                method: PUT,
                url: function url(id, skip) {
                    return "/services/" + id + "/restartService" + (skip ? "?auto=false" : "");
                }
            },
            getVersion: {
                method: GET,
                url: "/version"
            },
            getDeployStatus: {
                method: POST,
                url: "/templates/deploy/status",
                payload: function payload(def) {
                    return def;
                }
            },
            getDeployingTemplates: {
                method: GET,
                url: "/templates/deploy/active"
            },
            createBackup: {
                method: GET,
                url: "/backup/create"
            },
            restoreBackup: {
                method: GET,
                url: function url(filename) {
                    return "/backup/restore?filename=" + filename;
                }
            },
            getBackupCheck: {
                method: GET,
                url: "/backup/check"
            },
            getBackupFiles: {
                method: GET,
                url: "/backup/list"
            },
            getBackupStatus: {
                method: GET,
                url: "/backup/status"
            },
            getRestoreStatus: {
                method: GET,
                url: "/backup/restore/status"
            },
            getHostAlias: {
                method: GET,
                url: "/hosts/defaultHostAlias"
            },
            getUIConfig: {
                method: GET,
                url: "/config"
            },
            getStorage: {
                method: GET,
                url: "/storage"
            }
        };

        var v2MethodConfigs = {
            getPools: {
                method: GET,
                url: function url() {
                    return "/api/v2/pools";
                }
            },
            getPoolHosts: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/pools/" + id + "/hosts";
                }
            },
            getHosts: {
                method: GET,
                url: function url() {
                    return "/api/v2/hosts";
                }
            },
            getHostInstances: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/hosts/" + id + "/instances";
                }
            },
            getHostStatuses: {
                method: GET,
                url: function url(ids) {
                    return ids ? "/api/v2/hoststatuses?hostId=" + ids.join("&hostId=") : "/api/v2/hoststatuses";
                },
                ignorePending: true
            },
            getService: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id;
                }
            },
            getTenants: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services?tenants";
                }
            },
            updateService: {
                method: PUT,
                url: function url(id) {
                    return "/api/v2/services/" + id;
                },
                payload: function payload(id, service) {
                    return service;
                }
            },
            getServiceAncestors: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "?ancestors";
                }
            },
            getServiceChildren: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/services";
                }
            },
            getServiceConfig: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/serviceconfigs/" + id;
                }
            },
            updateServiceConfig: {
                method: PUT,
                url: function url(id) {
                    return "/api/v2/serviceconfigs/" + id;
                },
                payload: function payload(id, cfg) {
                    return JSON.stringify({
                        'Filename': cfg.Filename,
                        'Owner': cfg.Owner,
                        'Permissions': cfg.Permissions,
                        'Content': cfg.Content
                    });
                }
            },
            getServiceConfigs: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/serviceconfigs";
                }
            },
            getServiceContext: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/context";
                }
            },
            updateServiceContext: {
                method: PUT,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/context";
                },
                payload: function payload(id, ctx) {
                    return ctx;
                }
            },
            getServiceInstances: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/instances";
                },
                ignorePending: true
            },
            getServiceIpAssignments: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/ipassignments?includeChildren";
                }
            },
            getServiceMonitoringProfile: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/monitoringprofile";
                }
            },
            getServicePublicEndpoints: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/publicendpoints?includeChildren";
                }
            },
            getServiceChildPublicEndpoints: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/publicendpoints";
                }
            },
            getServiceExportEndpoints: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/exportendpoints?includeChildren";
                }
            },
            getServices: {
                method: GET,
                url: function url(since) {
                    return "/api/v2/services" + (since ? "?since=" + since : "");
                }
            },
            getInternalServices: {
                method: GET,
                url: function url() {
                    return "/api/v2/internalservices";
                }
            },
            getInternalService: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/internalservices/" + id;
                }
            },
            getInternalServiceInstances: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/internalservices/" + id + "/instances";
                }
            },
            getInternalServiceStatuses: {
                method: GET,
                url: function url(ids) {
                    return ids ? "/api/v2/internalservicestatuses?" + ids.map(function (id) {
                        return "id=" + id;
                    }).join('&') : '/api/v2/internalservicestatuses';
                }
            },
            getServiceStatus: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/statuses?serviceId=" + id;
                },
                ignorePending: true
            },
            getServiceStatuses: {
                method: GET,
                url: function url(ids) {
                    return "/api/v2/statuses?" + ids.map(function (id) {
                        return "serviceId=" + id;
                    }).join('&');
                },
                ignorePending: true
            },
            getDescendantCounts: {
                method: GET,
                url: function url(id) {
                    return "/api/v2/services/" + id + "/descendantstates";
                },
                ignorePending: true
            }
        };

        // adds success and error functions
        // to regular promise ala $http
        function httpify(deferred) {
            deferred.promise.success = function (fn) {
                deferred.promise.then(fn);
                return deferred.promise;
            };
            deferred.promise.error = function (fn) {
                deferred.promise.then(null, fn);
                return deferred.promise;
            };
            return deferred;
        }

        var pendingGETRequests = {};

        function generateMethod(config) {
            // method should be all lowercase
            config.method = config.method.toLowerCase();

            // if url is a string, turn it into a getter fn
            if (typeof config.url === "string") {
                (function () {
                    var url = config.url;
                    config.url = function () {
                        return url;
                    };
                })();
            }

            return function () /* args */{
                var url = config.url.apply(null, arguments),
                    method = config.method,
                    resourceName = url,
                    payload,

                // deferred that will be returned to the user
                deferred = $q.defer(),
                    requestObj;

                // if resourceName has query params, strip em off
                if (resourceName.indexOf("?")) {
                    resourceName = resourceName.split("?")[0];
                }

                // NOTE: all of our code expects angular's wrapped
                // promises which provide a success and error method
                // TODO - remove the need for this
                httpify(deferred);

                // theres already a pending request to
                // this endpoint, so fail!
                if (method === GET && pendingGETRequests[resourceName]) {
                    var message = "a request to " + resourceName + " is pending";
                    var data = { Detail: message };
                    deferred.reject(data);
                    return deferred.promise;
                }

                if (config.payload) {
                    payload = config.payload.apply(null, arguments);
                }

                requestObj = {
                    method: method,
                    url: url,
                    data: payload
                };

                if (method === GET) {
                    requestObj.timeout = REQUEST_TIMEOUT;
                }

                $http(requestObj).success(function (data, status) {
                    deferred.resolve(data);
                }).error(function (data, status) {
                    // TODO - include status as well?
                    deferred.reject(data);
                    redirectIfUnauthorized(status);
                }).finally(function () {
                    if (method === GET) {
                        pendingGETRequests[resourceName] = null;
                    }
                });

                // NOTE: only limits GET requests
                if (method === GET && !config.ignorePending) {
                    pendingGETRequests[resourceName] = deferred;
                }

                return deferred.promise;
            };
        }

        var resourcesFactoryInterface = {
            addAppTemplate: function addAppTemplate(fileData) {
                return $http({
                    url: "/templates/add",
                    method: POST,
                    data: fileData,
                    // content-type undefined forces the browser to fill in the
                    // boundary parameter of the request
                    headers: { "Content-Type": undefined },
                    // identity returns the value it receives, which prevents
                    // transform from modifying the request in any way
                    transformRequest: angular.identity
                }).error(function (data, status) {
                    redirectIfUnauthorized(status);
                });
            },

            registerPoll: function registerPoll(label, callback, interval) {
                if (pollingFunctions[label] !== undefined) {
                    clearInterval(pollingFunctions[label]);
                }

                pollingFunctions[label] = $interval(function () {
                    callback();
                }, interval);
            },

            unregisterAllPolls: function unregisterAllPolls() {
                for (var key in pollingFunctions) {
                    $interval.cancel(pollingFunctions[key]);
                }

                pollingFunctions = {};
            },

            // redirect to specific service details
            routeToService: function routeToService(id) {
                $location.path('/services/' + id);
            },

            // redirect to specific pool
            routeToPool: function routeToPool(id) {
                $location.path('/pools/' + id);
            },

            // redirect to specific host
            routeToHost: function routeToHost(id) {
                $location.path('/hosts/' + id);
            },

            // redirect to specific internal service details
            routeToInternalService: function routeToInternalService(id) {
                $location.path('/internalservices/' + id);
            },

            // redirect to internal service page
            routeToInternalServices: function routeToInternalServices() {
                $location.path('/internalservices');
            }
        };

        // generate additional methods and attach
        // to interface
        for (var name in methodConfigs) {
            resourcesFactoryInterface[name] = generateMethod(methodConfigs[name]);
        }

        // generate Version 2 API methods and attach
        // to interface
        resourcesFactoryInterface.v2 = {};
        for (var name in v2MethodConfigs) {
            resourcesFactoryInterface.v2[name] = generateMethod(v2MethodConfigs[name]);
        }

        return resourcesFactoryInterface;
    }]);
})();
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* servicedConfigService.js
 * get UI config values from serviced
 */
(function () {
    "use strict";

    var resourcesFactory, $q;

    var ServicedConfig = function () {
        function ServicedConfig() {
            _classCallCheck(this, ServicedConfig);
        }

        _createClass(ServicedConfig, [{
            key: "update",
            value: function update() {
                var d = $q.defer();

                resourcesFactory.getUIConfig()
                // TODO - errors
                .then(function (response) {
                    d.resolve(response);
                }, function (err) {
                    d.reject(err);
                });

                this._d = d.promise;
                return this._d;
            }
        }, {
            key: "getConfig",
            value: function getConfig() {
                if (!this._d) {
                    this.update();
                }
                return this._d;
            }
        }]);

        return ServicedConfig;
    }();

    var servicedConfig = new ServicedConfig();

    angular.module("servicedConfig", []).factory("servicedConfig", ["$q", "resourcesFactory", function (_$q, _resourcesFactory) {
        resourcesFactory = _resourcesFactory;
        $q = _$q;
        servicedConfig.update();
        return servicedConfig;
    }]);
})();
'use strict';

/* global: $ */
/* jshint multistr: true */
(function () {
    'use strict';

    angular.module('ui.datetimepicker', []).directive('datetimepicker', [function () {
        return {
            restrict: 'A',
            require: 'ngModel',
            link: function link(scope, element, attrs, ngModelCtrl) {
                // wait a tick before init because calling directive
                // may not have completed its init yet
                setTimeout(function () {
                    var options = {};
                    if (attrs.dateoptions && scope[attrs.dateoptions]) {
                        options = scope[attrs.dateoptions];
                    }
                    element.datetimepicker(options);
                    element.bind('blur keyup change', function () {
                        var model = attrs.ngModel;
                        if (model.indexOf(".") > -1) {
                            scope[model.replace(/\.[^.]*/, "")][model.replace(/[^.]*\./, "")] = element.val();
                        } else {
                            scope[model] = element.val();
                        }
                    });
                }, 0);
            }
        };
    }]);
})();
'use strict';

/* global: $ */
/* jshint multistr: true */
var SEVERITY = {
    SUCCESS: 0,
    INFO: 1,
    WARNING: 2,
    ERROR: 3
};

// stores whatever the last message is
var lastMessage;

(function () {
    'use strict';

    /**
     * @ngdoc overview
     * @name notification
     */

    angular.module('zenNotify', []).

    /**
     * @ngdoc object
     * @name zenNotify.Notification
     * @requires $templateCache
     */

    factory('$notification', ['$rootScope', '$templateCache', '$translate', "log", function ($rootScope, $templateCache, $translate, log) {
        var notificationFactory;

        var notificationTemplate = '<div class="bg-info notification" style="display:none;">\
            <span class="dialogIcon glyphicon glyphicon-info-sign"></span>\
            <span class="title"></span>\
            <span class="message"></span>\
            <button type="button" class="close" aria-hidden="true" style="display:none;">&times;</button>\
        </div>';

        /**
         * Notification
         * Creates a notification. Great for parties!
         */
        function Notification(id, title, msg, $attachPoint) {
            this.id = id;
            this.$el = $(notificationTemplate);
            this.$message = this.$el.find(".message");
            this.$title = this.$el.find(".title");
            this.title = title;
            this.msg = msg;
            this.$attachPoint = $attachPoint;
            this.severity = SEVERITY.INFO;

            this.updateTitle(this.title || "");
            this.updateStatus(this.msg || "");

            // bind onClose context so it doesn't have
            // to be rebound for each event listener
            this.onClose = this.onClose.bind(this);
            this.hide = this.hide.bind(this);
        }

        Notification.prototype = {
            constructor: Notification,

            success: function success(autoclose) {
                this.severity = SEVERITY.SUCCESS;

                // change notification color, icon, text, etc
                this.$el.removeClass("bg-info").addClass("bg-success");
                this.$el.find(".dialogIcon").removeClass("glyphicon-info-sign").addClass("glyphicon-ok-sign");

                this.updateTitle(this.title || $translate.instant("success"));
                this.updateStatus(this.msg || "");

                // show close button and make it active
                this.$el.find(".close").show().off().on("click", this.onClose);
                notificationFactory.store(this);
                this.show(autoclose);

                return this;
            },

            warning: function warning(autoclose) {
                this.severity = SEVERITY.WARNING;

                // change notification color, icon, text, etc
                this.$el.removeClass("bg-info").addClass("bg-warning");
                this.$el.find(".dialogIcon").removeClass("glyphicon-info-sign").addClass("glyphicon-warning-sign");

                this.updateTitle(this.title || $translate.instant("warning"));
                this.updateStatus(this.msg || "");
                notificationFactory.store(this);
                if (!autoclose) {
                    // show close button and make it active
                    this.$el.find(".close").show().off().on("click", this.onClose);
                    notificationFactory.store(this);
                }
                this.show(autoclose);

                return this;
            },

            info: function info(autoclose) {
                this.severity = SEVERITY.INFO;

                this.updateTitle(this.title || $translate.instant("info"));
                this.updateStatus(this.msg || "");

                // show close button and make it active
                this.$el.find(".close").show().off().on("click", this.onClose);
                notificationFactory.store(this);
                this.show(autoclose);

                return this;
            },

            error: function error() {
                this.severity = SEVERITY.ERROR;

                // change notification color, icon, text, etc
                this.$el.removeClass("bg-info").addClass("bg-danger");
                this.$el.find(".dialogIcon").removeClass("glyphicon-info-sign").addClass("glyphicon-remove-sign");

                this.updateTitle(this.title || $translate.instant("error"));
                this.updateStatus(this.msg || "");

                // show close button and make it active
                this.$el.find(".close").show().off().on("click", this.onClose);
                notificationFactory.store(this);
                this.show(false);

                return this;
            },

            onClose: function onClose(e) {
                notificationFactory.markRead(this);
                this.hide();
            },

            hide: function hide() {
                this.$el.slideUp("fast", function () {
                    this.$el.remove();
                }.bind(this));
            },

            // updates the status message (the smaller text)
            updateStatus: function updateStatus(msg) {
                this.msg = msg || "";
                this.$message.html(this.msg);
                return this;
            },

            // updates the notification title (larger text)
            updateTitle: function updateTitle(title) {
                this.title = title || "";
                this.$title.text(this.title);
                return this;
            },

            show: function show(autoclose) {
                // close previous message if it is not
                // the current message
                if (lastMessage && lastMessage !== this) {
                    lastMessage.hide();
                }

                // if $attachPoint is no longer in the document
                // use the default attachPoint
                if (!$.contains(document, this.$attachPoint[0])) {
                    this.$attachPoint = $("#notifications");
                }
                this.$attachPoint.append(this.$el);

                autoclose = typeof autoclose !== 'undefined' ? autoclose : true;
                this.$el.slideDown("fast");

                if (autoclose) {
                    setTimeout(this.hide, 5000);
                }

                lastMessage = this;

                return this;
            }
        };

        function NotificationFactory() {
            this.$storage = JSON.parse(localStorage.getItem('messages')) || [];
            this.lastId = null;

            // if this is the first time we sending a message, try to lookup the next ID from storage
            if (this.lastId === null) {
                this.lastId = 0;
                this.$storage.forEach(function (el, idx) {
                    if (el.id >= this.lastId) {
                        this.lastId = el.id;
                    }
                }.bind(this));
            }
        }

        /**
         * Notification Factory
         * interface for creating, storing, and updating notifications
         */
        NotificationFactory.prototype = {
            constructor: NotificationFactory,

            /**
             * create a new notification. Loads of fun!
             * @param  {string} title  notification title. treated as plain text
             * @param  {string} msg  notification message. treated as HTML
             * @param  {jQueryObject} $attachPoint  jQuery DOM element to attach notification to
             *                                      defaults to `#notification` element
             * @return {Notification}  returns the Notification object
             */
            create: function create(title, msg, $attachPoint) {
                // if no valid attachPoint is provided, default to #notifications
                if (!$attachPoint || !$attachPoint.length) {
                    $attachPoint = $("#notifications");
                }
                var notification = new Notification(++this.lastId, title, msg, $attachPoint);

                return notification;
            },

            /**
             * marks provided notification read and updates local data store
             * @param  {Notification} notification  the Notification object to mark read
             */
            markRead: function markRead(notification) {
                this.$storage.forEach(function (el, idx) {
                    if (el.id === notification.id) {
                        el.read = el.count;
                    }
                }.bind(this));

                localStorage.setItem('messages', JSON.stringify(this.$storage));
                $rootScope.$broadcast("messageUpdate");
            },

            /**
             * stores provided notification
             * @param  {Notification} notification  the Notification object to store
             */
            store: function store(notification) {
                var storable = { id: notification.id, read: 0, date: new Date(), title: notification.title, msg: notification.msg, count: 1 };
                var newMessage = false;

                var isDuplicate = function () {
                    // de-dup messages
                    for (var i = 0; i < this.$storage.length; ++i) {
                        var message = this.$storage[i];
                        log.log(notification.msg + " === " + message.msg);
                        if (message && notification.msg === message.msg) {
                            ++message.count;
                            return true;
                        } else {
                            return false;
                        }
                    }
                }.bind(this);

                if (!isDuplicate() && (notification.severity === SEVERITY.ERROR || notification.severity === SEVERITY.SUCCESS)) {
                    if (this.$storage.unshift(storable) > 100) {
                        this.$storage.pop();
                    }
                    newMessage = true;
                }

                localStorage.setItem('messages', JSON.stringify(this.$storage));
                $rootScope.$broadcast("messageUpdate");
                return newMessage;
            },

            /**
             * updates stored notification (by id) with the provided notification
             * @param  {Notification} notification  the Notification object to update
             */
            update: function update(notification) {
                var storable = { id: notification.id, read: 0, date: new Date(), title: notification.title, msg: notification.msg };

                this.$storage.forEach(function (el, idx) {
                    if (el.id === notification.id) {
                        el = storable;
                    }
                }.bind(this));

                localStorage.setItem('messages', JSON.stringify(this.$storage));
                $rootScope.$broadcast("messageUpdate");
            },

            /**
             * gets all stored messages as well as number of unread messages
             * @return {object}  object containing `unreadCount` - the number of unread messages,
             *                          and `messages` - an array of stored notifications.
             */
            getMessages: function getMessages() {
                var unreadCount;

                unreadCount = this.$storage.reduce(function (prev, cur, idx, storage) {
                    cur.count = cur.count || 0;
                    return prev + (cur.count - cur.read);
                }, 0);

                return {
                    unreadCount: unreadCount,
                    messages: this.$storage
                };
            },

            /**
             * removes all stored Notifications (read and unread)
             */
            clearAll: function clearAll() {
                this.$storage = [];
                localStorage.clear();
                $rootScope.$broadcast("messageUpdate");
            }
        };

        notificationFactory = new NotificationFactory();
        return notificationFactory;
    }]);
})();
//# sourceMappingURL=controlplane.js.map
